@@ -90,6 +90,11 @@ namespace Lum {
     bool HandleKeyEvent(const OS::KeyEvent& event);
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
+
+    static Button* CreateOk(Model::Action* action);
+    static Button* CreateCancel(Model::Action* action);
+    static Button* CreateClose(Model::Action* action);
+    static Button* CreateHelp(Model::Action* action);
   };
 }
 
