@@ -49,6 +49,11 @@ namespace Lum {
 
     void CalcSize();
     void Layout();
+
+    static ButtonRow* CreateOk(Model::Action* ok);
+    static ButtonRow* CreateCancel(Model::Action* cancel);
+    static ButtonRow* CreateOkCancel(Model::Action* ok, Model::Action* cancel);
+    static ButtonRow* CreateClose(Model::Action* close);
   };
 }
 
