@@ -33,6 +33,7 @@
 #include <Lum/Dialog.h>
 #include <Lum/Image.h>
 #include <Lum/Object.h>
+#include <Lum/Popup.h>
 #include <Lum/String.h>
 #include <Lum/Table.h>
 #include <Lum/TableView.h>
@@ -66,14 +67,14 @@ namespace Lum {
       void Resync(Base::Model* model, const Base::ResyncMsg& msg);
     };
 
-    class Popup : public Dialog
+    class ComboPopup : public Popup
     {
     public:
       Combo *combo;
 
     public:
-      Popup(Combo *combo);
-      ~Popup();
+      ComboPopup(Combo *combo);
+      ~ComboPopup();
       void PreInit();
       void Resync(Base::Model* model, const Base::ResyncMsg& msg);
     };
