@@ -21,7 +21,7 @@
 */
 
 #include <Lum/DatePicker.h>
-#include <Lum/Dialog.h>
+#include <Lum/Popup.h>
 #include <Lum/PopupControl.h>
 
 namespace Lum {
@@ -30,15 +30,15 @@ namespace Lum {
   class LUMAPI DateSelect : public PopupControl
   {
   private:
-    class Popup : public Dialog
+    class DateSelectPopup : public Popup
     {
     public:
       DateSelect *select;
       DatePicker *picker;
 
     public:
-      Popup(DateSelect *combo);
-      ~Popup();
+      DateSelectPopup(DateSelect *combo);
+      ~DateSelectPopup();
 
       void PreInit();
 
@@ -46,7 +46,7 @@ namespace Lum {
     };
 
   private:
-    Popup* popup;
+    DateSelectPopup* popup;
 
   private:
     void OpenPopup();
