@@ -33,23 +33,6 @@ namespace Lum {
   */
   class LUMAPI FuelGauge : public Control
   {
-  public:
-    class Prefs : public Control::Prefs
-    {
-    public:
-      OS::FillRef  hBackground;
-      OS::FillRef  vBackground;
-      OS::FillRef  hFill;
-      OS::FillRef  vFill;
-      OS::FrameRef hFrame;
-      OS::FrameRef vFrame;
-      Base::Size   minSize;
-
-    public:
-      Prefs();
-      void Initialize();
-    };
-
   private:
     Model::DoubleRef model;
     OS::FontRef      font;
