@@ -31,8 +31,190 @@
 namespace Lum {
 
   class Menu;
+  class MenuStrip;
   class PullDownMenu;
 
+  /* Definition of menues, menu items... */
+
+  class LUMAPI MenuItemDesc
+  {
+  protected:
+    MenuItemDesc();
+
+  public:
+    virtual ~MenuItemDesc();
+  };
+
+  class LUMAPI MenuDesc
+  {
+  public:
+    typedef std::list<MenuItemDesc*> MenuItemList;
+
+  private:
+    std::wstring             title;
+    std::list<MenuItemDesc*> items;
+
+  public:
+    MenuDesc();
+    MenuDesc(const std::wstring& title);
+    virtual ~MenuDesc();
+
+    MenuDesc* AddMenuItem(MenuItemDesc* menuItem);
+
+    MenuDesc* AddMenuItemAction(const std::wstring& label,
+                                Model::Action* action);
+
+    MenuDesc* AddMenuItemAction(const std::wstring& label,
+                                OS::Image* image,
+                                Model::Action* action);
+
+    MenuDesc* AddMenuItemAction(const std::wstring& label,
+                                unsigned long qualifier, const std::wstring& key,
+                                Model::Action* action);
+
+    MenuDesc* AddMenuItemAction(const std::wstring& label,
+                                OS::Image* image,
+                                unsigned long qualifier, const std::wstring& key,
+                                Model::Action* action);
+
+    MenuDesc* AddMenuItemSub(const std::wstring& label);
+
+    MenuDesc* AddMenuItemBool(const std::wstring& label,
+                              Model::Boolean* boolean);
+
+    MenuDesc* AddMenuItemBool(const std::wstring& label,
+                              OS::Image* image,
+                              Model::Boolean* boolean);
+
+    MenuDesc* AddMenuItemBool(const std::wstring& label,
+                              unsigned long qualifier, const std::wstring& key,
+                              Model::Boolean* boolean);
+
+    MenuDesc* AddMenuItemBool(const std::wstring& label,
+                              OS::Image* image,
+                              unsigned long qualifier, const std::wstring& key,
+                              Model::Boolean* boolean);
+
+    MenuDesc* AddMenuItemRadio(const std::wstring& label,
+                               Model::SizeT* model,
+                               size_t index);
+
+    MenuDesc* AddMenuItemRadio(const std::wstring& label,
+                               OS::Image* image,
+                               Model::SizeT* model,
+                               size_t index);
+
+    MenuDesc* AddMenuItemRadio(const std::wstring& label,
+                               unsigned long qualifier, const std::wstring& key,
+                               Model::SizeT* model,
+                               size_t index);
+
+    MenuDesc* AddMenuItemRadio(const std::wstring& label,
+                               OS::Image* image,
+                               unsigned long qualifier, const std::wstring& key,
+                               Model::SizeT* model,
+                               size_t index);
+
+    MenuDesc* AddSeparator();
+
+    const MenuItemList& GetItems() const;
+  };
+
+  class LUMAPI MenuItemSubDesc : public MenuItemDesc
+  {
+  private:
+    std::wstring label;
+    MenuDesc     *menu;
+
+  public:
+    MenuItemSubDesc(const std::wstring& label,
+                    MenuDesc* menu);
+    ~MenuItemSubDesc();
+
+    std::wstring GetLabel() const;
+    MenuDesc* GetMenuDesc() const;
+  };
+
+  class LUMAPI MenuItemActionDesc : public MenuItemDesc
+  {
+  private:
+    std::wstring     label;
+    OS::ImageRef     image;
+    unsigned long    qualifier;
+    std::wstring     key;
+    Model::ActionRef action;
+
+  public:
+    MenuItemActionDesc(const std::wstring& label,
+                       OS::Image* image,
+                       unsigned long qualifier, const std::wstring& key,
+                       Model::Action* action);
+
+    std::wstring GetLabel() const;
+    OS::Image* GetImage() const;
+    unsigned long GetQualifier() const;
+    std::wstring GetKey() const;
+    Model::Action* GetAction() const;
+  };
+
+  class LUMAPI MenuItemSeparatorDesc : public MenuItemDesc
+  {
+  public:
+    MenuItemSeparatorDesc();
+  };
+
+  class LUMAPI MenuItemBoolDesc : public MenuItemDesc
+  {
+  private:
+    std::wstring      label;
+    OS::ImageRef      image;
+    unsigned long     qualifier;
+    std::wstring      key;
+    Model::BooleanRef boolean;
+
+  public:
+    MenuItemBoolDesc(const std::wstring& label,
+                     OS::Image* image,
+                     unsigned long qualifier, const std::wstring& key,
+                     Model::Boolean* boolean);
+
+    std::wstring GetLabel() const;
+    OS::Image* GetImage() const;
+    unsigned long GetQualifier() const;
+    std::wstring GetKey() const;
+    Model::Boolean* GetBoolean() const;
+  };
+
+  class LUMAPI MenuItemRadioDesc : public MenuItemDesc
+  {
+  private:
+    std::wstring    label;
+    OS::ImageRef    image;
+    unsigned long   qualifier;
+    std::wstring    key;
+    Model::SizeTRef model;
+    size_t          index;
+
+  public:
+    MenuItemRadioDesc(const std::wstring& label,
+                      OS::Image* image,
+                      unsigned long qualifier, const std::wstring& key,
+                      Model::SizeT* model,
+                      size_t index);
+
+    std::wstring GetLabel() const;
+    OS::Image* GetImage() const;
+    unsigned long GetQualifier() const;
+    std::wstring GetKey() const;
+    Model::SizeT* GetModel() const;
+    size_t GetIndex() const;
+  };
+
+  /* Default implementation */
+
+  extern LUMAPI Menu* ConvertToMenu(MenuDesc* menuDesc);
+  extern LUMAPI MenuStrip* ConvertToMenuStrip(MenuDesc* menuDesc);
+
   /**
     Always visible menu bar containing a number of
     pulldown menues which in turn point to menu
@@ -132,7 +314,8 @@ namespace Lum {
     size_t           w2;
     size_t           w3;
     size_t           w4;
-    Menu*            menuWindow;
+    Menu             *menuWindow;
+    OS::Window       *parentWindow;
 
   protected:
     MenuEntry();
@@ -253,8 +436,8 @@ namespace Lum {
   class RadioItem : public MenuEntry
   {
   private:
-    Base::Reference<Model::SizeT> model;
-    size_t                        value;
+    Model::SizeTRef model;
+    size_t          value;
 
   public:
     RadioItem();
