@@ -350,11 +350,6 @@ namespace Lum {
         Notify();
       }
     };
-
-    /*
-    template<class N>
-    typedef Base::Reference<StdListTable<N> > StdListTableRef<N>;
-      */
   }
 }
 
