@@ -32,7 +32,7 @@ namespace Lum {
   namespace OS {
     namespace Base {
 
-      class LUMAPI Display : public ::Lum::OS::Display
+      class LUMAPI Display : public Lum::OS::Display
       {
       protected:
         Type                             type;
@@ -47,7 +47,6 @@ namespace Lum {
         size_t                           workAreaHeight;
 
         unsigned long                    multiClickTime;
-        std::list<Timer>                 timerList;
 
         std::wstring                     appName;
         std::wstring                     programName;
@@ -68,10 +67,7 @@ namespace Lum {
         size_t                           fixedFontSize;
         FontRef                          fixedFont;
 
-        TryMutex                         asyncMutex;
-        std::list<Model::ActionRef>      asyncActions;
-
-        std::list<Model::ActionRef>      eventLoopActions;
+        OS::EventLoop                    *eventLoop;
 
         KeyboardHandler                  *keyboardHandler;
 
@@ -86,9 +82,6 @@ namespace Lum {
 
         void EvaluateDisplaySize();
 
-        void HandleAsyncActions();
-        void HandleEventLoopActions();
-
         virtual FontRef GetFontInternal(FontType type, size_t size) const;
 
         bool GetFontFromCache(FontType type, size_t size, FontRef& font) const;
@@ -145,8 +138,10 @@ namespace Lum {
         Frame* GetFrame(FrameIndex frame) const;
         Image* GetImage(ImageIndex image) const;
 
-        // Event Looop
-        void SignalEventLoop();
+        // Event Loop
+        EventLoop* GetEventLoop() const;
+        void MainLoop();
+        void Exit();
         void QueueActionForAsyncNotification(Model::Action *action);
         void QueueActionForEventLoop(Model::Action *action);
 
@@ -158,8 +153,6 @@ namespace Lum {
         // Timer
         void AddTimer(long seconds, long microseconds, Model::Action* action);
         void RemoveTimer(Model::Action* action);
-        void CheckTimers();
-        bool GetNextTimer(::Lum::Base::SystemTime& interval);
 
         // Key-String-Mapping
         void KeyToKeyDescription(unsigned long qualifier,
