@@ -49,9 +49,11 @@ namespace Lum {
         Model::ActionRef     preInitAction;    //! Triggered before the window initially opens
         Model::ActionRef     eventAction;      //! Triggered for every low-level event
         Model::ActionRef     grabCancelAction; //! Triggered if a sub window opens and cancels our current mouse grab
+        Model::ActionRef     menuAction;       //! Triggered if the windo should show its window (embedded app context)
 
         std::wstring         title;            //! Title of window
         bool                 open;             //! Window is open
+        bool                 inEventLoop;      //! True, if window is in event loop
         bool                 shown;            //! Window has been redrawn after open
         bool                 focus;            //! Windows has focus
         bool                 activateOnOpen;   //! Actrivate windows afte rit opens
@@ -67,6 +69,8 @@ namespace Lum {
         OS::DrawInfo         *backgroundDraw;
         OS::Bitmap           *backgroundBitmap;
         OS::Window::Type     type;
+        bool                 grabMouse;
+        bool                 grabKeyboard;
 
       public:
         Window();
@@ -124,6 +128,7 @@ namespace Lum {
         Model::Action* GetPreInitAction() const;
         Model::Action* GetEventAction() const;
         Model::Action* GetGrabCancelAction() const;
+        Model::Action* GetMenuAction() const;
 
         OS::Window* GetTopWindow();
 
@@ -135,6 +140,9 @@ namespace Lum {
         void Close();
         bool IsShown() const;
 
+        void EventLoop();
+        bool IsInEventLoop() const;
+        void Exit();
         bool HandleEvent(Event* event);
         void Enable();
         void Disable();
@@ -144,6 +152,10 @@ namespace Lum {
 
         void Resize(size_t width, size_t height);
 
+        // action
+        void GrabMouse(bool grab);
+        void GrabKeyboard(bool grab);
+
         void AcquireKeyboardInput();
         void ReleaseKeyboardInput();
 
@@ -166,11 +178,17 @@ namespace Lum {
         void TriggerResize(size_t width, size_t height);
         void TriggerRedraw(int x, int y, size_t width, size_t height);
         void TriggerGrabCancel();
+        void TriggerMenu();
 
         bool SendBalloonMessage(const std::wstring& text,
                                 unsigned long timeout);
 
       protected:
+        virtual void MouseGrabOn();
+        virtual void MouseGrabOff();
+        virtual void KeyboardGrabOn();
+        virtual void KeyboardGrabOff();
+
         void CalculateWindowPos(bool& xManPos, bool& yManPos);
       };
     }
