@@ -93,15 +93,12 @@ namespace Lum {
         void ClearClipboard();
         bool HasClipboard() const;
 
-        void PutBackEvent(OS::Event* event, OS::Window* destWin);
-        void Exit();
         void ReinitWindows();
         void Close();
-        //void Receive(Lum::Base::Object::Message message);
-        void EventLoop();
 
         bool GetMousePos(int& x, int& y) const;
 
+        void GetEvent();
       private:
         void StopContextHelp();
         void RestartContextHelp();
@@ -111,8 +108,6 @@ namespace Lum {
         void RemoveWindow(Window* w);
 
         void CheckSleeps();
-        void GetEvent();
-        bool Wait();
       };
     }
   }
