@@ -33,6 +33,7 @@
 
 #include <Lum/OS/Color.h>
 #include <Lum/OS/Event.h>
+#include <Lum/OS/EventLoop.h>
 #include <Lum/OS/Fill.h>
 #include <Lum/OS/Font.h>
 #include <Lum/OS/Frame.h>
@@ -59,17 +60,6 @@ namespace Lum {
       static const size_t frameCount =  7; //! Number of predefined frames
       static const size_t imageCount = 31; //! Number of predefined images
 
-    protected:
-      class LUMAPI Timer
-      {
-      public:
-        Lum::Base::SystemTime time;
-        Model::ActionRef      action;
-
-      public:
-        bool operator<(const Timer& other) const;
-      };
-
     public:
       enum ColorIndex {
         backgroundColor               =  0, // To be removed!
@@ -346,9 +336,8 @@ namespace Lum {
         Methods for dealing with the global event loop.
       */
       //@{
-      virtual void PutBackEvent(Event* event, Window* destWin) = 0;
-      virtual void EventLoop() = 0;
-      virtual void SignalEventLoop() = 0;
+      virtual EventLoop* GetEventLoop() const = 0;
+      virtual void MainLoop() = 0;
       virtual void Exit() = 0;
       virtual void QueueActionForAsyncNotification(Model::Action *action) = 0;
       virtual void QueueActionForEventLoop(Model::Action *action) = 0;
@@ -409,12 +398,6 @@ namespace Lum {
       //@{
       virtual void AddTimer(long seconds, long microseconds, Model::Action* action) = 0;
       virtual void RemoveTimer(Model::Action* action) = 0;
-
-      /**
-        Check the list of registered timeouts and send a message for every elapsed
-        timeout.
-       */
-      virtual void CheckTimers() = 0;
       //@}
 
       /*
