@@ -57,6 +57,12 @@ namespace Lum {
         toolbarBottom
       };
 
+      enum MenuType {
+        menuTypeStrip,
+        menuTypeTopPopup,
+        menuTypeActionPopup
+      };
+
     public:
       Theme(Display *display);
       virtual ~Theme();
@@ -143,6 +149,7 @@ namespace Lum {
       virtual ScrollKnobMode GetScrollKnobMode() const = 0;
       virtual ToolbarPosition GetToolbarPosition() const = 0;
       virtual bool ShowButtonImages() const = 0;
+      virtual MenuType GetMenuType() const = 0;
       //@}
     };
   }
