@@ -52,7 +52,6 @@ namespace Lum {
         std::list<Tray*>     trayList;
         std::list<Window*>   winList;
         Lum::Base::DnDObject *selectObject;
-        bool                 exit;
 
       public:
         HINSTANCE            instance;
@@ -85,14 +84,9 @@ namespace Lum {
 
         bool GetMousePos(int& x, int& y) const;
 
-        void PutBackEvent(OS::Event* event,
-                          OS::Window* destWin);
-
         void ReinitWindows();
 
         bool Open();
-        void EventLoop();
-        void Exit();
         void Close();
 
         void AddWindow(Window* w);
