@@ -80,8 +80,8 @@ namespace Lum {
       };
 
     public:
-      virtual void SetMaster(::Lum::Base::MsgObject* master) = 0;
-      virtual ::Lum::Base::MsgObject* GetMaster() const = 0;
+      virtual void SetMaster(Lum::Base::MsgObject* master) = 0;
+      virtual Lum::Base::MsgObject* GetMaster() const = 0;
 
       /**
         @name Window type
@@ -154,6 +154,7 @@ namespace Lum {
       virtual Model::Action* GetPreInitAction() const = 0;
       virtual Model::Action* GetEventAction() const = 0;
       virtual Model::Action* GetGrabCancelAction() const =0;
+      virtual Model::Action* GetMenuAction() const =0;
       //@}
 
       /**
@@ -225,7 +226,8 @@ namespace Lum {
 
       virtual void Resize(size_t width, size_t height) = 0;
 
-      virtual void Grab(bool grab) = 0;
+      virtual void GrabMouse(bool grab) = 0;
+      virtual void GrabKeyboard(bool grab) = 0;
 
       virtual bool SendBalloonMessage(const std::wstring& text,
                                       unsigned long timeout) = 0;
