@@ -34,13 +34,11 @@
 #include <X11/SM/SMlib.h>
 #endif
 
-#if defined(HAVE_LIB_DBUS)
-#define DBUS_API_SUBJECT_TO_CHANGE 1
-#include <dbus/dbus.h>
-#endif
-
-#ifdef HAVE_LIB_GSTREAMER
-#include <gst/gst.h>
+#if defined(HAVE_LIB_OSSO)
+  #include <libosso.h>
+  #include <dbus/dbus.h>
+#elif defined(HAVE_LIB_DBUS)
+  #include <dbus/dbus.h>
 #endif
 
 #include <Lum/OS/Base/Display.h>
@@ -55,13 +53,7 @@ namespace Lum {
     namespace X11 {
 
       /*
-      class SleepDesc; // module private
-      class ChannelDesc; // module private
       class PatternDesc; // module private
-
-      typedef SleepDesc *Sleep; // module private
-      typedef ChannelDesc *Channel; // module private
-
       */
 
       class Tray;
@@ -110,53 +102,22 @@ namespace Lum {
           netWMWindowTypeNormalAtom  = 31,
           netWMPingAtom              = 32,
           netWMPIDAtom               = 33,
-	  netWMStateAtom             = 34,
-	  netWMStateFullScreenAtom   = 35,
-          netSystemTrayOpcodeAtom    = 36,
-          netSystemTrayMsgDataAtom   = 37,
-          netWorkAreaAtom            = 38,
-          utf8StringAtom             = 39,
-          xEmbedAtom                 = 40,
-          xEmbedInfoAtom             = 41,
-          cardinalAtom               = 42,
-          windowAtom                 = 43,
-          targetsAtom                = 44,
+          netWMStateAtom             = 34,
+          netWMStateFullScreenAtom   = 35,
+          netWMContextCustomAtom     = 36,
+          netSystemTrayOpcodeAtom    = 37,
+          netSystemTrayMsgDataAtom   = 38,
+          netWorkAreaAtom            = 39,
+          utf8StringAtom             = 40,
+          xEmbedAtom                 = 41,
+          xEmbedInfoAtom             = 42,
+          cardinalAtom               = 43,
+          windowAtom                 = 44,
+          targetsAtom                = 45,
 
-          atomCount                  = 45
+          atomCount                  = 46
         };
 
-#if defined(HAVE_LIB_DBUS)
-        class DBusWatchEntry
-        {
-        public:
-          DBusWatch *watch;
-        };
-
-        class DBusTimeoutEntry
-        {
-        public:
-          DBusTimeout *timeout;
-        };
-#endif
-
-#if defined(HAVE_LIB_GSTREAMER)
-      public:
-        class GstMsg : public ::Lum::Base::ResyncMsg
-        {
-        public:
-          GstMessage *message;
-        };
-
-      private:
-        class GstListener
-        {
-        public:
-          bool                  async;
-          GstElement            *element;
-          Lum::Model::ActionRef action;
-        };
-
-#endif
       public:
         Atom atoms[atomCount];
 
@@ -180,19 +141,12 @@ namespace Lum {
         //::Lum::OS::Display::Timer contextTimer;
         bool                      contextHelp;
 
-        //Sleep sleepList;
-        //Channel channelList;
-
         Window*                   dropWindow;
 
         std::wstring              clipboard;
 
         double                    dpi;
 
-        bool                      exit;
-
-        int                       signalPipe[2];
-
 #if defined(HAVE_LIBSM)
         SmcConn                   smSession;
         IceConn                   iceSession;
@@ -214,20 +168,19 @@ namespace Lum {
         Visual                    *visual;
         Colormap                  colorMap;
         XIM                       xim;
-#if defined(HAVE_LIB_DBUS)
+
+#if defined(HAVE_LIB_OSSO)
+        osso_context_t            *ossoContext;
+#endif
+
+#if defined(HAVE_LIB_DBUS) || defined(HAVE_LIB_OSSO)
         DBusConnection            *dbusSession;
         DBusConnection            *dbusSystem;
-        std::list<DBusWatchEntry>   dbusWatches;
-        std::list<DBusTimeoutEntry> dbusTimeouts;
-#endif
-#if defined(HAVE_LIB_GSTREAMER)
-        bool                      gstSyncSet;
-        ::Lum::OS::Mutex          gstMutex;
-        std::list<GstMessage*>    gstMessages;
-        std::list<GstListener>    gstListener;
 #endif
+
       public:
         Display();
+        ~Display();
 
         double GetDPI() const;
 
@@ -241,10 +194,6 @@ namespace Lum {
         bool AllocateNamedColor(const std::string& name,
                                 OS::Color& color);
         void FreeColor(OS::Color color);
-        //Sleep AddSleep(::Lum::OS::Object::MsgObject object);
-        //void RemoveSleep(::Lum::Base::Display::Sleep sleep);
-        //Channel AddChannel(Channel channel, unsigned long ops, ::Lum::Base::Object::MsgObject object);
-        //void RemoveChannel(::Lum::OS::Display::Channel channel);
 
         bool Open();
         void Close();
@@ -261,12 +210,6 @@ namespace Lum {
 
         void ReinitWindows();
 
-        //void Receive(::Lum::Base::Object::Message message);
-        void PutBackEvent(OS::Event* event, OS::Window* destWin);
-        void EventLoop();
-        void SignalEventLoop();
-        void Exit();
-
         bool GetMousePos(int& x, int& y) const;
 
 #if defined(HAVE_LIBSM)
@@ -281,15 +224,12 @@ namespace Lum {
         void CallbackICEIOError(IceConn connection);
 #endif
 
-#if defined(HAVE_LIB_DBUS)
-        DBusConnection *InitiateDBusConnection(DBusBusType busType);
+#if defined(HAVE_LIB_OSSO)
+        osso_context_t* InitializeLibOsso();
+#elif defined(HAVE_LIB_DBUS)
+        DBusConnection* InitiateDBusConnection(DBusBusType busType);
 #endif
 
-#if defined(HAVE_LIB_GSTREAMER)
-        void AddGstListener(GstElement* element, ::Lum::Model::Action* action, bool async=true);
-        void RemoveGstListener(Model::Action* action);
-        void HandleGstMessage(GstMessage *message);
-#endif
       private:
         void EnlargeUCS2Buffer(int len);
 
@@ -319,12 +259,10 @@ namespace Lum {
         void HandleXSelectionRequest(const XSelectionRequestEvent& event);
 
         void Flush();
-        void CheckSleeps();
-        void GetEvent();
-        bool Wait();
 
       public:
         bool WaitTimedForX11Event(::Window window, int eventType, XEvent& event) const;
+        void GetEvent();
       };
     }
   }
