@@ -47,33 +47,35 @@ namespace Lum {
           styleToolbar      =  6,
           styleToolButton   =  7,
           styleEdit         =  8,
-          styleProgress     =  9,
-          styleHKnob        = 10,
-          styleVKnob        = 11,
-          styleCheck        = 12,
-          styleRadio        = 13,
-          styleRadio2       = 14,
-          styleTab          = 15,
-          styleList         = 16,
-          styleComboBox     = 17,
-          styleEditComboBox = 18,
-          styleHLine        = 19,
-          styleVLine        = 20,
-          styleHScale       = 21,
-          styleVScale       = 22,
-          styleStatus       = 23,
-          styleScrolled     = 24,
-          styleLabel        = 25,
-          styleButtonBox    = 26,
-          stylePane         = 27,
-          styleDummy        = 28,
+          styleProgressH    =  9,
+          styleProgressV    = 10,
+          styleHKnob        = 11,
+          styleVKnob        = 12,
+          styleCheck        = 13,
+          styleRadio        = 14,
+          styleRadio2       = 15,
+          styleTab          = 16,
+          styleList         = 17,
+          styleComboBox     = 18,
+          styleEditComboBox = 19,
+          styleHLine        = 20,
+          styleVLine        = 21,
+          styleHScale       = 22,
+          styleVScale       = 23,
+          styleStatus       = 24,
+          styleScrolled     = 25,
+          styleLabel        = 26,
+          styleButtonBox    = 27,
+          stylePane         = 28,
+          styleDummy        = 29,
 
-          styleMenuBar      = 29,
-          styleMenuPullDown = 30,
-          styleMenu         = 31,
-          styleMenuItem     = 32,
+          styleMenuBar      = 30,
+          styleMenuPullDown = 31,
+          styleMenu         = 32,
+          styleMenuItem     = 33,
+          stylePopup        = 34,
 
-          styleMax          = 33
+          styleMax          = 35
         };
 
       public:
@@ -191,6 +193,7 @@ namespace Lum {
         ScrollKnobMode GetScrollKnobMode() const;
         ToolbarPosition GetToolbarPosition() const;
         bool ShowButtonImages() const;
+        MenuType GetMenuType() const;
       };
 
     }
