@@ -98,6 +98,33 @@ namespace Lum {
   */
   class LUMAPI Object : public Base::DnDObject
   {
+  public:
+    enum Constraint
+    {
+      constraintMinWidth,
+      constraintMinHeight,
+      constraintWidth,
+      constraintHeight,
+      constraintMaxWidth,
+      constraintMaxHeight
+    };
+
+  private:
+    class ConstraintSize
+    {
+    public:
+      Constraint constraint;
+      Base::Size size;
+
+    public:
+      ConstraintSize(Constraint constraint, const Base::Size& size)
+      : constraint(constraint),
+        size(size)
+      {
+        // no code
+      }
+    };
+
   protected:
     Object              *parent;        //! The parent object, may be NULL for top level objects.
 
@@ -131,16 +158,6 @@ namespace Lum {
     size_t              oMaxHeight;
     //@}
 
-    /**
-      @name Initial dimensions.
-      The initial dimension of the object.
-    */
-    //@{
-    Base::Size          setWidth,setHeight,
-                        setMinWidth,setMinHeight,
-                        setMaxWidth,setMaxHeight;
-    //@}
-
     /**
       @name Look.
       Common variables that define the look of the widget.
@@ -171,6 +188,14 @@ namespace Lum {
     bool                mouseActive;   //! Is currently activated by mouse
     bool                redrawOnMouseActive; //! If set (default) redraw object if it gets mouse active
 
+    /**
+      @name Initial dimensions.
+      The initial dimension of the object.
+    */
+    //@{
+    std::list<ConstraintSize> constraints;
+    //@}
+
   public:
     bool                inited;        //! Has been initialized
     bool                shortcutAlways;
@@ -254,19 +279,38 @@ namespace Lum {
       Methods setting the minimal, current and maximum sizeof the object.
     */
     //@{
-    virtual void SetWidth(Base::Size::Mode mode, size_t value);
-    virtual void SetHeight(Base::Size::Mode mode, size_t value);
-    virtual void SetMinWidth(Base::Size::Mode mode, size_t value);
-    virtual void SetMinHeight(Base::Size::Mode mode, size_t value);
-    virtual void SetMaxWidth(Base::Size::Mode mode, size_t value);
-    virtual void SetMaxHeight(Base::Size::Mode mode, size_t value);
+    virtual Object& SetConstraint(Constraint constraint,
+                                  Base::Size::Mode mode,
+                                  size_t value,
+                                  const OS::FontRef& font=::Lum::OS::FontRef());
+
+    virtual Object& SetWidth(Base::Size::Mode mode,
+                             size_t value,
+                             const OS::FontRef& font=::Lum::OS::FontRef());
+    virtual Object& SetHeight(Base::Size::Mode mode,
+                              size_t value,
+                              const OS::FontRef& font=::Lum::OS::FontRef());
+
+    virtual Object& SetMinWidth(Base::Size::Mode mode,
+                                size_t value,
+                                const OS::FontRef& font=::Lum::OS::FontRef());
+    virtual Object& SetMinHeight(Base::Size::Mode mode,
+                                 size_t value,
+                                 const OS::FontRef& font=::Lum::OS::FontRef());
+
+    virtual Object& SetMaxWidth(Base::Size::Mode mode,
+                                size_t value,
+                                const OS::FontRef& font=::Lum::OS::FontRef());
+    virtual Object& SetMaxHeight(Base::Size::Mode mode,
+                                 size_t value,
+                                 const OS::FontRef& font=::Lum::OS::FontRef());
     //@}
 
     /**
       @name Methods for manipulation object resize behaviour
     */
     //@{
-    virtual void SetFlex(bool horizontal, bool vertical);
+    virtual Object& SetFlex(bool horizontal, bool vertical);
     virtual bool HorizontalFlex() const;
     virtual bool VerticalFlex() const;
 
@@ -504,7 +548,7 @@ namespace Lum {
   class LUMAPI Component : public Object
   {
   protected:
-    Group *container;
+    Object *container;
 
   public:
     Component();
@@ -515,6 +559,8 @@ namespace Lum {
     bool HasBaseline() const;
     size_t GetBaseline() const;
 
+    void CalcSize();
+
     void Layout();
     void Draw(int x, int y, size_t w, size_t h);
     void Hide();
@@ -527,7 +573,7 @@ namespace Lum {
   class LUMAPI ControlComponent : public Control
   {
   protected:
-    Group *container;
+    Object *container;
 
   public:
     ControlComponent();
@@ -538,6 +584,8 @@ namespace Lum {
     bool HasBaseline() const;
     size_t GetBaseline() const;
 
+    void CalcSize();
+
     void Layout();
     void Draw(int x, int y, size_t w, size_t h);
     void Hide();
