@@ -29,14 +29,6 @@ namespace Lum {
 
   class LUMAPI Placeholder : public Object
   {
-  public:
-    class Prefs : public Object::Prefs
-    {
-    public:
-      Prefs(const std::wstring& name);
-      void Initialize();
-    };
-
   public:
     Placeholder();
 
