@@ -27,7 +27,7 @@
 
 namespace Lum {
 
-  class LUMAPI PopupControl : public Control
+  class LUMAPI PopupControl : public ControlComponent
   {
   protected:
     Control          *control;
@@ -47,8 +47,6 @@ namespace Lum {
     Base::Model* GetModel() const;
 
     void CalcSize();
-    void Layout();
-    void Draw(int x, int y, size_t w, size_t h);
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
   };
