@@ -25,7 +25,9 @@
 
 #include <Lum/OS/Display.h>
 
+#include <Lum/Button.h>
 #include <Lum/Object.h>
+#include <Lum/Popup.h>
 
 namespace Lum {
 
@@ -73,6 +75,29 @@ namespace Lum {
     };
 
   public:
+    class InputHelper : public Popup
+    {
+    private:
+      std::map<Model::ActionRef,std::wstring> strings;
+
+      protected:
+      Model::ActionRef                        backAction;
+      String                                  *string;
+
+    protected:
+      void RegisterKey(Model::Action* action, const std::wstring& string);
+
+    public:
+      InputHelper();
+      bool Open(String *string);
+      void Close();
+
+      Button* CreateTextButton(const std::wstring& label, const std::wstring& text);
+      Button* CreateTextButton(const std::wstring& label, Model::Action* action);
+
+      void Resync(Base::Model* model, const Base::ResyncMsg& msg);
+    };
+
     class Controller : public ::Lum::Controller
     {
     public:
@@ -113,6 +138,8 @@ namespace Lum {
     Model::ActionRef focusInAction;
     Model::ActionRef focusOutAction;
 
+    InputHelper      *inputHelper;
+
   private:
     size_t GetCursorPos(int x) const;
     bool Selected() const;
@@ -134,6 +161,8 @@ namespace Lum {
 
     void EvaluateMarkAllActionRights();
 
+    void OpenInputHelper();
+
   public:
     String();
     ~String();
@@ -144,6 +173,8 @@ namespace Lum {
     // Setter
     bool SetModel(Base::Model* model);
 
+    void SetInputHelper(InputHelper *inputHelper);
+
     void SetCursorUpAction(Model::Action* action);
     void SetCursorDownAction(Model::Action* action);
     void SetReturnAction(Model::Action* action);
@@ -211,6 +242,30 @@ namespace Lum {
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
   };
+
+  class LUMAPI InputHelperNumber : public String::InputHelper
+  {
+  public:
+    enum Type {
+      typeBin,
+      typeOct,
+      typePosDec,
+      typeDec,
+      typeHex,
+      typePosFloat,
+      typeFloat
+    };
+
+  private:
+    Type                          type;
+    Model::ActionRef              colonAction;
+    std::vector<Model::ActionRef> digitActions;
+
+  public:
+    InputHelperNumber(Type type);
+
+    void PreInit();
+  };
 }
 
 #endif
