@@ -92,8 +92,11 @@ namespace Lum {
     size_t                scrolling;           //! The scrolling delta, if scrolling is active
     bool                  scrollRefresh;
     Model::ActionRef      scrollTimerAction;   //! Timer for scrolling updates
-    int                   cx;                  //! x position of mouse on press
-    int                   cy;                  //! y position of mouse on press
+    int                   px;                  //! x position of mouse on press
+    int                   py;                  //! y position of mouse on press
+    size_t                ppos;                //! top line on mouse press
+    int                   my;                  //! y position of mouse on last move
+    int                   sy;                  //! y position of mouse on the last timer event
     Lum::Base::SystemTime mouseTimer;          //! Count time between mouse move events
     Model::ActionRef      mouseTimerAction;    //! Timer for mouse press and hold detection
 
@@ -153,7 +156,10 @@ namespace Lum {
 
     void Layout();
 
+    OS::Color GetTextColor(OS::DrawInfo *draw) const;
+
     void Draw(int x, int y, size_t w, size_t h);
+    void Hide();
     void DrawFocus();
     void HideFocus();
 
