@@ -22,7 +22,7 @@
 
 #include <Lum/Model/Action.h>
 
-#include <Lum/Dialog.h>
+#include <Lum/Popup.h>
 #include <Lum/PopupControl.h>
 
 namespace Lum {
@@ -31,7 +31,7 @@ namespace Lum {
   class LUMAPI TimeSelect : public PopupControl
   {
   private:
-    class Popup : public Dialog
+    class TimeSelectPopup : public Popup
     {
     public:
       Base::TimeFormat format;
@@ -39,8 +39,7 @@ namespace Lum {
       Model::ActionRef commit;
 
     public:
-      Popup(TimeSelect *combo, Base::TimeFormat format);
-      ~Popup();
+      TimeSelectPopup(TimeSelect *combo, Base::TimeFormat format);
 
       void PreInit();
 
