@@ -20,6 +20,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
+#include <Lum/Model/Action.h>
+
 #include <Lum/Object.h>
 #include <Lum/Scroller.h>
 
@@ -27,21 +29,15 @@ namespace Lum {
 
   class LUMAPI View : public Group
   {
-  public:
-    class Prefs : public Group::Prefs
-    {
-    public:
-      Prefs(const std::wstring& name);
-      void Initialize();
-    };
-
   private:
-    Scrollable *object;
-    Scroller   *hScroller;
-    Scroller   *vScroller;
+    Scrollable       *object;
+    Scroller         *hScroller;
+    Scroller         *vScroller;
 
-    bool       hVisible;
-    bool       vVisible;
+    bool             hVisible;
+    bool             vVisible;
+
+    Model::ActionRef refreshAction;
 
   public:
     View();
