@@ -24,17 +24,20 @@
 #include <Lum/Label.h>
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
+#include <Lum/Tab.h>
 #include <Lum/Text.h>
 
 namespace Lum {
 
   About::About()
+   : illuminationAction(new Model::Action())
   {
-    // no code
+    Observe(illuminationAction);
   }
 
   About::~About()
   {
+    // no code
   }
 
   void About::SetAppInfo(const AppInfo& info)
@@ -45,30 +48,30 @@ namespace Lum {
   void About::CalcSize()
   {
     Label *label;
-    Panel *vPanel;
+    Panel *vPanel,*topPanel;
+    Tab   *tab;
     Text  *text;
 
+    tab=new Tab();
+
     vPanel=new VPanel();
-    vPanel->SetParent(this);
 
     text=new Text(info.GetProgram()+L" "+info.GetVersion(),
                   OS::Font::normal,
                   Text::centered,
                   OS::display->GetFont(OS::Display::fontTypeProportional,
-                                       OS::Display::fontScaleLogo));
+                                       OS::Display::fontScaleCaption1));
     text->SetFlex(true,false);
     vPanel->Add(text);
 
     vPanel->Add(new VSpace());
 
     text=new Text(info.GetDescription(),
-                  OS::Font::italic|OS::Font::bold,Text::centered,
-                  OS::display->GetFont(OS::Display::fontTypeProportional,
-                                       OS::Display::fontScaleCaption1));
+                  OS::Font::italic|OS::Font::bold,Text::centered);
     text->SetFlex(true,false);
     vPanel->Add(text);
 
-    vPanel->Add(new VSpace(Space::sizeHuge));
+    vPanel->Add(new VSpace());
 
     label=new Label();
     label->SetFlex(true,false);
@@ -77,12 +80,11 @@ namespace Lum {
     label->AddLabel(_l(L"ABOUT_COPYRIGHT",L"Copyright:"),new Text(info.GetCopyright()));
     label->AddLabel(_l(L"ABOUT_LICENCE",L"License:"),new Text(info.GetLicense()));
     vPanel->Add(label);
+    tab->Add(_l(L"ABOUT_TAB_ABOUT",L"About"),vPanel);
 
-    vPanel->Add(new VSpace(Space::sizeHuge));
+    vPanel=new VPanel();
 
     text=new Text();
-    text->SetFont(OS::display->GetFont(OS::Display::fontTypeProportional,
-                                       OS::Display::fontScaleFootnote));
     text->SetAlignment(Text::centered);
     text->AddText(_l(L"ABOUT_SLOGAN",
                      L"This program was written using Illumination,\n"
@@ -90,18 +92,14 @@ namespace Lum {
                      L"Visit http://illumination.sourceforge.net\n"
                      L"for more information!"));
     vPanel->Add(text);
+    tab->Add(_l(L"ABOUT_TAB_ILLUMINATION",L"Illumination"),vPanel);
 
-    container=vPanel;
+    topPanel=new VPanel();
+    topPanel->Add(tab);
 
-    container->CalcSize();
+    container=topPanel;
 
-    minWidth=container->GetOMinWidth();
-    minHeight=container->GetOMinHeight();
-
-    width=container->GetOWidth();
-    height=container->GetOHeight();
-
-    Object::CalcSize();
+    Component::CalcSize();
   }
 }
 
