@@ -23,11 +23,9 @@
 
 namespace Lum {
 
-  static ImageState::Prefs *prefs=new ::Lum::ImageState::Prefs(L"Boolean");
-
   Boolean::Boolean()
    : ImageState(OS::Theme::objCheck)
   {
-    SetPrefs(::Lum::prefs);
+    // no code
   }
 }
