@@ -20,6 +20,7 @@
 #include <Lum/Button.h>
 
 #include <Lum/Base/DateTime.h>
+#include <Lum/Base/L10N.h>
 
 #include <Lum/OS/Theme.h>
 
@@ -501,4 +502,51 @@ namespace Lum {
 
     Control::Resync(model,msg);
   }
+
+  Button* Button::CreateOk(Model::Action* action)
+  {
+    Button *button;
+
+    button=new Button();
+    button->SetType(Button::typeCommit);
+    button->SetText(_ld(dlgButtonOk));
+    button->SetModel(action);
+
+    return button;
+  }
+
+  Button* Button::CreateCancel(Model::Action* action)
+  {
+    Button *button;
+
+    button=new Button();
+    button->SetType(Button::typeCancel);
+    button->SetText(_ld(dlgButtonCancel));
+    button->SetModel(action);
+
+    return button;
+  }
+
+  Button* Button::CreateClose(Model::Action* action)
+  {
+    Button *button;
+
+    button=new Button();
+    button->SetType(Button::typeCommit);
+    button->SetText(_ld(dlgButtonClose));
+    button->SetModel(action);
+
+    return button;
+  }
+
+  Button* Button::CreateHelp(Model::Action* action)
+  {
+    Button *button;
+
+    button=new Button();
+    button->SetText(_ld(dlgButtonHelp));
+    button->SetModel(action);
+
+    return button;
+  }
 }
