@@ -21,8 +21,12 @@
 
 #include <algorithm>
 
+#include <Lum/Base/L10N.h>
+
 #include <Lum/OS/Theme.h>
 
+#include <Lum/Button.h>
+
 namespace Lum {
 
   ButtonRow::ButtonRow()
@@ -191,4 +195,79 @@ namespace Lum {
 
     Group::Layout();
   }
+
+  ButtonRow* ButtonRow::CreateOk(Model::Action* ok)
+  {
+    assert(ok!=NULL);
+
+    ButtonRow *row;
+    Button    *button;
+
+    row=new ButtonRow();
+    row->SetFlex(true,false);
+
+    button=Button::CreateOk(ok);
+    button->SetFlex(true,true);
+    row->Add(button);
+
+    return row;
+  }
+
+  ButtonRow* ButtonRow::CreateCancel(Model::Action* cancel)
+  {
+    assert(cancel!=NULL);
+
+    ButtonRow *row;
+    Button    *button;
+
+    row=new ButtonRow();
+    row->SetFlex(true,false);
+
+    button=Button::CreateCancel(cancel);
+    button->SetFlex(true,true);
+    row->Add(button);
+
+    return row;
+  }
+
+
+  ButtonRow* ButtonRow::CreateOkCancel(Model::Action* ok,
+                                       Model::Action* cancel)
+  {
+    assert(ok!=NULL && cancel!=NULL);
+
+    ButtonRow *row;
+    Button    *button;
+
+    row=new ButtonRow();
+    row->SetFlex(true,false);
+
+    button=Button::CreateOk(ok);
+    button->SetFlex(true,true);
+    row->Add(button);
+
+    button=Button::CreateCancel(cancel);
+    button->SetFlex(true,true);
+    row->Add(button);
+
+    return row;
+  }
+
+  ButtonRow* ButtonRow::CreateClose(Model::Action* close)
+  {
+    assert(close!=NULL);
+
+    ButtonRow *row;
+    Button    *button;
+
+    row=new ButtonRow();
+    row->SetFlex(true,false);
+
+    button=Button::CreateClose(close);
+    button->SetFlex(true,true);
+    row->Add(button);
+
+    return row;
+  }
+
 }
