@@ -19,7 +19,6 @@
 
 #include <Lum/Combo.h>
 
-#include <Lum/PopupGroup.h>
 #include <Lum/Text.h>
 
 namespace Lum {
@@ -27,12 +26,12 @@ namespace Lum {
   Combo::Table::Table()
   : success(false)
   {
-    AttachModel(GetMouseSelectionAction());
+    Observe(GetMouseSelectionAction());
   }
 
   Combo::Table::~Table()
   {
-    UnattachModel(GetMouseSelectionAction());
+    // no code
   }
 
   void Combo::Table::Resync(Base::Model* model,
@@ -75,15 +74,12 @@ namespace Lum {
       value->SetBackground(NULL);
     }
 
-    AttachModel(prevAction);
-    AttachModel(nextAction);
+    Observe(prevAction);
+    Observe(nextAction);
   }
 
   Combo::~Combo()
   {
-    UnattachModel(nextAction);
-    UnattachModel(prevAction);
-
     delete value;
   }
 
@@ -135,11 +131,14 @@ namespace Lum {
   */
   void Combo::SetTableModel(Model::Table* model)
   {
-    Base::ResyncMsg msg;
+    if (tableModel.Valid()) {
+      Forget(tableModel);
+    }
 
     tableModel=model;
-    if (model!=NULL) {
-      Resync(model,msg);
+
+    if (tableModel.Valid()) {
+      Observe(tableModel);
     }
   }
 
@@ -187,7 +186,7 @@ namespace Lum {
       width=minWidth;
 
       minWidth+=value->GetOMinWidth();
-      minWidth+=value->GetOWidth();
+      width+=value->GetOWidth();
 
       minHeight=std::max(value->GetOMinHeight(),image->GetHeight());
       height=std::max(value->GetOHeight(),image->GetHeight());
@@ -207,55 +206,48 @@ namespace Lum {
     // no code
   }
 
-  Combo::Popup::Popup(Combo *combo)
+  Combo::ComboPopup::ComboPopup(Combo *combo)
   : combo(combo)
   {
-    AttachModel(GetOpenedAction());
+    Observe(GetOpenedAction());
   }
 
-  Combo::Popup::~Popup()
+  Combo::ComboPopup::~ComboPopup()
   {
-    UnattachModel(GetOpenedAction());
+    // no code
   }
 
-  void Combo::Popup::PreInit()
+  void Combo::ComboPopup::PreInit()
   {
-    PopupGroup *container;
-
-    container=new PopupGroup();
-    container->SetFlex(true,true);
-
     combo->table=new Lum::Table();
 
     combo->table->SetTableView(new Table());
     combo->table->SetFlex(true,true);
     combo->table->SetMinHeight(Base::Size::stdCharHeight,1);
-    combo->table->SetMaxWidth(Base::Size::screenVRel,40);
-    combo->table->SetMaxHeight(Base::Size::screenVRel,40);
+    combo->table->SetMaxWidth(Base::Size::workVRel,40);
+    combo->table->SetMaxHeight(Base::Size::workVRel,40);
     combo->table->SetModel(combo->tableModel);
     combo->table->SetSelection(combo->selection);
     if (combo->tableModel.Valid() && combo->tableModel->GetColumns()==1) {
       Model::HeaderRef headerModel=new Model::HeaderImpl();
-      headerModel->AddColumn(L"",Lum::Base::Size::modePixel,0);
+      headerModel->AddColumn(L"",Lum::Base::Size::pixel,0);
 
       combo->table->SetHeaderModel(headerModel);
       combo->table->GetTableView()->SetAutoFitColumns(true);
     }
     combo->table->GetTableView()->SetAutoHSize(true);
     combo->table->GetTableView()->SetAutoVSize(true);
-    dynamic_cast<Dialog*>(GetWindow()->GetMaster())->RegisterCommitShortcut(combo->table->GetTableView(),
-                                                                            combo->table->GetTableView()->GetMouseSelectionAction());
+    RegisterCommitShortcut(combo->table->GetTableView(),
+                           combo->table->GetTableView()->GetMouseSelectionAction());
 
     combo->InitTable(combo->table);
 
-    container->SetMain(combo->table);
+    SetMain(combo->table,true,false);
 
-    SetTop(container);
-
-    Dialog::PreInit();
+    Popup::PreInit();
   }
 
-  void Combo::Popup::Resync(Base::Model* model, const Base::ResyncMsg& msg)
+  void Combo::ComboPopup::Resync(Base::Model* model, const Base::ResyncMsg& msg)
   {
     if (model==GetOpenedAction() && GetOpenedAction()->IsFinished()) {
       if (combo->tableModel.Valid() && combo->selection->GetLine()>0) {
@@ -263,13 +255,12 @@ namespace Lum {
       }
     }
 
-    Dialog::Resync(model,msg);
+    Popup::Resync(model,msg);
   }
 
   void Combo::OpenPopup()
   {
-    popup=new Popup(this);
-    popup->SetType(OS::Window::typePopup);
+    popup=new ComboPopup(this);
     popup->SetParent(GetWindow());
     popup->SetReference(this);
 
@@ -537,6 +528,9 @@ namespace Lum {
           SetTableRow(1);
         }
       }
+      else if (model==tableModel && visible) {
+        Redraw();
+      }
     }
 
     Control::Resync(model,msg);
@@ -551,9 +545,7 @@ namespace Lum {
 
   TextCombo::~TextCombo()
   {
-    if (model.Valid()) {
-      UnattachModel(model);
-    }
+    // no code
   }
 
   bool TextCombo::SetModel(Base::Model* model)
@@ -624,9 +616,7 @@ namespace Lum {
 
   IndexCombo::~IndexCombo()
   {
-    if (model.Valid()) {
-      UnattachModel(model);
-    }
+    // no code
   }
 
   bool IndexCombo::SetModel(Base::Model* model)
@@ -704,9 +694,7 @@ namespace Lum {
 
   TextEditCombo::~TextEditCombo()
   {
-    if (model.Valid()) {
-      UnattachModel(model);
-    }
+    // no code
   }
 
   bool TextEditCombo::SetModel(Base::Model* model)
