@@ -39,10 +39,10 @@ namespace Lum {
 
     weekStart=1;
 
-    AttachModel(prevYear);
-    AttachModel(prevMonth);
-    AttachModel(nextMonth);
-    AttachModel(nextYear);
+    Observe(prevYear);
+    Observe(prevMonth);
+    Observe(nextMonth);
+    Observe(nextYear);
 
     prevYearButton=new Button();
     prevYearButton->SetFlex(true,true);
@@ -112,12 +112,6 @@ namespace Lum {
     delete prevMonthButton;
     delete nextMonthButton;
     delete nextYearButton;
-
-    UnattachModel(prevYear);
-    UnattachModel(prevMonth);
-    UnattachModel(nextMonth);
-    UnattachModel(nextYear);
-
   }
 
   void DatePicker::HandleDateChange()
