@@ -38,10 +38,6 @@ namespace Lum {
       delete objects[x];
     }
 
-    for (size_t x=0; x<models.size(); x++) {
-      UnattachModel(models[x]);
-    }
-
     delete templ;
   }
 
@@ -87,7 +83,7 @@ namespace Lum {
     for (size_t i=0; i<items.size(); i++) {
       if (!models[i].Valid()) {
         models[i]=new Model::Action();
-        AttachModel(models[i]);
+        Observe(models[i]);
       }
 
       if (objects[i]==NULL) {
