@@ -22,11 +22,9 @@
 #include <Lum/Base/L10N.h>
 
 #include <Lum/About.h>
-#include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
-#include <Lum/WindowGroup.h>
 
 namespace Lum {
   namespace Dlg {
@@ -45,10 +43,8 @@ namespace Lum {
     void About::PreInit()
     {
       Lum::About  *about;
-      Button      *button;
       ButtonRow   *row;
       Panel       *vPanel;
-      WindowGroup *wGroup;
 
       vPanel=new VPanel();
 
@@ -58,22 +54,11 @@ namespace Lum {
 
       vPanel->Add(new VSpace());
 
-      row=new ButtonRow();
+      row=ButtonRow::CreateOk(GetClosedAction());
       row->SetFlex(true,false);
-
-      button=new Button();
-      button->SetFlex(true,true);
-      button->SetText(_ld(dlgButtonOk));
-      button->SetType(Button::typeDefault);
-      button->SetModel(GetClosedAction());
-      row->Add(button);
-
       vPanel->Add(row);
 
-      wGroup=new WindowGroup();
-      wGroup->SetMain(vPanel);
-
-      SetTop(wGroup);
+      SetMain(vPanel);
 
       Dialog::PreInit();
     }
