@@ -21,13 +21,11 @@
 
 #include <Lum/Base/L10N.h>
 
-#include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/ColorView.h>
 #include <Lum/Panel.h>
 #include <Lum/RGBControl.h>
 #include <Lum/Space.h>
-#include <Lum/WindowGroup.h>
 
 namespace Lum {
   namespace Dlg {
@@ -35,27 +33,21 @@ namespace Lum {
     : color(color),
       okAction(new Lum::Model::Action)
     {
-      AttachModel(okAction);
-      AttachModel(GetClosedAction());
+      Observe(okAction);
+      Observe(GetClosedAction());
     }
 
     ColorChooser::~ColorChooser()
     {
-      UnattachModel(GetClosedAction());
-      UnattachModel(okAction);
+      // no code
     }
 
     void ColorChooser::PreInit()
     {
-      Button      *button;
       ButtonRow   *row;
       ColorView   *colorView;
       Panel       *vPanel,*hPanel;
       RGBControl  *rgb;
-      WindowGroup *wGroup;
-
-      wGroup=new Lum::WindowGroup();
-      wGroup->SetFlex(true,false);
 
       vPanel=new Lum::VPanel();
       vPanel->SetFlex(true,false);
@@ -78,28 +70,11 @@ namespace Lum {
 
       vPanel->Add(new VSpace());
 
-      row=new Lum::ButtonRow();
+      row=Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction());
       row->SetFlex(true,false);
-
-      button=new Lum::Button;
-      button->SetFlex(true,true);
-      button->SetModel(okAction);
-      button->SetText(_ld(dlgButtonOk));
-      button->SetType(Lum::Button::typeCommit);
-      row->Add(button);
-
-      button=new Lum::Button;
-      button->SetFlex(true,true);
-      button->SetModel(GetClosedAction());
-      button->SetText(_ld(dlgButtonCancel));
-      button->SetType(Lum::Button::typeCancel);
-      row->Add(button);
-
       vPanel->Add(row);
 
-      wGroup->SetMain(vPanel);
-
-      SetTop(wGroup);
+      SetMain(vPanel);
 
       Dialog::PreInit();
     }
