@@ -19,9 +19,9 @@
 #include <Lum/DirSelect.h>
 #include <Lum/Menu.h>
 #include <Lum/Panel.h>
+#include <Lum/Popup.h>
 #include <Lum/PopupGroup.h>
 #include <Lum/Space.h>
-#include <Lum/WindowGroup.h>
 
 namespace Lum {
   namespace Dlg {
@@ -46,7 +46,7 @@ namespace Lum {
       }
     };
 
-    class Locations : public Dialog
+    class Locations : public Popup
     {
     public:
       std::wstring                  result;
@@ -60,50 +60,38 @@ namespace Lum {
         selection(new Model::SingleLineSelection),
         roots(new Model::ListTable(1))
       {
-        AttachModel(table->GetTableView()->GetMouseSelectionAction());
-      }
-
-      ~Locations()
-      {
-        UnattachModel(table->GetTableView()->GetMouseSelectionAction());
+        Observe(table->GetTableView()->GetMouseSelectionAction());
       }
 
       void PreInit()
       {
-        PopupGroup *container;
-
         std::vector<Base::Path::PathDescription> list;
 
         Base::Path::GetStdPathes(list);
 
         Model::HeaderRef headerModel=new Model::HeaderImpl();
-        headerModel->AddColumn(L"",Lum::Base::Size::modePixel,0);
+        headerModel->AddColumn(L"",Lum::Base::Size::pixel,0);
 
         for (size_t x=0; x<list.size(); x++) {
           roots->Append(new RootsEntry(roots,list[x].description,list[x].path));
         }
 
-        container=new PopupGroup();
-        //container->SetFlex(true,true);
-
         table->SetFlex(true,true);
         table->SetMinHeight(Base::Size::stdCharHeight,1);
-        table->SetMaxWidth(Base::Size::screenVRel,40);
-        table->SetMaxHeight(Base::Size::screenVRel,40);
+        table->SetMaxWidth(Base::Size::workVRel,40);
+        table->SetMaxHeight(Base::Size::workVRel,40);
         table->SetHeaderModel(headerModel);
         table->SetSelection(selection);
         table->SetModel(roots);
         table->GetTableView()->SetAutoFitColumns(true);
         table->GetTableView()->SetAutoHSize(true);
         table->GetTableView()->SetAutoVSize(true);
-        dynamic_cast<Dialog*>(GetWindow()->GetMaster())->RegisterCommitShortcut(table->GetTableView(),
-                                                                                table->GetTableView()->GetMouseSelectionAction());
+        RegisterCommitShortcut(table->GetTableView(),
+                               table->GetTableView()->GetMouseSelectionAction());
 
-        container->SetMain(table);
+        SetMain(table);
 
-        SetTop(container);
-
-        Dialog::PreInit();
+        Popup::PreInit();
       }
 
       void Resync(Base::Model* model, const Base::ResyncMsg& msg)
@@ -115,7 +103,7 @@ namespace Lum {
           Exit();
         }
 
-        Dialog::Resync(model,msg);
+        Popup::Resync(model,msg);
       }
     };
 
@@ -213,36 +201,24 @@ namespace Lum {
       showHidden->Off();
       showHidden->Set(false);
 
-      AttachModel(GetOpenedAction());
-      AttachModel(GetClosedAction());
-      AttachModel(path);
-      AttachModel(full);
-      AttachModel(filter);
-      AttachModel(showHidden);
-      AttachModel(okAction);
-      AttachModel(reloadAction);
-      AttachModel(parentAction);
-      AttachModel(fullAction);
-      AttachModel(selectionAction);
-      AttachModel(doubleClickAction);
-      AttachModel(locationsAction);
+      Observe(GetOpenedAction());
+      Observe(GetClosedAction());
+      Observe(path);
+      Observe(full);
+      Observe(filter);
+      Observe(showHidden);
+      Observe(okAction);
+      Observe(reloadAction);
+      Observe(parentAction);
+      Observe(fullAction);
+      Observe(selectionAction);
+      Observe(doubleClickAction);
+      Observe(locationsAction);
     }
 
     File::~File()
     {
-      UnattachModel(locationsAction);
-      UnattachModel(doubleClickAction);
-      UnattachModel(selectionAction);
-      UnattachModel(fullAction);
-      UnattachModel(parentAction);
-      UnattachModel(reloadAction);
-      UnattachModel(okAction);
-      UnattachModel(showHidden);
-      UnattachModel(filter);
-      UnattachModel(full);
-      UnattachModel(path);
-      UnattachModel(GetClosedAction());
-      UnattachModel(GetOpenedAction());
+      // no code
     }
 
     void File::SetOptions(Options* options)
@@ -270,7 +246,6 @@ namespace Lum {
       Menu             *popup;
       Panel            *hPanel,*vPanel;
       Space            *space;
-      WindowGroup      *wGroup;
       Model::HeaderRef header;
 
       vPanel=new VPanel();
@@ -360,35 +335,18 @@ namespace Lum {
       vPanel->Add(hPanel);
       vPanel->Add(new VSpace());
 
-      row=new ButtonRow();
+      row=ButtonRow::CreateOkCancel(okAction,GetClosedAction());
       row->SetFlex(true,false);
-
-      button=new Button;
-      button->SetFlex(true,true);
-      button->SetModel(okAction);
-      button->SetText(_ld(dlgButtonOk));
-      button->SetType(Button::typeCommit);
-      row->Add(button);
-
-      button=new Button;
-      button->SetFlex(true,true);
-      button->SetModel(GetClosedAction());
-      button->SetText(_ld(dlgButtonCancel));
-      button->SetType(Button::typeCancel);
-      row->Add(button);
       vPanel->Add(row);
 
-      wGroup=new WindowGroup();
-      wGroup->SetFlex(true,true);
-      wGroup->SetMinHeight(Base::Size::screenVRel,40);
-
       if (OS::display->GetSize()<OS::Display::sizeNormal) {
-        wGroup->SetMinWidth(Base::Size::screenVRel,80);
+        vPanel->SetMinWidth(Base::Size::workVRel,80);
+      }
+      else {
+        vPanel->SetMinHeight(Base::Size::workVRel,60);
       }
 
-      wGroup->SetMain(vPanel);
-
-      SetTop(wGroup);
+      SetMain(vPanel);
 
       RegisterCommitShortcut(table->GetTableView(),okAction);
       RegisterShortcut(table->GetTableView(),0,L"BackSpace",parentAction);
@@ -646,7 +604,6 @@ namespace Lum {
         Locations *popup;
 
         popup=new Locations();
-        popup->SetType(OS::Window::typePopup);
         popup->SetParent(GetWindow());
         popup->SetReference(locations);
 
