@@ -25,7 +25,6 @@
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
 #include <Lum/Text.h>
-#include <Lum/WindowGroup.h>
 
 namespace Lum {
   namespace Dlg {
@@ -35,9 +34,7 @@ namespace Lum {
 
     Msg::~Msg()
     {
-      for (size_t x=0; x<list.size(); x++) {
-        UnattachModel(list[x].action);
-      }
+      // no code
     }
 
     void Msg::SetCaption(const std::wstring& caption)
@@ -58,7 +55,7 @@ namespace Lum {
       info.type=type;
       info.action=action;
 
-      AttachModel(action);
+      Observe(action);
 
       list.push_back(info);
     }
@@ -129,7 +126,6 @@ namespace Lum {
       ButtonRow   *row;
       Panel       *vPanel;
       Text        *text;
-      WindowGroup *wGroup;
 
       vPanel=new VPanel();
 
@@ -165,10 +161,7 @@ namespace Lum {
       }
       vPanel->Add(row);
 
-      wGroup=new WindowGroup();
-      wGroup->SetMain(vPanel);
-
-      SetTop(wGroup);
+      SetMain(vPanel);
 
       Dialog::PreInit();
     }
@@ -267,7 +260,6 @@ namespace Lum {
       msg=new Msg();
       msg->SetParent(parent);
       msg->SetTitle(L""/*caption*/);
-      msg->SetType(::Lum::OS::Window::typePopup);
       msg->SetPosition(::Lum::OS::Window::positionManual,::Lum::OS::Window::positionManual);
       msg->GetWindow()->SetPos(x,y);
       msg->SetCaption(caption);
