@@ -22,14 +22,12 @@
 #include <Lum/Base/L10N.h>
 
 #include <Lum/Boolean.h>
-#include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/Label.h>
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
 #include <Lum/String.h>
 #include <Lum/Text.h>
-#include <Lum/WindowGroup.h>
 
 namespace Lum {
   namespace Dlg {
@@ -39,14 +37,13 @@ namespace Lum {
       password(password),
       okAction(new Lum::Model::Action)
     {
-      AttachModel(okAction);
-      AttachModel(GetClosedAction());
+      Observe(okAction);
+      Observe(GetClosedAction());
     }
 
     Password::~Password()
     {
-      UnattachModel(GetClosedAction());
-      UnattachModel(okAction);
+      // no code
     }
 
     void Password::SetCaption(const std::wstring& caption)
@@ -74,16 +71,11 @@ namespace Lum {
     void Password::PreInit()
     {
       Boolean     *boolean;
-      Button      *button;
       ButtonRow   *row;
       Label       *label;
       Panel       *vPanel;
       String      *string;
       Text        *text;
-      WindowGroup *wGroup;
-
-      wGroup=new Lum::WindowGroup();
-      wGroup->SetFlex(true,false);
 
       vPanel=new Lum::VPanel;
       vPanel->SetFlex(true,false);
@@ -147,28 +139,11 @@ namespace Lum {
 
       vPanel->Add(new VSpace());
 
-      row=new Lum::ButtonRow();
+      row=Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction());
       row->SetFlex(true,false);
-
-      button=new Lum::Button;
-      button->SetFlex(true,true);
-      button->SetModel(okAction);
-      button->SetText(_ld(dlgButtonOk));
-      button->SetType(Lum::Button::typeCommit);
-      row->Add(button);
-
-      button=new Lum::Button;
-      button->SetFlex(true,true);
-      button->SetModel(GetClosedAction());
-      button->SetText(_ld(dlgButtonCancel));
-      button->SetType(Lum::Button::typeCancel);
-      row->Add(button);
-
       vPanel->Add(row);
 
-      wGroup->SetMain(vPanel);
-
-      SetTop(wGroup);
+      SetMain(vPanel);
 
       Dialog::PreInit();
     }
