@@ -19,15 +19,11 @@
 
 #include <Lum/Dlg/Values.h>
 
-#include <Lum/Base/L10N.h>
-
-#include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/Label.h>
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
 #include <Lum/Text.h>
-#include <Lum/WindowGroup.h>
 
 namespace Lum {
   namespace Dlg {
@@ -45,17 +41,14 @@ namespace Lum {
     {
       okAction->Disable();
 
-      AttachModel(okAction);
-      AttachModel(GetClosedAction());
+      Observe(okAction);
+      Observe(GetClosedAction());
     }
 
     ValuesInput::~ValuesInput()
     {
-      UnattachModel(GetClosedAction());
-      UnattachModel(okAction);
-
       for (std::list<Value>::iterator iter=values.begin(); iter!=values.end(); ++iter) {
-        UnattachModel(iter->model);
+        Forget(iter->model);
         iter->model->Pop();
         delete iter->validator;
       }
@@ -71,7 +64,7 @@ namespace Lum {
           value.control->SetModel(value.model.Get());
         }
 
-        AttachModel(value.model.Get());
+        Observe(value.model.Get());
       }
     }
 
@@ -97,17 +90,17 @@ namespace Lum {
       this->text=text;
     }
 
+    void ValuesInput::SetNote(const std::wstring& note)
+    {
+      this->note=note;
+    }
+
     void ValuesInput::PreInit()
     {
-      Button      *button;
       ButtonRow   *row;
       Label       *label;
       Panel       *vPanel;
       Text        *text;
-      WindowGroup *wGroup;
-
-      wGroup=new Lum::WindowGroup();
-      wGroup->SetFlex(true,false);
 
       vPanel=new Lum::VPanel;
       vPanel->SetFlex(true,false);
@@ -126,12 +119,22 @@ namespace Lum {
         vPanel->Add(new VSpace());
       }
 
-      text=new Lum::Text();
+      text=new Lum::Text(this->text);
       text->SetFlex(true,false);
-      text->SetText(this->text);
-
       vPanel->Add(text);
 
+      if (!note.empty()) {
+        vPanel->Add(new VSpace());
+
+        text=new Lum::Text(this->note,
+                           Lum::OS::Font::italic,
+                           Lum::Text::left,
+                           Lum::OS::display->GetFont(OS::Display::fontTypeProportional,
+                                                     Lum::OS::Display::fontScaleFootnote));
+        text->SetFlex(true,false);
+        vPanel->Add(text);
+      }
+
       vPanel->Add(new VSpace());
 
       if (values.size()==1 and values.begin()->label.empty()) {
@@ -149,28 +152,12 @@ namespace Lum {
 
       vPanel->Add(new VSpace());
 
-      row=new Lum::ButtonRow();
+      row=ButtonRow::CreateOkCancel(okAction,GetClosedAction());
       row->SetFlex(true,false);
 
-      button=new Lum::Button;
-      button->SetFlex(true,true);
-      button->SetModel(okAction);
-      button->SetText(_ld(dlgButtonOk));
-      button->SetType(Lum::Button::typeCommit);
-      row->Add(button);
-
-      button=new Lum::Button;
-      button->SetFlex(true,true);
-      button->SetModel(GetClosedAction());
-      button->SetText(_ld(dlgButtonCancel));
-      button->SetType(Lum::Button::typeCancel);
-      row->Add(button);
-
       vPanel->Add(row);
 
-      wGroup->SetMain(vPanel);
-
-      SetTop(wGroup);
+      SetMain(vPanel);
 
       Dialog::PreInit();
     }
