@@ -944,13 +944,10 @@ namespace Lum {
         info.SetDecoration(cursor->GetX(),LineInfo::decoCursor);
       }
 
-      std::wstring   textPart;
       OS::FontExtent extent;
-
-      textPart=L" ";
+      std::wstring   textPart(L" ");
 
       for (size_t x=0; x<info.text.length(); x++) {
-
         textPart[0]=info.text[x];
 
         font->StringExtent(textPart,extent,info.style[x].style);
