@@ -28,7 +28,7 @@ namespace Lum {
   FuelGauge::FuelGauge()
   : font(OS::display->GetFont())
   {
-    // no code
+    SetBackground(OS::display->GetFill(OS::Display::hprogressBackgroundFillIndex));
   }
 
   bool FuelGauge::SetModel(Base::Model* model)
@@ -42,11 +42,10 @@ namespace Lum {
 
   void FuelGauge::CalcSize()
   {
-    SetBackground(OS::display->GetFill(OS::Display::hprogressBackgroundFillIndex));
-
     minWidth=2*OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder)+
              3*font->StringWidth(L"m",OS::Font::normal);
     minHeight=font->height+2*OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
+
     width=minWidth;
     height=minHeight;
 
@@ -84,7 +83,7 @@ namespace Lum {
 
       if (width>=height) {
         Lum::OS::FontExtent extent;
-        std::wstring        label(Base::NumberToWString((size_t)(percent*100))+L"%");
+        std::wstring        label(Base::NumberToWString(lround(percent*100))+L"%");
         OS::FillRef         fill=OS::display->GetFill(OS::Display::hprogressFillIndex);
 
         fill->Draw(draw,
