@@ -134,11 +134,7 @@ namespace Lum {
     }
 
     if (adjustment.Valid()) {
-      UnattachModel(adjustment->GetTopModel());
-    }
-
-    if (model.Valid()) {
-      UnattachModel(model);
+      Forget(adjustment->GetTopModel());
     }
   }
 
@@ -155,13 +151,17 @@ namespace Lum {
 
   void Header::SetAdjustment(Model::Adjustment* adjustment)
   {
+    assert(adjustment!=NULL);
+
     if (this->adjustment.Valid()) {
-      UnattachModel(this->adjustment->GetTopModel());
+      Forget(this->adjustment->GetTopModel());
     }
 
     this->adjustment=adjustment;
 
-    AttachModel(this->adjustment->GetTopModel());
+    if (this->adjustment.Valid()) {
+      Observe(this->adjustment->GetTopModel());
+    }
   }
 
   void Header::CalcSize()
