@@ -82,7 +82,7 @@ namespace Lum {
   {
     Object::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
