@@ -41,20 +41,13 @@ namespace Lum {
     knob->SetParent(this);
     knob->SetFlex(true,true);
 
-    AttachModel(incAction);
-    AttachModel(decAction);
+    Observe(incAction);
+    Observe(decAction);
   }
 
   Knob::~Knob()
   {
-    UnattachModel(incAction);
-    UnattachModel(decAction);
-
     delete knob;
-
-    if (adjustment.Valid()) {
-      UnattachModel(adjustment);
-    }
   }
 
   /**
