@@ -27,7 +27,6 @@
 #include <Lum/TextLabel.h>
 
 namespace Lum {
-  static Label::Prefs *prefs=new Label::Prefs(L"Label");
 
   void Label::Entry::CalcSize()
   {
@@ -154,7 +153,7 @@ namespace Lum {
   Label::Label()
   : labelWidth(0),objectWidth(0),labelFlex(false)
   {
-    SetPrefs(::Lum::prefs);
+    // no code
   }
 
   Label::~Label()
@@ -385,7 +384,7 @@ namespace Lum {
         else {
           iter->label->Move(x,pos+(iter->GetHeight()-iter->label->GetOHeight())/2);
         }
-        
+
         if (iter->object->GetOHeight()<=iter->label->GetOHeight()) {
           iter->object->Move(x+labelWidth+OS::display->GetSpaceHorizontal(OS::Display::spaceLabelObject),
           pos+(iter->label->GetOHeight()-iter->object->GetOHeight())/2);
