@@ -30,6 +30,405 @@
 
 namespace Lum {
 
+  /* ---------- MenuDesc stuff ------------------*/
+
+  MenuItemDesc::MenuItemDesc()
+  {
+    // no code
+  }
+
+  MenuItemDesc::~MenuItemDesc()
+  {
+    // no code
+  }
+
+  MenuDesc::MenuDesc()
+  {
+    // no code
+  }
+
+  MenuDesc::MenuDesc(const std::wstring& title)
+  {
+    // no code
+  }
+
+  MenuDesc::~MenuDesc()
+  {
+    for (MenuItemList::const_iterator iter=items.begin();
+         iter!=items.end();
+         ++iter) {
+      delete *iter;
+    }
+  }
+
+  MenuDesc* MenuDesc::AddMenuItem(MenuItemDesc* menuItem)
+  {
+    items.push_back(menuItem);
+
+    return this;
+  }
+
+  MenuDesc* MenuDesc::AddMenuItemAction(const std::wstring& label,
+                                        Model::Action* action)
+  {
+    AddMenuItem(new MenuItemActionDesc(label,NULL,0,L"",action));
+
+    return this;
+  }
+
+  MenuDesc* MenuDesc::AddMenuItemAction(const std::wstring& label,
+                                        OS::Image* image,
+                                        Model::Action* action)
+  {
+    AddMenuItem(new MenuItemActionDesc(label,image,0,L"",action));
+
+    return this;
+  }
+
+  MenuDesc* MenuDesc::AddMenuItemAction(const std::wstring& label,
+                                        unsigned long qualifier, const std::wstring& key,
+                                        Model::Action* action)
+  {
+    AddMenuItem(new MenuItemActionDesc(label,NULL,qualifier,key,action));
+
+    return this;
+  }
+
+  MenuDesc* MenuDesc::AddMenuItemAction(const std::wstring& label,
+                                        OS::Image* image,
+                                        unsigned long qualifier, const std::wstring& key,
+                                        Model::Action* action)
+  {
+    AddMenuItem(new MenuItemActionDesc(label,image,qualifier,key,action));
+
+    return this;
+  }
+
+  MenuDesc* MenuDesc::AddMenuItemBool(const std::wstring& label,
+                                      Model::Boolean* boolean)
+  {
+    AddMenuItem(new MenuItemBoolDesc(label,NULL,0,L"",boolean));
+
+    return this;
+  }
+
+  MenuDesc* MenuDesc::AddMenuItemBool(const std::wstring& label,
+                                      OS::Image* image,
+                                      Model::Boolean* boolean)
+  {
+    AddMenuItem(new MenuItemBoolDesc(label,image,0,L"",boolean));
+
+    return this;
+  }
+
+  MenuDesc* MenuDesc::AddMenuItemBool(const std::wstring& label,
+                                      unsigned long qualifier, const std::wstring& key,
+                                      Model::Boolean* boolean)
+  {
+    AddMenuItem(new MenuItemBoolDesc(label,NULL,qualifier,key,boolean));
+
+    return this;
+  }
+
+  MenuDesc* MenuDesc::AddMenuItemBool(const std::wstring& label,
+                                      OS::Image* image,
+                                      unsigned long qualifier, const std::wstring& key,
+                                      Model::Boolean* boolean)
+  {
+    AddMenuItem(new MenuItemBoolDesc(label,image,qualifier,key,boolean));
+
+    return this;
+  }
+
+  MenuDesc* MenuDesc::AddMenuItemRadio(const std::wstring& label,
+                                       Model::SizeT* model,
+                                       size_t index)
+  {
+    AddMenuItem(new MenuItemRadioDesc(label,NULL,0,L"",model,index));
+
+    return this;
+  }
+
+  MenuDesc* MenuDesc::AddMenuItemRadio(const std::wstring& label,
+                                       OS::Image* image,
+                                       Model::SizeT* model,
+                                       size_t index)
+  {
+    AddMenuItem(new MenuItemRadioDesc(label,image,0,L"",model,index));
+
+    return this;
+  }
+
+  MenuDesc* MenuDesc::AddMenuItemRadio(const std::wstring& label,
+                                       unsigned long qualifier, const std::wstring& key,
+                                       Model::SizeT* model,
+                                       size_t index)
+  {
+    AddMenuItem(new MenuItemRadioDesc(label,NULL,qualifier,key,model,index));
+
+    return this;
+  }
+
+  MenuDesc* MenuDesc::AddMenuItemRadio(const std::wstring& label,
+                                       OS::Image* image,
+                                       unsigned long qualifier, const std::wstring& key,
+                                       Model::SizeT* model,
+                                       size_t index)
+  {
+    AddMenuItem(new MenuItemRadioDesc(label,image,qualifier,key,model,index));
+
+    return this;
+  }
+
+  MenuDesc* MenuDesc::AddMenuItemSub(const std::wstring& label)
+  {
+    MenuDesc* sub=new MenuDesc();
+
+    AddMenuItem(new MenuItemSubDesc(label,sub));
+
+    return sub;
+  }
+
+  MenuDesc* MenuDesc::AddSeparator()
+  {
+    AddMenuItem(new MenuItemSeparatorDesc());
+
+    return this;
+  }
+
+  const MenuDesc::MenuItemList& MenuDesc::GetItems() const
+  {
+    return items;
+  }
+
+  MenuItemSubDesc::MenuItemSubDesc(const std::wstring& label,
+                                   MenuDesc* menu)
+   : label(label),
+     menu(menu)
+  {
+    // no code
+  }
+
+  MenuItemSubDesc::~MenuItemSubDesc()
+  {
+    delete menu;
+  }
+
+  std::wstring MenuItemSubDesc::GetLabel() const
+  {
+    return label;
+  }
+
+  MenuDesc* MenuItemSubDesc::GetMenuDesc() const
+  {
+    return menu;
+  }
+
+  MenuItemSeparatorDesc::MenuItemSeparatorDesc()
+  {
+    // no code
+  }
+
+  MenuItemActionDesc::MenuItemActionDesc(const std::wstring& label,
+                                         OS::Image* image,
+                                         unsigned long qualifier, const std::wstring& key,
+                                         Model::Action* action)
+  : label(label),
+    image(image),
+    qualifier(qualifier),
+    key(key),
+    action(action)
+  {
+    // no code
+  }
+
+  std::wstring MenuItemActionDesc::GetLabel() const
+  {
+    return label;
+  }
+
+  OS::Image* MenuItemActionDesc::GetImage() const
+  {
+    return image;
+  }
+
+  unsigned long MenuItemActionDesc::GetQualifier() const
+  {
+    return qualifier;
+  }
+
+  std::wstring MenuItemActionDesc::GetKey() const
+  {
+    return key;
+  }
+
+  Model::Action* MenuItemActionDesc::GetAction() const
+  {
+    return action;
+  }
+
+  MenuItemBoolDesc::MenuItemBoolDesc(const std::wstring& label,
+                                     OS::Image* image,
+                                     unsigned long qualifier, const std::wstring& key,
+                                     Model::Boolean* boolean)
+  : label(label),
+    image(image),
+    qualifier(qualifier),
+    key(key),
+    boolean(boolean)
+  {
+    // no code
+  }
+
+  std::wstring MenuItemBoolDesc::GetLabel() const
+  {
+    return label;
+  }
+
+  OS::Image* MenuItemBoolDesc::GetImage() const
+  {
+    return image;
+  }
+
+  unsigned long MenuItemBoolDesc::GetQualifier() const
+  {
+    return qualifier;
+  }
+
+  std::wstring MenuItemBoolDesc::GetKey() const
+  {
+    return key;
+  }
+
+  Model::Boolean* MenuItemBoolDesc::GetBoolean() const
+  {
+    return boolean;
+  }
+
+  MenuItemRadioDesc::MenuItemRadioDesc(const std::wstring& label,
+                                       OS::Image* image,
+                                       unsigned long qualifier, const std::wstring& key,
+                                       Model::SizeT* model,
+                                       size_t index)
+  : label(label),
+    image(image),
+    qualifier(qualifier),
+    key(key),
+    model(model),
+    index(index)
+  {
+    // no code
+  }
+
+  std::wstring MenuItemRadioDesc::GetLabel() const
+  {
+    return label;
+  }
+
+  OS::Image* MenuItemRadioDesc::GetImage() const
+  {
+    return image;
+  }
+
+  unsigned long MenuItemRadioDesc::GetQualifier() const
+  {
+    return qualifier;
+  }
+
+  std::wstring MenuItemRadioDesc::GetKey() const
+  {
+    return key;
+  }
+
+  Model::SizeT* MenuItemRadioDesc::GetModel() const
+  {
+    return model;
+  }
+
+  size_t MenuItemRadioDesc::GetIndex() const
+  {
+    return index;
+  }
+
+  Menu* ConvertToMenu(MenuDesc* menuDesc)
+  {
+    Menu *menu=new Menu();
+
+    for (MenuDesc::MenuItemList::const_iterator iter=menuDesc->GetItems().begin();
+         iter!=menuDesc->GetItems().end();
+         ++iter) {
+      assert((*iter)!=NULL);
+
+      if (dynamic_cast<MenuItemSubDesc*>(*iter)!=NULL) {
+        MenuItemSubDesc *sub=dynamic_cast<MenuItemSubDesc*>(*iter);
+
+        menu->AddSubMenu(sub->GetLabel(),ConvertToMenu(sub->GetMenuDesc()));
+      }
+      else if (dynamic_cast<MenuItemActionDesc*>(*iter)!=NULL) {
+        MenuItemActionDesc *action=dynamic_cast<MenuItemActionDesc*>(*iter);
+
+        menu->AddActionItem(action->GetLabel(),
+                            /*action->GetImage(),*/
+                            action->GetAction(),
+                            action->GetQualifier(),action->GetKey());
+      }
+      else if (dynamic_cast<MenuItemBoolDesc*>(*iter)!=NULL) {
+        MenuItemBoolDesc *boolean=dynamic_cast<MenuItemBoolDesc*>(*iter);
+
+        menu->AddBoolItem(boolean->GetLabel(),
+                            /*bool->GetImage(),*/
+                          boolean->GetBoolean(),
+                          boolean->GetQualifier(),
+                          boolean->GetKey());
+      }
+      else if (dynamic_cast<MenuItemRadioDesc*>(*iter)!=NULL) {
+        MenuItemRadioDesc *radio=dynamic_cast<MenuItemRadioDesc*>(*iter);
+
+        menu->AddRadioItem(radio->GetLabel(),
+                            /*radio->GetImage(),*/
+                           radio->GetModel(),
+                           radio->GetIndex(),
+                           radio->GetQualifier(),
+                           radio->GetKey());
+      }
+      else if (dynamic_cast<MenuItemSeparatorDesc*>(*iter)!=NULL) {
+        menu->AddSeparator();
+      }
+      else {
+        assert(false);
+      }
+    }
+
+    return menu;
+  }
+
+  MenuStrip* ConvertToMenuStrip(MenuDesc* menuDesc)
+  {
+    assert(menuDesc!=NULL);
+
+    MenuStrip *strip=new MenuStrip();
+
+    strip->SetFlex(true,false);
+
+    for (MenuDesc::MenuItemList::const_iterator iter=menuDesc->GetItems().begin();
+         iter!=menuDesc->GetItems().end();
+         ++iter) {
+      assert((*iter)!=NULL);
+
+      if (dynamic_cast<MenuItemSubDesc*>(*iter)!=NULL) {
+        MenuItemSubDesc *sub=dynamic_cast<MenuItemSubDesc*>(*iter);
+
+        strip->AddPullDownMenu(sub->GetLabel(),ConvertToMenu(sub->GetMenuDesc()));
+      }
+      else {
+        assert(false);
+      }
+    }
+
+    return strip;
+  }
+
+
   /* ---------- Menustrip stuff ------------------*/
 
   MenuStrip::MenuStrip()
@@ -228,7 +627,6 @@ namespace Lum {
   void MenuStrip::PreDrawChild(Object* child)
   {
     OS::DrawInfo *draw=GetDrawInfo();
-
     std::list<Object*>::iterator label=FindLabel(selection);
     if (label!=list.end() && child==*label) {
       draw->selected=true;
@@ -256,12 +654,14 @@ namespace Lum {
 
     SetFlex(true,true);
 
-    AttachModel(shortcutAction);
+    Observe(shortcutAction);
   }
 
   PullDownMenu::~PullDownMenu()
   {
-    UnattachModel(shortcutAction);
+    if (sc!=L'\0' && dynamic_cast<Dialog*>(GetWindow()->GetMaster())!=NULL) {
+      dynamic_cast<Dialog*>(GetWindow()->GetMaster())->UnregisterShortcut(shortcutAction);
+    }
 
     delete label;
     delete subMenu;
@@ -288,7 +688,7 @@ namespace Lum {
     minWidth=width;
     minHeight=height;
 
-    if ((sc!=L'\0') && (dynamic_cast<Dialog*>(GetWindow()->GetMaster())!=NULL)) {
+    if (sc!=L'\0' && dynamic_cast<Dialog*>(GetWindow()->GetMaster())!=NULL) {
       dynamic_cast<Dialog*>(GetWindow()->GetMaster())->RegisterShortcut(this,
                                                                         OS::qualifierAlt,std::wstring(1,sc),
                                                                         shortcutAction);
@@ -379,21 +779,27 @@ namespace Lum {
     x1(0),x2(0),x3(0),x4(0),
     sc(L'\0'),
     w1(0),w2(0),w3(0),w4(0),
-    menuWindow(NULL)
+    menuWindow(NULL),
+    parentWindow(NULL)
   {
     SetBackground(OS::display->GetFill(OS::Display::menuEntryBackgroundFillIndex));
 
     shortcutAlways=true;
 
-    AttachModel(shortcutAction);
+    Observe(shortcutAction);
   }
 
   MenuEntry::~MenuEntry()
   {
+    if (!key.empty() &&
+        parentWindow!=NULL &&
+        parentWindow->GetMaster()!=NULL &&
+        dynamic_cast<Dialog*>(parentWindow->GetMaster())!=NULL) {
+      dynamic_cast<Dialog*>(parentWindow->GetMaster())->UnregisterShortcut(shortcutAction);
+    }
+
     delete label;
     delete shortcut;
-
-    UnattachModel(shortcutAction);
   }
 
   void MenuEntry::SetOffsets(int x1, int x2, int x3, int x4)
@@ -428,6 +834,8 @@ namespace Lum {
 
   void MenuEntry::RegisterToParentWindow(OS::Window* parent)
   {
+    parentWindow=parent;
+
     if (!key.empty()) {
       assert(parent!=NULL);
       if (dynamic_cast<Dialog*>(parent->GetMaster())!=NULL) {
@@ -583,8 +991,13 @@ namespace Lum {
 
   void ActionItem::OnSelection()
   {
-    if (action.Valid() && action->IsEnabled()) {
-      action->Trigger();
+    // We make a copy of the action reference, because the triggering of the action
+    // might result in deletion of the menu and the containing action references, making us
+    // work on an already deleted model instance.
+    Model::ActionRef localAction=action;
+
+    if (localAction.Valid() && localAction->IsEnabled()) {
+      localAction->Trigger();
     }
   }
 
@@ -592,11 +1005,11 @@ namespace Lum {
   {
     assert(label!=NULL);
 
+    width=w1+w2+w3+w4;
+
     CalcLabelSize();
     CalcShortcutSize();
 
-    width=w1+w2+w3+w4;
-
     MenuEntry::CalcSize();
   }
 
@@ -955,13 +1368,9 @@ namespace Lum {
 
   void MenuBox::CalcSize()
   {
-    size_t w1,w2,w3,w4;
-    int x1,x2,x3,x4;
+    size_t w1=0,w2=0,w3=0,w4=0;
 
-    w1=0;
-    w2=0;
-    w3=0;
-    w4=0;
+    width=0;
     height=0;
 
     for (std::list<Object*>::iterator iter=list.begin(); iter!=list.end(); ++iter) {
@@ -975,28 +1384,24 @@ namespace Lum {
       height+=entry->GetOHeight();
     }
 
-    x1=x+OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
     width+=OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
 
     // Image
     if (w1==0) {
       w1=OS::display->GetSpaceHorizontal(OS::Display::spaceGroupIndent);
     }
-    x2=x1+w1+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
     width+=w1+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
 
     //Label
     if (w2==0) {
       w2=OS::display->GetSpaceHorizontal(OS::Display::spaceGroupIndent);
     }
-    x3=x2+w2+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
     width+=w2+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
 
     // Shortcut
     if (w3==0) {
       w3=OS::display->GetSpaceHorizontal(OS::Display::spaceGroupIndent);
     }
-    x4=x3+w3+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
     width+=w3+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
 
     // Sub Image
@@ -1012,7 +1417,6 @@ namespace Lum {
       entry->w2=w2;
       entry->w3=w3;
       entry->w4=w4;
-      entry->SetOffsets(x1,x2,x3,x4);
     }
 
     minWidth=width;
@@ -1025,6 +1429,34 @@ namespace Lum {
   {
     std::list<Object*>::iterator iter;
     int                          yPos;
+    int                          x1,x2,x3,x4;
+    size_t                       w1=0,w2=0,w3=0,w4=0;
+
+    if (list.size()>0) {
+      MenuEntry* entry=dynamic_cast<MenuEntry*>(*list.begin());
+
+      w1=entry->w1;
+      w2=entry->w2;
+      w3=entry->w3;
+      w4=entry->w4;
+    }
+
+    x1=x+OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
+
+    // Image
+    x2=x1+w1+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
+
+    //Label
+    x3=x2+w2+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
+
+    // Shortcut
+    x4=x3+w3+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
+
+    for (std::list<Object*>::iterator iter=list.begin(); iter!=list.end(); ++iter) {
+      MenuEntry* entry=dynamic_cast<MenuEntry*>(*iter);
+
+      entry->SetOffsets(x1,x2,x3,x4);
+    }
 
     yPos=y;
 
@@ -1187,25 +1619,17 @@ namespace Lum {
     top=new MenuBox();
     top->SetWindow(window);
 
-    AttachModel(window->GetUnmapedAction());
-    AttachModel(window->GetHiddenAction());
-    AttachModel(window->GetRedrawAction());
-    AttachModel(window->GetMouseOutAction());
-    AttachModel(window->GetPreInitAction());
-    AttachModel(window->GetEventAction());
+    Observe(window->GetUnmapedAction());
+    Observe(window->GetHiddenAction());
+    Observe(window->GetRedrawAction());
+    Observe(window->GetMouseOutAction());
+    Observe(window->GetPreInitAction());
+    Observe(window->GetEventAction());
   }
 
   Menu::~Menu()
   {
     delete top;
-
-    UnattachModel(window->GetEventAction());
-    UnattachModel(window->GetPreInitAction());
-    UnattachModel(window->GetMouseOutAction());
-    UnattachModel(window->GetRedrawAction());
-    UnattachModel(window->GetHiddenAction());
-    UnattachModel(window->GetUnmapedAction());
-
     delete window;
   }
 
@@ -1345,7 +1769,8 @@ namespace Lum {
       y=help->GetY();
       x+=reference->GetOX();
       y+=reference->GetOY()+reference->GetOHeight();
-      window->Grab(true);
+      window->GrabMouse(true);
+      window->GrabKeyboard(true);
     }
     else if (parentMenu!=NULL) { /* submenu */
       x=parentMenu->GetWindow()->GetX()+parentMenu->GetWindow()->GetWidth();
@@ -1368,7 +1793,8 @@ namespace Lum {
     }
 
     if (strip==NULL && parentMenu==NULL) {
-      window->Grab(true);
+      window->GrabMouse(true);
+      window->GrabKeyboard(true);
     }
 
     x=Base::RoundRange(x,0,OS::display->GetScreenWidth()-1-window->GetWidth());
@@ -1814,7 +2240,13 @@ namespace Lum {
 
   void Menu::AddSubMenu(const std::wstring& label, Menu* subMenu)
   {
-    AddSubMenu(new Text(label),subMenu);
+    SubMenu* sub;
+
+    sub=new SubMenu();
+    sub->SetTextLabel(label);
+    sub->SetSubMenu(subMenu);
+
+    Add(sub);
   }
 }
 
