@@ -19,8 +19,6 @@
 
 #include <Lum/OS/Base/Display.h>
 
-#include <iostream>
-
 #include <Lum/Private/Config.h>
 #include <wctype.h>
 
@@ -42,6 +40,7 @@ namespace Lum {
         multiClickTime(200),
         appName(L""),
         theme(NULL),
+        eventLoop(NULL),
         keyboardHandler(NULL)
       {
         int i=1;
@@ -134,7 +133,7 @@ namespace Lum {
 
       std::wstring Display::GetThemePath() const
       {
-        ::Lum::Base::Path path;
+        Lum::Base::Path path;
 
         path.SetNativeDir(::Lum::Base::Path::GetHome());
         path.AppendDir(L".illumination");
@@ -145,7 +144,7 @@ namespace Lum {
 
       std::wstring Display::GetThemeName() const
       {
-        ::Lum::Base::Path path;
+        Lum::Base::Path path;
 
         path.SetNativeDir(GetThemePath());
         path.SetBaseName(L"theme.xml");
@@ -158,17 +157,17 @@ namespace Lum {
         return theme;
       }
 
-      ::Lum::OS::Display::Type Display::GetType() const
+      Display::Type Display::GetType() const
       {
         return type;
       }
 
-      ::Lum::OS::Display::Size Display::GetSize() const
+     Display::Size Display::GetSize() const
       {
         return size;
       }
 
-      ::Lum::OS::Display::ColorMode Display::GetColorMode() const
+     Display::ColorMode Display::GetColorMode() const
       {
         return colorMode;
       }
@@ -253,46 +252,29 @@ namespace Lum {
         return GetColor((ColorIndex)index);
       }
 
-      void Display::SignalEventLoop()
+      EventLoop* Display::GetEventLoop() const
       {
-        std::cerr << "WARNING: Display::SignalEventLoop() is not implemented by this driver!" << std::endl;
+        return eventLoop;
+      }
+
+      void Display::MainLoop()
+      {
+        eventLoop->Run();
+      }
+
+      void Display::Exit()
+      {
+        eventLoop->Exit();
       }
 
       void Display::QueueActionForAsyncNotification(Model::Action *action)
       {
-        Guard<TryMutex> guard(asyncMutex);
-
-        asyncActions.push_back(action);
-
-        SignalEventLoop();
-      }
-
-      void Display::HandleAsyncActions()
-      {
-        if (asyncMutex.TryLock()) {
-          while (asyncActions.begin()!=asyncActions.end()) {
-            Model::ActionRef action(*asyncActions.begin());
-
-            asyncActions.erase(asyncActions.begin());
-            action->Trigger();
-          }
-          asyncMutex.Unlock();
-        }
+        eventLoop->QueueActionForAsyncNotification(action);
       }
 
       void Display::QueueActionForEventLoop(Model::Action *action)
       {
-        eventLoopActions.push_back(action);
-      }
-
-      void Display::HandleEventLoopActions()
-      {
-        while (eventLoopActions.begin()!=eventLoopActions.end()) {
-          Model::ActionRef action(*eventLoopActions.begin());
-
-          eventLoopActions.erase(eventLoopActions.begin());
-          action->Trigger();
-        }
+        eventLoop->QueueActionForEventLoop(action);
       }
 
       void Display::AddTimer(long seconds, long microseconds,
@@ -300,91 +282,12 @@ namespace Lum {
       {
         assert(action!=NULL);
 
-        ::Lum::Base::SystemTime time(seconds,microseconds);
-        ::Lum::Base::SystemTime now;
-        Timer                   timer;
-
-        time.Add(now);
-
-        timer.time=time;
-        timer.action=action;
-
-        timerList.push_back(timer);
+        eventLoop->AddTimer(seconds,microseconds,action);
       }
 
       void Display::RemoveTimer(Model::Action* action)
       {
-        std::list<Timer>::iterator iter;
-
-        iter=timerList.begin();
-        while (iter!=timerList.end()) {
-          if (iter->action.Get()==action) {
-            iter=timerList.erase(iter);
-          }
-          else {
-            ++iter;
-          }
-        }
-      }
-
-      void Display::CheckTimers()
-      {
-        std::list<Timer>::iterator iter;
-        ::Lum::Base::SystemTime    now;
-
-        iter=timerList.begin();
-        while (iter!=timerList.end()) {
-          if (iter->time<=now) {
-            Model::ActionRef action;
-
-            action=iter->action;
-
-            timerList.erase(iter);
-
-            action->Trigger();
-
-            // A Timer might trigger a new dialog. This dialog may have its own event loop
-            // which might call CheckTimers again, resulting in recursive calls to CheckTimers
-            // changing timerList.
-            // To make this work, we restart the loop over timerList every time we trigger
-            // an action.
-            iter=timerList.begin();
-          }
-          else {
-            ++iter;
-          }
-        }
-      }
-
-      /**
-        Return the next pending future time event. If there is no event pending it
-        will return a event 10 seconds in the future.
-      */
-      bool Display::GetNextTimer(::Lum::Base::SystemTime& interval)
-      {
-        if (!timerList.empty()) {
-          ::Lum::Base::SystemTime now;
-          ::Lum::Base::SystemTime time;
-
-          for (std::list<Timer>::iterator iter=timerList.begin(); iter!=timerList.end(); ++iter) {
-            if (iter==timerList.begin()) {
-              time=iter->time;
-            }
-            else if (iter->time<time) {
-              time=iter->time;
-            }
-          }
-
-          interval=time;
-          interval.Sub(now);
-
-          return true;
-        }
-        else {
-          interval=::Lum::Base::SystemTime(1,0);
-
-          return false;
-        }
+        eventLoop->RemoveSource(action);
       }
 
       bool Display::SetClipboard(const std::wstring& /*content*/)
