@@ -1872,6 +1872,11 @@ namespace Lum {
       {
         return true;
       }
+
+      OS::Theme::MenuType DefaultTheme::GetMenuType() const
+      {
+        return menuTypeStrip;
+      }
     }
   }
 }
