@@ -43,7 +43,9 @@ namespace Lum {
         preInitAction(new Model::Action),
         eventAction(new Model::Action),
         grabCancelAction(new Model::Action()),
+        menuAction(new Model::Action()),
         open(false),
+        inEventLoop(false),
         shown(false),
         focus(false),
         x(0),y(0),width(0),height(0),
@@ -56,16 +58,15 @@ namespace Lum {
         draw(NULL),
         backgroundDraw(NULL),
         backgroundBitmap(NULL),
-        type(typeAuto)
+        type(typeAuto),
+        grabMouse(false),grabKeyboard(false)
       {
         // no code
       }
 
       Window::~Window()
       {
-        if (exitAction.Valid()) {
-          UnattachModel(exitAction);
-        }
+        // no code
       }
 
       void Window::Resync(Lum::Base::Model* model,
@@ -84,13 +85,13 @@ namespace Lum {
       void Window::SetExitAction(Model::Action* action)
       {
         if (exitAction.Valid()) {
-          UnattachModel(exitAction);
+          Forget(exitAction);
         }
 
         exitAction=action;
 
         if (exitAction.Valid()) {
-          AttachModel(exitAction);
+          Observe(exitAction);
         }
       }
 
@@ -179,6 +180,11 @@ namespace Lum {
         return grabCancelAction.Get();
       }
 
+      Model::Action* Window::GetMenuAction() const
+      {
+        return menuAction.Get();
+      }
+
       void Window::SetParent(OS::Window* parent)
       {
         if (!IsOpen()) {
@@ -387,7 +393,10 @@ namespace Lum {
         switch (type) {
         case OS::Window::typePopup:
           assert(parent!=NULL);
-          Grab(true);
+          GrabMouse(true);
+          if (activate) {
+            GrabKeyboard(true);
+          }
           break;
         default:
           break;
@@ -416,6 +425,35 @@ namespace Lum {
         modalCount=0;
       }
 
+      void Window::EventLoop()
+      {
+        assert(!inEventLoop);
+
+        inEventLoop=true;
+
+        if (type!=typeMenu && type!=typePopup) {
+          DisableParents();
+        }
+
+        display->MainLoop();
+
+        if (type!=typeMenu && type!=typePopup) {
+          EnableParents();
+        }
+
+        inEventLoop=false;
+      }
+
+      bool Window::IsInEventLoop() const
+      {
+        return inEventLoop;
+      }
+
+      void Window::Exit()
+      {
+        display->Exit();
+      }
+
       /**
         If you derive yourself from window and want to overload the
         defaulthandler, call the baseclass first in your handler and check the
@@ -657,6 +695,11 @@ namespace Lum {
         grabCancelAction->Trigger();
       }
 
+      void Window::TriggerMenu()
+      {
+        menuAction->Trigger();
+      }
+
       bool Window::SendBalloonMessage(const std::wstring& /*text*/, unsigned long /*timeout*/)
       {
         return false;
@@ -736,6 +779,56 @@ namespace Lum {
         // By default do nothing
       }
 
+      void Window::GrabMouse(bool grab)
+      {
+        if (this->grabMouse==grab) {
+          return;
+        }
+        this->grabMouse=grab;
+        if (IsOpen()) {
+          if (this->grabMouse) {
+            //OS::display->StopContextHelp();
+            MouseGrabOn();
+          }
+          else {
+            MouseGrabOff();
+            //OS::display->RestartContextHelp();
+          }
+        }
+      }
+
+      void Window::GrabKeyboard(bool grab)
+      {
+        if (this->grabKeyboard==grab) {
+          return;
+        }
+        this->grabKeyboard=grab;
+        if (IsOpen()) {
+          if (this->grabKeyboard) {
+            KeyboardGrabOn();
+          }
+          else {
+            KeyboardGrabOff();
+          }
+        }
+      }
+
+      void Window::MouseGrabOn()
+      {
+      }
+
+      void Window::MouseGrabOff()
+      {
+      }
+
+      void Window::KeyboardGrabOn()
+      {
+      }
+
+      void Window::KeyboardGrabOff()
+      {
+      }
+
       bool Window::SetFullScreen()
       {
         return false;
