@@ -24,19 +24,12 @@
 #include <iostream>
 #include <limits>
 
-#include <stdint.h>
-#include <unistd.h>
-#include <pwd.h>
-
-// for select TODO: Write a configure test for it
-#include <sys/select.h>
-#include <sys/time.h>
-#include <sys/types.h>
-
 #include <Lum/Base/String.h>
 
 #include <Lum/Images/Image.h>
 
+#include <Lum/OS/EventLoopUnix.h>
+
 #include <Lum/OS/Curses/Font.h>
 #include <Lum/OS/Curses/Theme.h>
 #include <Lum/OS/Curses/Tray.h>
@@ -46,6 +39,61 @@ namespace Lum {
   namespace OS {
     namespace Curses {
 
+      class LUMAPI CursesEventSource : public EventSource
+      {
+      private:
+        Display *display;
+
+      public:
+        CursesEventSource(Display* display)
+        {
+          this->display=display;
+        }
+
+        bool Matches(const Model::Action* action) const
+        {
+          return false;
+        }
+
+        bool GetTimeout(Lum::Base::SystemTime& time) const
+        {
+          return false;
+        }
+
+        bool GetFileIO(FileIO& fileIO) const
+        {
+          fileIO.file=0;
+          fileIO.conditions=ioRead;
+
+          return true;
+        }
+
+        bool DataAvailable() const
+        {
+          return false;
+        }
+
+        bool DataAvailable(Lum::Base::SystemTime& time) const
+        {
+          return false;
+        }
+
+        bool DataAvailable(const FileIO& fileIO) const
+        {
+          return true;
+        }
+
+        void Trigger()
+        {
+          display->GetEvent();
+        }
+
+        bool IsFinished() const
+        {
+          return false;
+        }
+      };
+
       double Display::GetDPI() const
       {
         return 1;
@@ -260,6 +308,9 @@ namespace Lum {
 
         multiClickTime=200;
 
+        eventLoop=new UnixEventLoop();
+        eventLoop->AddSource(new CursesEventSource(this));
+
         return true;
       }
 
@@ -285,6 +336,8 @@ namespace Lum {
 
         delwin(screen);
         endwin();
+
+        delete eventLoop;
       }
 
       void Display::Beep()
@@ -374,19 +427,6 @@ namespace Lum {
         return !clipboard.empty();
       }
 
-      void Display::PutBackEvent(OS::Event* /*event*/,
-                                 OS::Window* /*destWin*/)
-      {
-        // TODO
-      }
-
-      void Display::Exit()
-      {
-        assert(!exit);
-
-        exit=true;
-      }
-
       void Display::ReinitWindows()
       {
         std::list<Window*>::iterator win;
@@ -453,73 +493,9 @@ namespace Lum {
             }
           }
         }
-      }
 
-      /**
-        Waits for certain events to happen:
-        *A X11 event occurs
-        *Timer run out
-
-        Returns TRUE, if the wait exceeds the given timeout, else FALSE, if Wait
-        returned because an X11 event is available.
-
-        File descriptors getting available will be handled internaly. In this
-        case a notification will be send and the wait will be restarted.
-      */
-      bool Display::Wait()
-      {
-
-        while (true) {
-          fd_set                set;
-          int                   ret;
-          Lum::Base::SystemTime tmp;
-          timeval               timeout;
-          int                   max;
-          int                   cursesFd;
-
-          cursesFd=0;
-
-          FD_ZERO(&set);
-          FD_SET(cursesFd,&set); // Waiting on standard input
-          max=cursesFd;
-
-          GetNextTimer(tmp);
-          tmp.GetTimeval(timeout);
-
-          ret=select(max+1,&set,NULL,NULL,&timeout);
-
-          if (ret>=0) {
-            return true;
-          }
-        }
-      }
-
-      void Display::EventLoop()
-      {
-        assert(exit);
-
-        exit=false;
-
-        HandleAsyncActions();
-        HandleEventLoopActions();
-        CheckTimers();
-
-        while (true) {
-          if (Wait()) {
-            GetEvent();
-          }
-
-          HandleAsyncActions();
-          HandleEventLoopActions();
-          CheckTimers();
-
-          update_panels();
-          doupdate();
-
-          if (exit) {
-            break;
-          }
-        }
+        update_panels();
+        doupdate();
       }
 
       bool Display::GetMousePos(int& /*x*/, int& /*y*/) const
