@@ -1005,6 +1005,10 @@ namespace Lum {
         return false;
       }
 
+      OS::Theme::MenuType Theme::GetMenuType() const
+      {
+        return menuTypeStrip;
+      }
     }
   }
 }
