@@ -31,7 +31,6 @@ namespace Lum {
 
       Window::Window(OS::Display* display)
       : display(dynamic_cast<Display*>(display)),
-        grab(false),exit(true),
         //oldPress(0),lastPress(0),thisPress(0),
         window(NULL),frame(NULL),panel(NULL),framePanel(NULL)
       {
@@ -81,45 +80,9 @@ namespace Lum {
         }*/
       }
 
-      /**
-        Grabs the mouse cursor and keyboard.
-      */
-      void Window::GrabOn()
-      {
-        display->StopContextHelp();
-        /*
-        if (XGrabPointer(display->display,window,
-                         False,
-                         StructureNotifyMask|ButtonPressMask|ButtonReleaseMask|ButtonMotionMask|PointerMotionMask|PointerMotionHintMask|LeaveWindowMask|EnterWindowMask|VisibilityChangeMask|FocusChangeMask,
-                         GrabModeAsync,GrabModeAsync,
-                         None,
-                         None,
-                         CurrentTime)!=GrabSuccess) {
-          std::cerr << "Cannot grab pointer" << std::endl;
-        }
-        if (XGrabKeyboard(display->display,window,
-                          False,
-                          GrabModeAsync,GrabModeAsync,
-                          CurrentTime)!=GrabSuccess) {
-          std::cerr << "Cannot grab keyboard" << std::endl;
-        }*/
-      }
-
-      /**
-        Releases the grab of the mouse cursor and the keyboard.
-      */
-      void Window::GrabOff()
-      {
-        /*
-        XUngrabPointer(display->display,CurrentTime);
-        XUngrabKeyboard(display->display,CurrentTime);
-        */
-        display->RestartContextHelp();
-      }
-
       void Window::OnFocusIn()
       {
-        if (!grab) {
+        if (!grabMouse) {
           display->StartContextHelp();
         }
         TriggerFocusIn();
@@ -127,7 +90,7 @@ namespace Lum {
 
       void Window::OnFocusOut()
       {
-        if (!grab) {
+        if (!grabMouse) {
           display->StopContextHelp();
         }
         TriggerFocusOut();
@@ -156,22 +119,6 @@ namespace Lum {
         // TODO
       }
 
-      void Window::Grab(bool grab)
-      {
-        if (this->grab==grab) {
-          return;
-        }
-        this->grab=grab;
-        if (IsOpen()) {
-          if (this->grab) {
-            GrabOn();
-          }
-          else {
-            GrabOff();
-          }
-        }
-      }
-
       bool Window::Open(bool activate)
       {
         bool xManPos;
@@ -257,9 +204,8 @@ namespace Lum {
       void Window::Close()
       {
         if (IsOpen() && window!=NULL) {
-          if (grab) {
-            GrabOff();
-          }
+          GrabMouse(false);
+          GrabKeyboard(false);
         }
 
         TriggerMouseOut();
@@ -323,37 +269,6 @@ namespace Lum {
                              &rx,&ry,&x,&y,&bmask)!=False;*/
       }
 
-      void Window::EventLoop()
-      {
-        assert(exit);
-
-        exit=false;
-
-        DisableParents();
-
-        while (true) {
-          if (display->Wait()) {
-            display->HandleAsyncActions();
-            display->HandleEventLoopActions();
-            display->CheckTimers();
-            display->GetEvent();
-          }
-
-          display->HandleAsyncActions();
-          display->HandleEventLoopActions();
-          display->CheckTimers();
-
-          update_panels();
-          doupdate();
-
-          if (exit) {
-            break;
-          }
-        }
-
-        EnableParents();
-      }
-
       void Window::Enable()
       {
         OS::Base::Window::Enable();
@@ -379,11 +294,6 @@ namespace Lum {
         return false;
       }
 
-      bool Window::IsInEventLoop() const
-      {
-        return !exit;
-      }
-
       bool Window::IsDoubleClicked() const
       {
         return false;
@@ -400,12 +310,6 @@ namespace Lum {
         return false;
         //return (w.oldButton.type==w.lastButton.type) && (w.oldButton.qualifier==w.lastButton.qualifier) && (ABS(w.oldButton.x-w.lastButton.x)<5) && (ABS(w.oldButton.y-w.lastButton.y)<5) && (w.lastPress-w.oldPress<=D.display(Display).multiClickTime) && (w.lastButton.type==w.thisButton.type) && (w.lastButton.qualifier==w.thisButton.qualifier) && (ABS(w.lastButton.x-w.thisButton.x)<5) && (ABS(w.lastButton.y-w.thisButton.y)<5) && (w.thisPress-w.lastPress<=D.display(Display).multiClickTime);
       }
-
-      void Window::Exit()
-      {
-        assert(!exit);
-        exit=true;
-      }
     }
   }
 }
