@@ -44,9 +44,67 @@ namespace Lum {
       {
       }
 
+      class Win32MsgEventSource : public EventSource
+      {
+      private:
+        Display *display;
+
+      public:
+        Win32MsgEventSource(Display *display)
+        {
+          this->display=display;
+        }
+
+        bool Matches(const Model::Action* action) const
+        {
+          return false;
+        }
+
+        bool GetTimeout(Lum::Base::SystemTime& time) const
+        {
+          return false;
+        }
+
+        bool GetFileIO(FileIO& fileIO) const
+        {
+          return false;
+        }
+
+        bool DataAvailable() const
+        {
+          return GetQueueStatus(QS_ALLINPUT)!=0;
+        }
+
+        bool DataAvailable(Lum::Base::SystemTime& time) const
+        {
+          return false;
+        }
+
+        bool DataAvailable(const FileIO& fileIO) const
+        {
+          return false;
+        }
+
+        void Trigger()
+        {
+          MSG msg;
+          
+          while (::PeekMessage(&msg,NULL,0,0,PM_REMOVE)) {
+            if (msg.message==WM_QUIT) {
+              break;
+            }
+            ::DispatchMessage(&msg);
+          }
+        }
+
+        bool IsFinished() const
+        {
+          return false;
+        }
+      };
+      
       Display::Display()
        : selectObject(NULL),
-         exit(true),
          instance(0),
          hdc(0),
          appWindow(0)
@@ -450,11 +508,6 @@ namespace Lum {
         return !GetClipboard().empty();
       }
 
-      void Display::PutBackEvent(OS::Event* /*event*/, OS::Window* /*destWin*/)
-      {
-        // TODO
-      }
-
       void Display::ReinitWindows()
       {
         // TODO
@@ -523,6 +576,9 @@ namespace Lum {
 
         colorMode=colorModeColor;
 
+        eventLoop=new Win32EventLoop();
+        eventLoop->AddSource(new Win32MsgEventSource(this));
+        
         //D.smallChess=d.CreateBitmapPattern(D.disablePattern,D.disableWidth,D.disableHeight);
         //D.bigChess=d.CreateBitmapPattern(D.bigChessPattern,D.bigChessWidth,D.bigChessHeight);
 
@@ -570,61 +626,7 @@ namespace Lum {
 
         return true;
       }
-
-      void Display::EventLoop()
-      {
-        assert(exit);
-
-        exit=false;
-
-        HandleAsyncActions();
-        HandleEventLoopActions();
-        CheckTimers();
-
-        while (true) {
-          DWORD                   result;
-          MSG                     msg;
-          HANDLE                  handles[1];
-          ::Lum::Base::SystemTime tmp;
-
-          HandleAsyncActions();
-          HandleEventLoopActions();
-          CheckTimers();
-
-          while (::PeekMessage(&msg,NULL,0,0,PM_REMOVE)) {
-            if (msg.message==WM_QUIT) {
-              break;
-            }
-            ::DispatchMessage(&msg);
-            HandleAsyncActions();
-            HandleEventLoopActions();
-            CheckTimers();
-          }
-
-          if (exit) {
-            break;
-          }
-
-          handles[0]=0;
-          GetNextTimer(tmp);
-          result=::MsgWaitForMultipleObjectsEx(0,handles,tmp.GetTime()*1000+tmp.GetMicroseconds()/1000,QS_ALLINPUT,MWMO_INPUTAVAILABLE);
-
-          if (result==(WAIT_OBJECT_0+0)) {
-            continue;
-          }
-          else {
-            //DoStuff (result - WAIT_OBJECT_0) ;
-          }
-        }
-      }
-
-      void Display::Exit()
-      {
-        assert(!exit);
-
-        exit=true;
-      }
-
+      
       void Display::Close()
       {
         //std::list<Window*>::iterator win;
@@ -650,6 +652,8 @@ namespace Lum {
         */
 
         DestroyWindow(appWindow);
+        
+        delete eventLoop;
       }
 
       bool Display::GetMousePos(int& x, int& y) const
