@@ -1122,6 +1122,7 @@ namespace Lum {
             rightBorder=extent.right;
             topBorder=-extent.top;
             bottomBorder=extent.bottom;
+            transparentBorder=true;
           }
           else {
             leftBorder=2;
@@ -1687,6 +1688,8 @@ namespace Lum {
           break;
         case Display::tabBackgroundFillIndex:
           if (HasTheming()) {
+	        FillRect(dc,&rect,::GetSysColorBrush(COLOR_INFOBK));
+
             RECT content,extent,clip;
 
             content.left=xOff;
@@ -1711,6 +1714,8 @@ namespace Lum {
           break;
         case Display::tabRiderBackgroundFillIndex:
           if (HasTheming()) {
+            FillRect(dc,&rect,::GetSysColorBrush(COLOR_INFOBK));
+
             RECT content,extent,clip;
 
             // Extent of tab frame
@@ -2150,6 +2155,7 @@ namespace Lum {
         switch (frame) {
         case Display::tabFrameIndex:
           if (HasTheming()) {
+
             draw->PushClipBegin(x,y,w,h);
             draw->SubClipRegion(x+leftBorder,y+topBorder,w-minWidth,h-minHeight);
             draw->PushClipEnd();
@@ -2160,17 +2166,18 @@ namespace Lum {
 
             RECT clip;
 
-            rect.left=x+gx;
-            rect.right=rect.left+gw;
+            rect.left=x+gx+1;
+            rect.right=rect.left+gw-2;
             rect.bottom=y+topBorder;
             rect.top=rect.bottom-10;
 
-            clip.left=x+gx;
-            clip.right=clip.left+gw;
+            clip.left=x+gx+1;
+            clip.right=clip.left+gw-2;
             clip.top=y;
             clip.bottom=clip.top+topBorder;
 
-            /* ignore */ MyDrawThemeBackground(tabTheme,dc,TABP_TOPTABITEM,TTIS_SELECTED,&rect,&clip);
+            /* ignore */ MyDrawThemeBackground(tabTheme,dc,TABP_BODY,1,&rect,&clip);
+
           }
           else {
             draw->PushForeground(GetSysColor(COLOR_3DDKSHADOW));
@@ -2695,6 +2702,11 @@ namespace Lum {
       {
         return false;
       }
+      
+      OS::Theme::MenuType Win32Theme::GetMenuType() const
+      {
+	      return menuTypeStrip;
+      }
     }
   }
 }
