@@ -270,7 +270,7 @@ namespace Lum {
 
       Window::Window(OS::Display* display)
       : display(dynamic_cast<Display*>(display)),
-        grab(false),exit(true),
+        grab(false),
         oldPress(0),lastPress(0),thisPress(0),
         drawn(false),queueFocus(false),
         window(0)
@@ -567,58 +567,6 @@ namespace Lum {
         return false;
       }
 
-      void Window::EventLoop()
-      {
-        assert(exit);
-
-        exit=false;
-
-        if (type!=typeMenu && type!=typePopup) {
-          DisableParents();
-        }
-
-        while (true) {
-          DWORD                 result;
-          MSG                   msg;
-          HANDLE                handles[1];
-          Lum::Base::SystemTime tmp;
-
-          display->HandleAsyncActions();
-          display->HandleEventLoopActions();
-          display->CheckTimers();
-
-          while (::PeekMessage(&msg,NULL,0,0,PM_REMOVE)) {
-            if (msg.message==WM_QUIT) {
-              break;
-            }
-            ::DispatchMessage(&msg);
-
-            display->HandleAsyncActions();
-            display->HandleEventLoopActions();
-            display->CheckTimers();
-          }
-
-          if (exit) {
-            break;
-          }
-
-          handles[0]=0;
-          display->GetNextTimer(tmp);
-          result=::MsgWaitForMultipleObjectsEx(0,handles,tmp.GetTime()*1000+tmp.GetMicroseconds()/1000,QS_ALLINPUT,MWMO_INPUTAVAILABLE);
-
-          if (result == (WAIT_OBJECT_0+0)) {
-            continue;
-          }
-          else {
-            //DoStuff (result - WAIT_OBJECT_0) ;
-          }
-        }
-
-        if (type!=typeMenu && type!=typePopup) {
-        EnableParents();
-        }
-      }
-
       void Window::Enable()
       {
         OS::Base::Window::Enable();
@@ -645,11 +593,6 @@ namespace Lum {
         return true;
       }
 
-      bool Window::IsInEventLoop() const
-      {
-        return !exit;
-      }
-
       bool Window::IsDoubleClicked() const
       {
         return (lastButton.type==thisButton.type)
@@ -665,12 +608,6 @@ namespace Lum {
         return false;
       }
 
-      void Window::Exit()
-      {
-        assert(!exit);
-        exit=true;
-      }
-
       LRESULT Window::MessageHandler(HWND wnd,UINT msg, WPARAM wParam, LPARAM lParam)
       {
         HDC         dc;
