@@ -19,6 +19,8 @@
 
 #include <Lum/OS/X11/Display.h>
 
+#include <math.h>
+
 #include <cassert>
 
 #if defined(HAVE_UNISTD_H)
@@ -49,12 +51,25 @@
   #include <gdk-pixbuf-xlib/gdk-pixbuf-xlib.h>
 #endif
 
+#if defined(HAVE_LIB_DBUS) && !defined(HAVE_LIB_OSSO)
+  #include <dbus/dbus-glib-lowlevel.h>
+#endif
+
+#if defined(HAVE_LIB_GSTREAMER)
+  #include <gst/gst.h>
+#endif
+
 #include <Lum/Base/String.h>
 
 #include <Lum/Images/Image.h>
 
 #include <Lum/OS/Base/Theme.h>
 
+#include <Lum/OS/EventLoopUnix.h>
+#if defined(HAVE_LIB_GTK)
+  #include <Lum/OS/EventLoopGMainLoop.h>
+#endif
+
 #include <Lum/OS/X11/DrawInfo.h>
 #include <Lum/OS/X11/Font.h>
 #include <Lum/OS/X11/Image.h>
@@ -112,8 +127,9 @@ namespace Lum {
         "_NET_WM_WINDOW_TYPE_NORMAL",
         "_NET_WM_PING",
         "_NET_WM_PID",
-	"_NET_WM_STATE",
-	"_NET_WM_STATE_FULLSCREEN",
+        "_NET_WM_STATE",
+        "_NET_WM_STATE_FULLSCREEN",
+        "_NET_WM_CONTEXT_CUSTOM",
         "_NET_SYSTEM_TRAY_OPCODE",
         "_NET_SYSTEM_TRAY_MESSAGE_DATA",
         "_NET_WORKAREA",
@@ -128,45 +144,69 @@ namespace Lum {
       static const int sleepCursor=150;
       static const int popCursor=94;
       static const int dndCursor=50;
-#if defined(HAVE_LIB_DBUS)
+
+#if defined(HAVE_LIB_DBUS) || defined(HAVE_LIB_OSSO)
       static const char* dbusDomain="org.teulings.illumination";
 #endif
 
       const char* unicodeEncoding="iso10646-1";
 
-      /*
-      class SleepDesc : public ::Lum::OS::Display::SleepDesc
+      class LUMAPI X11EventSource : public EventSource
       {
-        protected:
-        Sleep next;
-        ::Lum::Base::Object::MsgObject object;
-      };
+      private:
+        Display *display;
 
-      class ChannelDesc : public ::Lum::OS::Display::ChannelDesc
-      {
-        protected:
-        Channel next;
-        SelectionKey key;
-        ::Lum::Base::Object::MsgObject object;
-        void SendNotify();
-      };
+      public:
+        X11EventSource(Display *display)
+        {
+          this->display=display;
+        }
 
-      class PenDashDesc
-      {
-        protected:
-        PenDash next;
-        char *list;
-        int mode;
-      };
+        bool Matches(const Model::Action* action) const
+        {
+          return false;
+        }
 
-      class PatternDesc
-      {
-        protected:
-        Pattern next;
-        Pixmap pixMap;
-        int mode;
+        bool GetTimeout(Lum::Base::SystemTime& time) const
+        {
+          return false;
+        }
+
+        bool GetFileIO(FileIO& fileIO) const
+        {
+          fileIO.file=ConnectionNumber(display->display);
+          fileIO.conditions=ioRead;
+
+          return true;
+        }
+
+        bool DataAvailable() const
+        {
+          return XPending(display->display)>0;
+        }
+
+        bool DataAvailable(Lum::Base::SystemTime& time) const
+        {
+          return false;
+        }
+
+        bool DataAvailable(const FileIO& fileIO) const
+        {
+          return fileIO.file==ConnectionNumber(display->display) && (fileIO.conditions & ioRead);
+        }
+
+        void Trigger()
+        {
+          while (XPending(display->display)>0) {
+            display->GetEvent();
+          }
+        }
+
+        bool IsFinished() const
+        {
+          return false;
+        }
       };
-*/
 
       double Display::GetDPI() const
       {
@@ -268,7 +308,7 @@ namespace Lum {
                 return dragWin;
               }
 
-         #endif
+#endif
 
       /**
         Get the Illumination window matching the given X11 window.
@@ -628,84 +668,6 @@ namespace Lum {
         XFreeColors(display,colorMap,&color,1,0);
       }
 
-#if 0
-
-      Sleep Display::AddSleep(Lum::Base::Object::MsgObject object)
-      {
-        Sleep sleep;
-
-
-        sleep=new Sleep;
-        sleep.object=object;
-        sleep.next=d.sleepList;
-        d.sleepList=sleep;
-        return sleep;
-      }
-
-      void Display::RemoveSleep(OS::Sleep sleep)
-      {
-        Sleep help;
-        Sleep last;
-        if (d.sleepList==NULL) {
-          return ;
-        }
-        if (d.sleepList==sleep) {
-          d.sleepList=d.sleepList.next;
-          return ;
-        }
-        help=d.sleepList.next;
-        last=d.sleepList;
-        while ((help!=NULL) && (help!=sleep)) {
-          last=help;
-          help=help.next;
-        }
-        if (help!=NULL) {
-          last.next=help.next;
-        }
-      }
-
-      Channel Display::AddChannel(Channel channel, unsigned long ops, OS::Object::MsgObject object)
-      {
-        Channel entry;
-
-
-        entry=new Channel;
-        entry.channel=channel;
-        entry.object=object;
-        entry.next=d.channelList;
-        d.channelList=entry;
-        entry.key=channel.RegisterWithSelector(d.selector,ops,NULL);
-        return entry;
-      }
-
-      void Display::RemoveChannel(OS::Channel channel)
-      {
-        Channel help;
-        Channel last;
-        if (channel(Channel).key!=NULL) {
-          channel(Channel).key.Cancel;
-          channel(Channel).key=NULL;
-        }
-        if (d.channelList==NULL) {
-          return ;
-        }
-        if (d.channelList==channel) {
-          d.channelList=d.channelList.next;
-          return ;
-        }
-        help=d.channelList.next;
-        last=d.channelList;
-        while ((help!=NULL) && (help!=channel)) {
-          last=help;
-          help=help.next;
-        }
-        if (help!=NULL) {
-          last.next=help.next;
-        }
-      }
-
-#endif
-
 /*      ::Lum::OS::Bitmap Display::CreateBitmapPattern(char pattern[], int width, int height)
       {
         ::Lum::OS::Bitmap bitmap;
@@ -753,80 +715,32 @@ namespace Lum {
       }
 #endif
 
-#if defined(HAVE_LIB_DBUS)
-      static dbus_bool_t AddWatch(DBusWatch *watch, void *data)
+#if defined(HAVE_LIB_OSSO)
+      osso_context_t* Display::InitializeLibOsso()
       {
-        if (!dbus_watch_get_enabled(watch)) {
-          return true;
+        osso_context_t* context;
+        std::string     appName;
+        std::string     serviceName;
+
+        appName=Lum::Base::WStringToString(GetAppName());
+        for (size_t i=0; i<appName.length(); ++i) {
+          appName[i]=tolower(appName[i]);
         }
 
-        Display::DBusWatchEntry handle;
-        Display                 *display=static_cast<Display*>(data);
+        serviceName=std::string(dbusDomain)+"."+appName;
 
-        handle.watch=watch;
+        context=osso_initialize(serviceName.c_str(),"1.0",FALSE,
+                                dynamic_cast<GMainLoopEventLoop*>(eventLoop)->context);
 
-        display->dbusWatches.push_back(handle);
-
-        return true;
-      }
-
-      static void RemoveWatch(DBusWatch *watch, void *data)
-      {
-        //std::cout << "RemoveWatch " << dbus_watch_get_unix_fd(watch) << " " << dbus_watch_get_flags(watch) << std::endl;
-      }
-
-      static void WatchToggled(DBusWatch *watch, void *data)
-      {
-        //std::cout << "WatchToggled " << dbus_watch_get_enabled(watch) << std::endl;
-
-        if (dbus_watch_get_enabled(watch)) {
-          AddWatch(watch,data);
-        }
-        else {
-          RemoveWatch(watch,data);
-        }
-      }
-
-      static dbus_bool_t AddTimeout(DBusTimeout *timeout, void *data)
-      {
-        //std::cout << "AddTimeout " << dbus_timeout_get_interval(timeout) << std::endl;
-
-        if (!dbus_timeout_get_enabled(timeout)) {
-          return true;
+        if (context!=NULL) {
+          dbusSession=(DBusConnection*)osso_get_dbus_connection(context);
+          dbusSystem=(DBusConnection*)osso_get_sys_dbus_connection(context);
         }
 
-        Display::DBusTimeoutEntry handle;
-        Display                   *display=static_cast<Display*>(data);
-
-        handle.timeout=timeout;
-
-        display->dbusTimeouts.push_back(handle);
-
-        return true;
+        return context;
       }
-
-      static void RemoveTimeout(DBusTimeout *timeout, void *data)
-      {
-        //std::cout << "RemoveTimeout " << dbus_timeout_get_interval(timeout) << std::endl;
-      }
-
-      static void TimeoutToggled(DBusTimeout *timeout, void *data)
-      {
-        //std::cout << "TimeoutToggled" << std::endl;
-
-        if (dbus_timeout_get_enabled(timeout)) {
-          AddTimeout(timeout,data);
-        }
-        else {
-          RemoveTimeout(timeout,data);
-        }
-      }
-
-      static void WakeupMain(void *data)
-      {
-        //std::cout << "WakeupMain" << std::endl;
-      }
-
+#elif defined(HAVE_LIB_DBUS)
+      /*
       static DBusHandlerResult DBusMsgHandler(DBusConnection *connection, DBusMessage *msg, void *data)
       {
         const char* interface;
@@ -846,8 +760,11 @@ namespace Lum {
         }
 
         interface=dbus_message_get_interface(msg);
+        if (interface==NULL) {
+          return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
+        }
 
-        //std::out << "Got a " <<  type << " " <<  (isMethod?"to":"from") << " interface '" << interface << "' '" << dbus_message_get_path(msg) << "' '" << dbus_message_get_member(msg) << "'" << std::endl;
+        std::cout << "Got a " <<  type << " " <<  (isMethod? "to" : "from") << " interface '" << interface << "' '" << dbus_message_get_path(msg) << "' '" << dbus_message_get_member(msg) << "'" << std::endl;
 
         if (dbus_message_get_type(msg)==DBUS_MESSAGE_TYPE_METHOD_CALL) {
           DBusMessage *response;
@@ -862,38 +779,18 @@ namespace Lum {
           response=dbus_message_new_error(msg,error.c_str(),"Message not implemented");
           dbus_connection_send(connection,response,NULL);
           dbus_message_unref(response);
+          return DBUS_HANDLER_RESULT_HANDLED;
         }
 
-        return DBUS_HANDLER_RESULT_HANDLED;
-//          return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
-/*
-364     for(i=0; i<osso->ifs->len; i++) {
-365         _osso_interface_t *intf;
-366         DBusHandlerResult r;
-367         intf = &g_array_index(osso->ifs, _osso_interface_t, i);
-368         if(intf->method == is_method) {
-369             dprint("comparing '%s' to '%s'",interface, intf->interface);
-370             if(strcmp(interface, intf->interface) == 0) {
-371                 dprint("match!, now calling callback at %p", intf->handler);
-372                 r = (intf->handler)(osso, msg, intf->data);
-373                 if(r == DBUS_HANDLER_RESULT_HANDLED) {
-374                     return r;
-375                 }
-376             }
-377         }
-378     }
-379
-380     return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;*/
-      }
+        return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
+      }*/
 
       DBusConnection *Display::InitiateDBusConnection(DBusBusType busType)
       {
-        DBusConnection       *connection;
-        DBusError            err;
-        //DBusObjectPathVTable vtable;
-        std::string          appName;
-        std::string          serviceName;
-        std::string          objectName;
+        DBusConnection *connection;
+        DBusError      err;
+        std::string    appName;
+        std::string    serviceName;
 
         dbus_error_init(&err);
 
@@ -904,53 +801,22 @@ namespace Lum {
           return NULL;
         }
 
-        dbus_connection_set_exit_on_disconnect(connection,false);
-        /* ignore */dbus_connection_set_watch_functions(connection,
-                                                        AddWatch,
-                                                        RemoveWatch,
-                                                        WatchToggled,
-                                                        (void*)this,
-                                                        NULL);
-
-        /* ignore */dbus_connection_set_timeout_functions(connection,
-                                                          AddTimeout,
-                                                          RemoveTimeout,
-                                                          TimeoutToggled,
-                                                          (void*)this,
-                                                          NULL);
-
-        dbus_connection_set_wakeup_main_function(connection,
-                                                 WakeupMain,
-                                                 (void*)this,
-                                                 NULL);
-
+        dbus_connection_setup_with_g_main(connection,
+                                          dynamic_cast<Lum::OS::GMainLoopEventLoop*>(eventLoop)->context);
 
         appName=Lum::Base::WStringToString(GetAppName());
         for (size_t i=0; i<appName.length(); ++i) {
           appName[i]=tolower(appName[i]);
         }
 
-//        if (busType==DBUS_BUS_SESSION) {
           serviceName=std::string(dbusDomain)+"."+appName;
 
           if (dbus_bus_request_name(connection,serviceName.c_str(),DBUS_NAME_FLAG_ALLOW_REPLACEMENT,&err)==-1) {
             //std::cerr << "Cannot request name '" << serviceName << "': "<< err.message << std::endl;
             dbus_error_free(&err);
           }
-//        }
 
-        /*
-        vtable.message_function=DBusMsgHandler;
-        vtable.unregister_function=NULL;
-
-        objectName="/or/teulings/illumination/"+appName;
-
-        if(!dbus_connection_register_object_path(connection,objectName.c_str(),&vtable,NULL)) {
-          std::cerr << "Cannot register object '" << objectName << "'" << std::endl;
-        }
-        */
-
-        dbus_connection_add_filter(connection,DBusMsgHandler,NULL,NULL);
+        //dbus_connection_add_filter(connection,DBusMsgHandler,NULL,NULL);
 
         dbus_connection_set_exit_on_disconnect(connection,false);
 
@@ -958,108 +824,6 @@ namespace Lum {
       }
 #endif
 
-#if defined(HAVE_LIB_GSTREAMER)
-      static GstBusSyncReply gstMessageHandler(GstBus*, GstMessage *message, gpointer data)
-      {
-        Display *display=static_cast<Display*>(data);
-
-        if (GST_MESSAGE_TYPE(message)==GST_MESSAGE_ERROR) {
-          GError *error;
-          char   *text;
-
-          gst_message_parse_error(message,&error,&text);
-
-          std::cerr << "gstreamer ERROR: " << text << std::endl;
-
-         g_free(error);
-         g_free(text);
-       }
-       else if (GST_MESSAGE_TYPE(message)==GST_MESSAGE_WARNING) {
-         GError *error;
-         char   *text;
-
-         gst_message_parse_warning(message,&error,&text);
-
-         std::cerr << "gstreamer WARNING: " << text << std::endl;
-
-         g_free(error);
-         g_free(text);
-      }
-	
-      message=gst_message_copy(message);
-
-      display->HandleGstMessage(message);
-
-      // We don't free the message here, that will be done later in the main event loop
-      return GST_BUS_PASS;
-    }
-
-      void Display::AddGstListener(GstElement* element, Model::Action* action, bool async)
-      {
-        Guard<Mutex> guard(gstMutex);
-
-        assert(element!=NULL && action!=NULL);
-
-        GstListener listener;
-
-        GstBus *bus;
-
-        bus=gst_element_get_bus(element);
-
-        if (!gstSyncSet) {
-          gstSyncSet=true;
-          gst_bus_set_sync_handler(bus,gstMessageHandler,this);
-        }
-
-        gst_object_unref(bus);
-
-        listener.async=async;
-        listener.element=element;
-        listener.action=action;
-
-        gstListener.push_back(listener);
-      }
-
-      void Display::RemoveGstListener(Model::Action* action)
-      {
-        assert(action!=NULL);
-
-        std::list<GstListener>::iterator iter;
-
-        iter=gstListener.begin();
-        while (iter!=gstListener.end()) {
-          if (iter->action.Get()==action) {
-            iter=gstListener.erase(iter);
-          }
-          else {
-            ++iter;
-          }
-        }
-      }
-
-      void Display::HandleGstMessage(GstMessage *message)
-      {
-        Guard<Mutex> guard(gstMutex);
-
-        // First handle sync notification requests
-        for (std::list<GstListener>::iterator iter=gstListener.begin(); iter!=gstListener.end(); ++iter) {
-          if (!iter->async && message->src==GST_OBJECT(iter->element)) {
-            GstMsg msg;
-
-            msg.message=message;
-            iter->action->Trigger(msg);
-            gst_message_unref(message);
-            return;
-          }
-        }
-
-        // Now handle async notification requests
-        gstMessages.push_back(message);
-
-        SignalEventLoop();
-      }
-#endif
-
       Display::Display()
       : currentWin(NULL),
         selectObject(NULL),
@@ -1068,19 +832,24 @@ namespace Lum {
         selClearPend(false),
         contextHelp(true),
         dropWindow(NULL),
-        exit(true),
         appWindow(0),
         scrNum(0),
         display(NULL),
         visual(NULL),
         xim(0)
-#if defined(HAVE_LIB_DBUS)
+#if defined(HAVE_LIB_OSSO)
+        ,ossoContext(NULL)
+#endif
+
+#if defined(HAVE_LIB_DBUS) || defined(HAVE_LIB_OSSO)
         ,dbusSession(NULL),
         dbusSystem(NULL)
 #endif
-#if defined(HAVE_LIB_GSTREAMER)
-        ,gstSyncSet(false)
-#endif
+      {
+        // no code
+      }
+
+      Display::~Display()
       {
         // no code
       }
@@ -1150,13 +919,16 @@ namespace Lum {
         colorMap=XDefaultColormap(display,scrNum);
 #endif
 
-#if defined(HAVE_LIB_GSTREAMER)
+#if defined(HAVE_LIB_GTK)
+        eventLoop=new GMainLoopEventLoop();
+  #if defined(HAVE_LIB_GSTREAMER)
         gst_init(NULL,NULL);
+  #endif
+#else
+        eventLoop=new UnixEventLoop();
 #endif
+        eventLoop->AddSource(new X11EventSource(this));
 
-        if (pipe(signalPipe)!=0) {
-          std::cerr << "Cannot create signal pipe!" << std::endl;
-        }
 
         Images::Factory::Set(driver->CreateImageFactory(this));
 
@@ -1167,7 +939,7 @@ namespace Lum {
 
         EvaluateDisplaySize();
 
-        dpi=XDisplayHeight(display,scrNum)/(XDisplayHeightMM(display,scrNum)/25.4);
+        dpi=round((XDisplayHeight(display,scrNum)*25.4)/XDisplayHeightMM(display,scrNum));
         /*
         int            eventBase,errorBase;
 
@@ -1245,9 +1017,11 @@ namespace Lum {
           return false;
         }
 
+        XInternAtoms(display,(char**)atomNames,atomCount,false,atoms);
+        /*
         for (size_t i=0; i<atomCount; i++) {
           atoms[i]=XInternAtom(display,atomNames[i],False);
-        }
+        }*/
 
                       /*
         D.smallChess:=d.CreateBitmapPattern(D.disablePattern,D.disableWidth,D.disableHeight);
@@ -1431,7 +1205,14 @@ namespace Lum {
         }
 #endif
 
-#if defined(HAVE_LIB_DBUS)
+#if defined(HAVE_LIB_OSSO)
+        ossoContext=InitializeLibOsso();
+        if (ossoContext==NULL) {
+          std::cerr << "Cannot create OSSO context!" << std::endl;
+        }
+#elif defined(HAVE_LIB_DBUS)
+        dbus_g_thread_init ();
+
         dbusSession=InitiateDBusConnection(DBUS_BUS_SESSION);
         if (dbusSession==NULL) {
           std::cerr << "Cannot create session DBUS connection!" << std::endl;
@@ -1454,7 +1235,11 @@ namespace Lum {
 
         OS::Base::Display::Close();
 
-#if defined(HAVE_LIB_DBUS)
+#if defined(HAVE_LIB_OSSO)
+        if (ossoContext!=NULL) {
+          osso_deinitialize(ossoContext);
+        }
+#elif defined(HAVE_LIB_DBUS)
         if (dbusSystem!=NULL) {
           dbus_connection_unref(dbusSystem);
         }
@@ -1463,6 +1248,7 @@ namespace Lum {
         }
 #endif
 
+
 #if 0
         if (smSession!=NULL) {
           SmcCloseConnection(smSession,0,NULL);
@@ -1497,14 +1283,13 @@ namespace Lum {
           }
         }
 
-        close(signalPipe[0]);
-        close(signalPipe[1]);
-
 #if defined(HAVE_LIB_CAIRO) && defined(CAIRO_HAS_XLIB_SURFACE)
         Cairo::FreeGlobalCairo();
         Cairo::FreeGlobalSurface();
 #endif
 
+        delete eventLoop;
+
 #if !defined(HAVE_LIB_GTK)
         if (display!=NULL) {
           XCloseDisplay(display);
@@ -1720,26 +1505,6 @@ namespace Lum {
         return ::XGetSelectionOwner(display,atoms[clipboardAtom])!=None;
       }
 
-      void Display::PutBackEvent(OS::Event* event,
-                                 OS::Window* destWin)
-      {
-        XEvent x11Event;
-
-        GetX11Event(event,x11Event);
-        x11Event.xany.window=dynamic_cast<Window*>(destWin)->window;
-        if (XSendEvent(display,dynamic_cast<Window*>(destWin)->window,
-                       True,NoEventMask,&x11Event)==0) {
-          std::cerr << "Cannot resend event!" << std::endl;
-        }
-      }
-
-      void Display::Exit()
-      {
-        assert(!exit);
-
-        exit=true;
-      }
-
       void Display::ReinitWindows()
       {
         std::list<Window*>::iterator win;
@@ -1752,28 +1517,6 @@ namespace Lum {
         }
       }
 
-#if 0
-      /**
-       Check the list of registered sleeps and send a message for every elapsed
-       timeout.
-      */
-      void Display::CheckSleeps()
-      {
-        Sleep        sleep;
-        OS::SleepMsg msg;
-
-        sleep=d.sleepList;
-        while (sleep!=NULL) {
-
-          msg=new SleepMsg;
-          msg.sleep=sleep;
-          sleep.object.Receive(msg);
-          sleep=sleep.next;
-        }
-      }
-
-#endif
-
       /**
         Handle the XSelecitionNotify of X11. A SelectionNotify gets send
         as a result of our request for the selection value. The event states
@@ -1885,7 +1628,7 @@ namespace Lum {
           if (!text.empty()) {
             XChangeProperty(event.display,event.requestor,event.property,
                             XA_STRING,8,
-                            PropModeReplace,(unsigned char*)text.c_str(),
+                            PropModeReplace,(const unsigned char*)text.c_str(),
                             text.length());
           }
         }
@@ -1987,144 +1730,6 @@ namespace Lum {
         File descriptors getting available will be handled internaly. In this
         case a notification will be send and the wait will be restarted.
       */
-      bool Display::Wait()
-      {
-
-        while (true) {
-          fd_set                readSet,writeSet;
-          int                   ret;
-          Lum::Base::SystemTime tmp;
-          int                   max;
-          int                   x11Fd;
-
-          x11Fd=ConnectionNumber(display);
-
-          FD_ZERO(&readSet);
-          FD_ZERO(&writeSet);
-
-          FD_SET(x11Fd,&readSet);
-          max=x11Fd;
-
-          FD_SET(signalPipe[0],&readSet);
-          max=std::max(max,signalPipe[0]);
-#if 0
-          FD_SET(iceFd,&readSet);
-          max=std::max(max,iceFd);
-#endif
-
-#if defined(HAVE_LIB_DBUS)
-          for (std::list<DBusWatchEntry>::const_iterator iter=dbusWatches.begin(); iter!=dbusWatches.end(); ++iter) {
-            if (dbus_watch_get_flags(iter->watch) & DBUS_WATCH_READABLE) {
-#ifdef HAVE_LIB_HILDON
-              FD_SET(dbus_watch_get_fd(iter->watch),&readSet);
-              max=std::max(max,dbus_watch_get_fd(iter->watch));
-#else
-              FD_SET(dbus_watch_get_unix_fd(iter->watch),&readSet);
-              max=std::max(max,dbus_watch_get_unix_fd(iter->watch));
-#endif
-            }
-
-            if (dbus_watch_get_flags(iter->watch) & DBUS_WATCH_WRITABLE) {
-#ifdef HAVE_LIB_HILDON
-              FD_SET(dbus_watch_get_fd(iter->watch),&writeSet);
-              max=std::max(max,dbus_watch_get_fd(iter->watch));
-#else
-              FD_SET(dbus_watch_get_unix_fd(iter->watch),&writeSet);
-              max=std::max(max,dbus_watch_get_unix_fd(iter->watch));
-#endif
-            }
-          }
-#endif
-          if (GetNextTimer(tmp)) {
-            timeval timeout;
-
-            tmp.GetTimeval(timeout);
-
-            ret=select(max+1,&readSet,&writeSet,NULL,&timeout);
-          }
-          else {
-            ret=select(max+1,&readSet,&writeSet,NULL,NULL);
-          }
-
-          if (ret==-1) {
-            std::cerr << "Error while selecting...!" << std::endl;
-          }
-          else if (ret>=0) {
-            if (FD_ISSET(signalPipe[0],&readSet)) {
-              char buffer[2];
-
-              if (read(signalPipe[0],(void*)buffer,(size_t)1)==1) {
-#if defined(HAVE_LIB_GSTREAMER)
-                {
-                  Guard<Mutex> guard(gstMutex);
-
-                  while (gstMessages.begin()!=gstMessages.end()) {
-                    for (std::list<GstListener>::iterator iter=gstListener.begin(); iter!=gstListener.end(); ++iter) {
-                      if (iter->async && (*gstMessages.begin())->src==GST_OBJECT(iter->element)) {
-                        GstMsg msg;
-
-                        msg.message=*gstMessages.begin();
-                        iter->action->Trigger(msg);
-                      }
-                    }
-
-                    gst_message_unref(*gstMessages.begin());
-                    gstMessages.erase(gstMessages.begin());
-                  }
-                }
-#endif
-              }
-              else {
-                std::cerr << "Error getting signal!" << std::endl;
-              }
-            }
-#if 0
-            if (FD_ISSET(iceFd,&readSet)) {
-              if (IceProcessMessages(iceSession,NULL,NULL)==IceProcessMessagesIOError) {
-                std::cerr << "Error during processing of Ice message!" << std::endl;
-              }
-            }
-#endif
-
-#if defined(HAVE_LIB_DBUS)
-            for (std::list<DBusWatchEntry>::const_iterator iter=dbusWatches.begin(); iter!=dbusWatches.end(); ++iter) {
-              if (dbus_watch_get_flags(iter->watch) & DBUS_WATCH_READABLE) {
-#ifdef HAVE_LIB_HILDON
-                if (FD_ISSET(dbus_watch_get_fd(iter->watch),&readSet)) {
-#else
-                if (FD_ISSET(dbus_watch_get_unix_fd(iter->watch),&readSet)) {
-#endif
-                  dbus_watch_handle(iter->watch,DBUS_WATCH_READABLE);
-                }
-              }
-              if (dbus_watch_get_flags(iter->watch) & DBUS_WATCH_WRITABLE) {
-#ifdef HAVE_LIB_HILDON
-                if (FD_ISSET(dbus_watch_get_fd(iter->watch),&writeSet)) {
-#else
-                if (FD_ISSET(dbus_watch_get_unix_fd(iter->watch),&writeSet)) {
-#endif
-                  dbus_watch_handle(iter->watch,DBUS_WATCH_WRITABLE);
-                }
-              }
-            }
-
-            if (dbusSystem!=NULL) {
-              while (dbus_connection_get_dispatch_status(dbusSystem)==DBUS_DISPATCH_DATA_REMAINS) {
-                dbus_connection_dispatch(dbusSystem);
-              }
-            }
-
-            if (dbusSession!=NULL) {
-              while (dbus_connection_get_dispatch_status(dbusSession)==DBUS_DISPATCH_DATA_REMAINS) {
-              dbus_connection_dispatch(dbusSession);
-              }
-            }
-#endif
-            return true;
-          }
-        }
-      }
-
       bool Display::WaitTimedForX11Event(::Window window, int eventType, XEvent& event) const
       {
         Lum::Base::SystemTime timer,max;
@@ -2165,40 +1770,6 @@ namespace Lum {
 
       }
 
-      void Display::SignalEventLoop()
-      {
-        write(signalPipe[1],"+",1);
-      }
-
-      void Display::EventLoop()
-      {
-        assert(exit);
-
-        exit=false;
-
-        HandleAsyncActions();
-        HandleEventLoopActions();
-        CheckTimers();
-
-        while (true) {
-          if (XEventsQueued(display,QueuedAlready)==0 && XEventsQueued(display,QueuedAfterFlush)==0) {
-            Wait();
-          }
-
-          if (XEventsQueued(display,QueuedAfterReading)>0) {
-            GetEvent();
-          }
-
-          HandleAsyncActions();
-          HandleEventLoopActions();
-          CheckTimers();
-
-          if (exit) {
-            break;
-          }
-        }
-      }
-
       bool Display::GetMousePos(int& x, int& y) const
       {
         ::Window     root;
@@ -2248,13 +1819,13 @@ namespace Lum {
 
         std::cout << "CallbackSaveYourself" << std::endl;
 
-        vals.program->value=(void*)programName.c_str();
+        vals.program->value=(void*)const_cast<wchar_t*>(programName.c_str());
         vals.program->length=programName.length();
 
 #if HAVE_PWD_H
         struct passwd *pw = getpwuid(getuid());
 
-        vals.user->value=(void*) (pw ? pw->pw_name : "");
+        vals.user->value=(void*)const_cast<char*>(pw ? pw->pw_name : "");
         vals.user->length=strlen((const char*)vals.user->value);
 #endif
 
@@ -2263,7 +1834,7 @@ namespace Lum {
         vals.hint->value=&restartStyle;
         vals.hint->length=1;
 
-        vals.restart->value=(void*)programName.c_str();
+        vals.restart->value=(void*)const_cast<wchar_t*>(programName.c_str());
         vals.restart->length=programName.length();
 
         SmcSetProperties(smc_conn,sizeof(props)/sizeof(SmProp*),props);
