@@ -43,7 +43,7 @@ namespace Lum {
         Initialize an instance of the  DrawInfo class.
       */
       DrawInfo::DrawInfo(Lum::OS::Window* window)
-      : ::Lum::OS::Base::DrawInfo(window)
+      : Base::DrawInfo(window)
 #ifdef HAVE_LIB_GTK
         ,gdkPixmap(NULL)
         ,gdkWindow(NULL)
@@ -56,7 +56,7 @@ namespace Lum {
       }
 
       DrawInfo::DrawInfo(Lum::OS::Bitmap* bitmap)
-      : ::Lum::OS::Base::DrawInfo(bitmap)
+      : Base::DrawInfo(bitmap)
  #ifdef HAVE_LIB_GTK
         ,gdkPixmap(NULL)
         ,gdkWindow(NULL)
@@ -364,10 +364,10 @@ namespace Lum {
 
 #if SIZEOF_WCHAR_T == 4
           XftDrawString32(xftgc,&color,font->xftfonts[pos],x,y,
-                          (XftChar32*)text.data()+start,length);
+                          (const XftChar32*)text.data()+start,length);
 #else
           XftDrawString16(xftgc,&color,font->xftfonts[pos],x,y,
-                          (XftChar16*)text.data+start,length);
+                          (const XftChar16*)text.data+start,length);
 #endif
 
           if (Font::underlined & fontStack.top().style) {
@@ -376,11 +376,11 @@ namespace Lum {
 #if SIZEOF_WCHAR_T == 4
             XftTextExtents32(dynamic_cast<Display*>(OS::display)->display,
                              font->xftfonts[pos],
-                             (XftChar32*)text.data()+start,length,&info);
+                             (const XftChar32*)text.data()+start,length,&info);
 #else
             XftTextExtents16(dynamic_cast<Display*>(OS::display)->display,
                              font->xftfonts[pos],
-                             (XftChar16*)text.data()+start,length),&info);
+                             (const XftChar16*)text.data()+start,length),&info);
 #endif
             DrawLine(x,y,x-info.x+info.xOff,y);
           }
@@ -432,11 +432,11 @@ namespace Lum {
 #if SIZEOF_WCHAR_T == 4
           XftTextExtents32(dynamic_cast<Display*>(OS::display)->display,
                            font->xftfonts[pos],
-                           (XftChar32*)text.c_str(),text.length(),&info);
+                           (const XftChar32*)text.c_str(),text.length(),&info);
 #else
           XftTextExtents16(dynamic_cast<Display*>(OS::display)->display,
                            font->xftfonts[pos],
-                           (XftChar16*)text.c_str(),text.length(),&info);
+                           (const XftChar16*)text.c_str(),text.length(),&info);
 #endif
 
           PushForeground(background);
@@ -456,10 +456,10 @@ namespace Lum {
 
 #if SIZEOF_WCHAR_T == 4
           XftDrawString32(xftgc,&color,font->xftfonts[pos],x,y,
-                          (XftChar32*)text.c_str(),text.length());
+                          (const XftChar32*)text.c_str(),text.length());
 #else
           XftDrawString16(xftgc,&color,font->xftfonts[pos],x,y,
-                          (XftChar16*)text.c_str(),text.length());
+                          (const XftChar16*)text.c_str(),text.length());
 #endif
 
           handled=true;
@@ -792,7 +792,7 @@ namespace Lum {
         XDrawPoint(display,drawable,gc,x,y);
       }
 
-      void DrawInfo::DrawPointWithColor(int x, int y, ::Lum::OS::Color color)
+      void DrawInfo::DrawPointWithColor(int x, int y, Color color)
       {
         XSetForeground(display,gc,color);
         XDrawPoint(display,drawable,gc,x,y);
@@ -858,7 +858,7 @@ namespace Lum {
                   dX,dY);
       }
 
-      void DrawInfo::CopyToBitmap(int sX, int sY, int width, int height, int dX, int dY, ::Lum::OS::Bitmap* bitmap)
+      void DrawInfo::CopyToBitmap(int sX, int sY, int width, int height, int dX, int dY, OS::Bitmap* bitmap)
       {
         //XSetGraphicsExposures(display,gc,True);
         XCopyArea(display,drawable,
