@@ -20,6 +20,7 @@
 #include <Lum/OS/X11/Window.h>
 
 #include <cassert>
+#include <cstdlib>
 #include <cstring>
 
 #ifdef HAVE_UNISTD_H
@@ -143,7 +144,7 @@ namespace Lum {
 
       Window::Window(OS::Display* display)
       : display(dynamic_cast<Display*>(display)),
-        grab(false),exit(true),oldPress(0),lastPress(0),thisPress(0),balloonId(0),
+        oldPress(0),lastPress(0),thisPress(0),balloonId(0),
         window(0),fullScreen(false),xic(0)
       {
       }
@@ -191,46 +192,13 @@ namespace Lum {
         }
       }
 
-      /**
-        Grabs the mouse cursor and keyboard.
-      */
-      void Window::GrabOn()
-      {
-        display->StopContextHelp();
-        if (XGrabPointer(display->display,window,
-                         False,
-                         StructureNotifyMask|ButtonPressMask|ButtonReleaseMask|ButtonMotionMask|PointerMotionMask|PointerMotionHintMask|LeaveWindowMask|EnterWindowMask|VisibilityChangeMask|FocusChangeMask,
-                         GrabModeAsync,GrabModeAsync,
-                         None,
-                         None,
-                         CurrentTime)!=GrabSuccess) {
-          std::cerr << "Cannot grab pointer" << std::endl;
-        }
-        if (XGrabKeyboard(display->display,window,
-                          False,
-                          GrabModeAsync,GrabModeAsync,
-                          CurrentTime)!=GrabSuccess) {
-          std::cerr << "Cannot grab keyboard" << std::endl;
-        }
-      }
-
-      /**
-        Releases the grab of the mouse cursor and the keyboard.
-      */
-      void Window::GrabOff()
-      {
-        XUngrabPointer(display->display,CurrentTime);
-        XUngrabKeyboard(display->display,CurrentTime);
-        display->RestartContextHelp();
-      }
-
       void Window::OnFocusIn()
       {
         if (xic!=0) {
           XSetICFocus(xic);
-	}
+        }
 
-        if (!grab) {
+        if (!grabMouse) {
           display->StartContextHelp();
         }
 
@@ -239,7 +207,7 @@ namespace Lum {
 
       void Window::OnFocusOut()
       {
-        if (!grab) {
+        if (!grabMouse) {
           display->StopContextHelp();
         }
 
@@ -450,6 +418,11 @@ data        : POINTER TO ARRAY OF LONGINT;*/
             }
             return true;
           }
+          else if ((Atom)x11Event.xclient.data.l[0]==display->atoms[Display::netWMContextCustomAtom]) {
+#ifdef HAVE_LIB_HILDON
+            TriggerMenu();
+#endif
+          }
           break;
         case ConfigureNotify:
           while (XCheckTypedWindowEvent(display->display,this->window,ConfigureNotify,&x11Event)==True) {
@@ -569,8 +542,11 @@ data        : POINTER TO ARRAY OF LONGINT;*/
           RecalcWindowPosition();
           draw->OnMap();
           TriggerMaped();
-          if (grab) {
-            GrabOn();
+          if (grabMouse) {
+            MouseGrabOn();
+          }
+          if (grabKeyboard) {
+            KeyboardGrabOn();
           }
           return true;
         case FocusIn:
@@ -673,22 +649,39 @@ data        : POINTER TO ARRAY OF LONGINT;*/
         XResizeWindow(display->display,window,width,height);
       }
 
-      void Window::Grab(bool grab)
+      void Window::MouseGrabOn()
       {
-        if (this->grab==grab) {
-          return;
+        if (XGrabPointer(display->display,window,
+                         False,
+                         StructureNotifyMask|ButtonPressMask|ButtonReleaseMask|ButtonMotionMask|PointerMotionMask|PointerMotionHintMask|LeaveWindowMask|EnterWindowMask|VisibilityChangeMask|FocusChangeMask,
+                         GrabModeAsync,GrabModeAsync,
+                         None,
+                         None,
+                         CurrentTime)!=GrabSuccess) {
+          std::cerr << "Cannot grab pointer" << std::endl;
         }
-        this->grab=grab;
-        if (IsOpen()) {
-          if (this->grab) {
-            GrabOn();
-          }
-          else {
-            GrabOff();
-          }
+      }
+
+      void Window::MouseGrabOff()
+      {
+        XUngrabPointer(display->display,CurrentTime);
+      }
+
+      void Window::KeyboardGrabOn()
+      {
+        if (XGrabKeyboard(display->display,window,
+                          False,
+                          GrabModeAsync,GrabModeAsync,
+                          CurrentTime)!=GrabSuccess) {
+          std::cerr << "Cannot grab keyboard" << std::endl;
         }
       }
 
+      void Window::KeyboardGrabOff()
+      {
+        //XUngrabKeyboard(display->display,CurrentTime);
+      }
+
       bool Window::Open(bool activate)
       {
         XSizeHints           *sHints;
@@ -699,7 +692,7 @@ data        : POINTER TO ARRAY OF LONGINT;*/
         bool                 xManPos;
         bool                 yManPos;
         std::string          className;
-        Atom                 protocols[2];
+        Atom                 protocols[3];
 
         if (!Base::Window::Open(activate)) {
           return false;
@@ -772,7 +765,7 @@ data        : POINTER TO ARRAY OF LONGINT;*/
                         XNClientWindow,window,
                         XNFocusWindow,window,
                         NULL);
-	}
+        }
 /*
         if (xic==NULL) {
           XFree(sHints);
@@ -860,8 +853,9 @@ data        : POINTER TO ARRAY OF LONGINT;*/
 
         protocols[0]=display->atoms[Display::deleteProtAtom];
         protocols[1]=display->atoms[Display::netWMPingAtom];
+        protocols[2]=display->atoms[Display::netWMContextCustomAtom];
 
-        if (XSetWMProtocols(display->display,this->window,&protocols[0],2)==0) {
+        if (XSetWMProtocols(display->display,this->window,&protocols[0],3)==0) {
           std::cerr << "Warning: Cannot set supported window manager protocols" << std::endl;
         }
 
@@ -929,9 +923,9 @@ data        : POINTER TO ARRAY OF LONGINT;*/
       void Window::Close()
       {
         if (IsOpen() && (window!=0)) {
-          if (grab) {
-            GrabOff();
-          }
+          GrabMouse(false);
+          GrabKeyboard(false);
+
           /*
 
           if (parent!=NULL) {
@@ -1017,39 +1011,6 @@ data        : POINTER TO ARRAY OF LONGINT;*/
                              &rx,&ry,&x,&y,&bmask)!=False;
       }
 
-      void Window::EventLoop()
-      {
-        assert(exit);
-
-        exit=false;
-
-        DisableParents();
-
-        display->HandleAsyncActions();
-        display->HandleEventLoopActions();
-        display->CheckTimers();
-
-        while (true) {
-          if (XEventsQueued(display->display,QueuedAlready)==0 && XEventsQueued(display->display,QueuedAfterFlush)==0) {
-            display->Wait();
-          }
-
-          if (XEventsQueued(display->display,QueuedAfterReading)>0) {
-            display->GetEvent();
-          }
-
-          display->HandleAsyncActions();
-          display->HandleEventLoopActions();
-          display->CheckTimers();
-
-          if (exit) {
-            break;
-          }
-        }
-
-        EnableParents();
-      }
-
       void Window::Enable()
       {
         Base::Window::Enable();
@@ -1141,19 +1102,13 @@ data        : POINTER TO ARRAY OF LONGINT;*/
         return true;
       }
 
-      bool Window::IsInEventLoop() const
-      {
-
-        return !exit;
-      }
-
       bool Window::IsDoubleClicked() const
       {
         return (thisPress-lastPress<=display->multiClickTime)
           && (lastButton.type==thisButton.type)
           && (lastButton.qualifier==thisButton.qualifier)
-          && (abs(lastButton.x-thisButton.x)<5)
-          && (abs(lastButton.y-thisButton.y)<5);
+          && (std::abs(lastButton.x-thisButton.x)<5)
+          && (std::abs(lastButton.y-thisButton.y)<5);
       }
 
       bool Window::IsTrippleClicked() const
@@ -1162,13 +1117,6 @@ data        : POINTER TO ARRAY OF LONGINT;*/
         //return (w.oldButton.type==w.lastButton.type) && (w.oldButton.qualifier==w.lastButton.qualifier) && (ABS(w.oldButton.x-w.lastButton.x)<5) && (ABS(w.oldButton.y-w.lastButton.y)<5) && (w.lastPress-w.oldPress<=D.display(Display).multiClickTime) && (w.lastButton.type==w.thisButton.type) && (w.lastButton.qualifier==w.thisButton.qualifier) && (ABS(w.lastButton.x-w.thisButton.x)<5) && (ABS(w.lastButton.y-w.thisButton.y)<5) && (w.thisPress-w.lastPress<=D.display(Display).multiClickTime);
       }
 
-      void Window::Exit()
-      {
-        assert(!exit);
-
-        exit=true;
-      }
-
       bool Window::SetFullScreen()
       {
         assert(window!=0);
