@@ -91,9 +91,6 @@ namespace Lum {
     oX(0),oY(0),oWidth(0),oHeight(0),
     oMinWidth(0),oMinHeight(0),
     oMaxWidth(0),oMaxHeight(0),
-    setWidth(),setHeight(),
-    setMinWidth(),setMinHeight(),
-    setMaxWidth(),setMaxHeight(),
     horizontalFlex(false),verticalFlex(false),
     visible(false),
     firstDraw(true),
@@ -128,8 +125,8 @@ namespace Lum {
   {
     // Tell the window, that this object hides
     // Dialog may delgate focus or other things
-    if (visible && GetWindow()!=NULL && dynamic_cast<Dialog*>(GetWindow()->GetMaster())!=NULL) {
-      dynamic_cast<Dialog*>(GetWindow()->GetMaster())->ObjectHides(this);
+    if (visible && GetWindow()!=NULL && dynamic_cast<Window*>(GetWindow()->GetMaster())!=NULL) {
+      dynamic_cast<Window*>(GetWindow()->GetMaster())->ObjectHides(this);
     }
 
     visible=false;
@@ -331,64 +328,103 @@ namespace Lum {
     return 0;
   }
 
+  /**
+    Set a size constraint for the object.
+   */
+  Object& Object::SetConstraint(Constraint constraint,
+                                Base::Size::Mode mode,
+                                size_t value,
+                                const OS::FontRef& font)
+  {
+    constraints.push_back(ConstraintSize(constraint,Base::Size(mode,value,font)));
+
+    return *this;
+  }
+
   /**
     Set the width of the object.
     "Mode" defines the interpretation of the given value.
   */
-  void Object::SetWidth(Base::Size::Mode mode, size_t value)
+  Object& Object::SetWidth(Base::Size::Mode mode,
+                           size_t value,
+                           const OS::FontRef& font)
   {
-    setWidth.SetSize(mode,value);
+    SetConstraint(constraintWidth,mode,value,font);
+
+    return *this;
   }
 
   /**
     Set the height of the object.
     "Mode" defines the interpretation of the given value.
   */
-  void Object::SetHeight(Base::Size::Mode mode, size_t value)
+  Object& Object::SetHeight(Base::Size::Mode mode,
+                            size_t value,
+                            const OS::FontRef& font)
   {
-    setHeight.SetSize(mode,value);
+    SetConstraint(constraintHeight,mode,value,font);
+
+    return *this;
   }
 
   /**
     Set the minimal width of the object.
     "Mode" defines the interpretation of the given value.
   */
-  void Object::SetMinWidth(Base::Size::Mode mode, size_t value)
+  Object& Object::SetMinWidth(Base::Size::Mode mode,
+                              size_t value,
+                              const OS::FontRef& font)
   {
-    setMinWidth.SetSize(mode,value);
+    SetConstraint(constraintMinWidth,mode,value,font);
+
+    return *this;
   }
 
   /**
     Set the minimal height of the object.
     "Mode" defines the interpretation of the given value.
   */
-  void Object::SetMinHeight(Base::Size::Mode mode, size_t value)
+  Object& Object::SetMinHeight(Base::Size::Mode mode,
+                               size_t value,
+                               const OS::FontRef& font)
   {
-    setMinHeight.SetSize(mode,value);
+    SetConstraint(constraintMinHeight,mode,value,font);
+
+    return *this;
   }
 
   /**
     Set the maximum width of the object.
     "Mode" defines the interpretation of the given value.
   */
-  void Object::SetMaxWidth(Base::Size::Mode mode, size_t value)
+  Object& Object::SetMaxWidth(Base::Size::Mode mode,
+                              size_t value,
+                              const OS::FontRef& font)
   {
-    setMaxWidth.SetSize(mode,value);
+    SetConstraint(constraintMaxWidth,mode,value,font);
+
+    return *this;
   }
 
   /**
     Set the maximum height of the object.
     "Mode" defines the interpretation of the given value.
   */
-  void Object::SetMaxHeight(Base::Size::Mode mode, size_t value)
+  Object& Object::SetMaxHeight(Base::Size::Mode mode,
+                               size_t value,
+                               const OS::FontRef& font)
   {
-    setMaxHeight.SetSize(mode,value);
+    SetConstraint(constraintMaxHeight,mode,value,font);
+
+    return *this;
   }
 
-  void Object::SetFlex(bool horizontal, bool vertical)
+  Object& Object::SetFlex(bool horizontal, bool vertical)
   {
     horizontalFlex=horizontal;
     verticalFlex=vertical;
+
+    return *this;
   }
 
   bool Object::HorizontalFlex() const
@@ -503,14 +539,19 @@ namespace Lum {
   */
   OS::DrawInfo* Object::GetDrawInfo() const
   {
+    assert(GetWindow()!=NULL);
+
     return GetWindow()->GetDrawInfo();
   }
 
   OS::Color Object::GetTextColor(OS::DrawInfo *draw) const
   {
-     if (draw->disabled) {
-       return OS::display->GetColor(OS::Display::textDisabledColor);
-     }
+    if (parent!=NULL) {
+      return parent->GetTextColor(draw);
+    }
+    else if (draw->disabled) {
+      return OS::display->GetColor(OS::Display::textDisabledColor);
+    }
     else if (draw->selected) {
       return OS::display->GetColor(OS::Display::textSelectColor);
     }
@@ -1158,31 +1199,52 @@ namespace Lum {
   */
   void Object::CalcSize()
   {
-    if (setMinWidth.IsSizeSet()) {
-      minWidth=Base::RoundRange(setMinWidth.GetSize(),minWidth,maxWidth);
+    for(std::list<ConstraintSize>::const_iterator iter=constraints.begin();
+        iter!=constraints.end();
+        ++iter) {
+      switch (iter->constraint) {
+        case constraintMinWidth:
+          minWidth=Base::RoundRange(iter->size.GetSize(),width,maxWidth);
+          break;
+        case constraintMinHeight:
+          minHeight=Base::RoundRange(iter->size.GetSize(),height,maxHeight);
+          break;
+        default:
+          break;
+      }
     }
 
-    if (setMinHeight.IsSizeSet()) {
-      minHeight=Base::RoundRange(setMinHeight.GetSize(),minHeight,maxHeight);
-    }
-
-    if (setMaxWidth.IsSizeSet()) {
-      maxWidth=Base::RoundRange(setMaxWidth.GetSize(),minWidth,maxWidth);
-    }
-
-    if (setMaxHeight.IsSizeSet()) {
-      maxHeight=Base::RoundRange(setMaxHeight.GetSize(),minHeight,maxHeight);
+    for(std::list<ConstraintSize>::const_iterator iter=constraints.begin();
+        iter!=constraints.end();
+        ++iter) {
+      switch (iter->constraint) {
+        case constraintMaxWidth:
+          maxWidth=Base::RoundRange(minWidth,width,iter->size.GetSize());
+          break;
+        case constraintMaxHeight:
+          maxHeight=Base::RoundRange(minHeight,height,iter->size.GetSize());
+          break;
+        default:
+          break;
+      }
     }
 
     width=Base::RoundRange(width,minWidth,maxWidth);
     height=Base::RoundRange(height,minHeight,maxHeight);
 
-    if (setWidth.IsSizeSet()) {
-      width=Base::RoundRange(setWidth.GetSize(),minWidth,maxWidth);
-    }
-
-    if (setHeight.IsSizeSet()) {
-      height=Base::RoundRange(setHeight.GetSize(),minHeight,maxHeight);
+    for(std::list<ConstraintSize>::const_iterator iter=constraints.begin();
+        iter!=constraints.end();
+        ++iter) {
+      switch (iter->constraint) {
+        case constraintWidth:
+          width=Base::RoundRange(minWidth,iter->size.GetSize(),maxWidth);
+          break;
+        case constraintHeight:
+          height=Base::RoundRange(minHeight,iter->size.GetSize(),maxHeight);
+          break;
+        default:
+          break;
+      }
     }
 
     oWidth=width;
@@ -1472,8 +1534,8 @@ namespace Lum {
   void Object::LeaveFocus()
   {
     if (HasFocus()) {
-      if (GetWindow()!=NULL && dynamic_cast<Dialog*>(GetWindow()->GetMaster())!=NULL) {
-        dynamic_cast<Dialog*>(GetWindow()->GetMaster())->FocusNext();
+      if (GetWindow()!=NULL && dynamic_cast<Window*>(GetWindow()->GetMaster())!=NULL) {
+        dynamic_cast<Window*>(GetWindow()->GetMaster())->FocusNext();
       }
     }
   }
@@ -1563,7 +1625,7 @@ namespace Lum {
       }
 
       OS::display->GetFill(OS::Display::backgroundFillIndex)->Draw(draw,
-                                                                   this->oX,this->oY,
+                                                                   oX,oY,
                                                                    oWidth,oHeight,
                                                                    x,y,w,h);
     }
@@ -1660,8 +1722,8 @@ namespace Lum {
 
     // Tell the window, that this object hides
     // Dialog may delgate focus or other things
-    if (GetWindow()!=NULL && dynamic_cast<Dialog*>(GetWindow()->GetMaster())!=NULL) {
-      dynamic_cast<Dialog*>(GetWindow()->GetMaster())->ObjectHides(this);
+    if (GetWindow()!=NULL && dynamic_cast<Window*>(GetWindow()->GetMaster())!=NULL) {
+      dynamic_cast<Window*>(GetWindow()->GetMaster())->ObjectHides(this);
     }
   }
 
@@ -1796,9 +1858,7 @@ namespace Lum {
 
   Control::~Control()
   {
-    if (model.Valid()) {
-      UnattachModel(model);
-    }
+    // no code
   }
 
   bool Control::HandlesFocus() const
@@ -1814,14 +1874,14 @@ namespace Lum {
    */
   bool Control::SetModel(Base::Model* model)
   {
-    if ((model!=NULL) && this->model.Valid()) {
-      UnattachModel(this->model);
+    if (this->model.Valid()) {
+      Forget(this->model);
     }
 
     this->model=model;
 
     if (this->model.Valid()) {
-      AttachModel(this->model);
+      Observe(this->model);
     }
 
     return true;
@@ -1835,11 +1895,11 @@ namespace Lum {
   void Control::Resync(Base::Model* model, const Base::ResyncMsg& msg)
   {
     // Delegate the focus, if we get disabled
-    if (model==this->model && HasFocus() && !model->IsEnabled()) {
-      Dialog* dialog;
+    if (model==this->model && !model->IsEnabled() && HasFocus()) {
+      Window* dialog;
 
-      if (GetWindow()!=NULL && (dialog=dynamic_cast<Dialog*>(GetWindow()->GetMaster()))!=NULL) {
-        dialog->FocusFirst();
+      if (GetWindow()!=NULL && (dialog=dynamic_cast<Window*>(GetWindow()->GetMaster()))!=NULL) {
+        dialog->FocusNext();
       }
     }
 
@@ -1849,14 +1909,13 @@ namespace Lum {
   Scrollable::Scrollable()
   : hAdjustment(new Model::Adjustment()), vAdjustment(new Model::Adjustment())
   {
-    AttachModel(hAdjustment->GetTopModel());
-    AttachModel(vAdjustment->GetTopModel());
+    Observe(hAdjustment->GetTopModel());
+    Observe(vAdjustment->GetTopModel());
   }
 
   Scrollable::~Scrollable()
   {
-    UnattachModel(hAdjustment->GetTopModel());
-    UnattachModel(vAdjustment->GetTopModel());
+    // no code
   }
 
   void Scrollable::CalculateDimension()
@@ -1866,30 +1925,34 @@ namespace Lum {
 
   void Scrollable::SetHAdjustment(Model::Adjustment* adjustment)
   {
-    UnattachModel(hAdjustment->GetTopModel());
+    assert(adjustment!=NULL && adjustment->GetTopModel()!=NULL);
 
-    hAdjustment=adjustment;
+    Forget(hAdjustment->GetTopModel());
 
-    AttachModel(hAdjustment->GetTopModel());
+    this->hAdjustment=adjustment;
+
+    Observe(hAdjustment->GetTopModel());
   }
 
   void Scrollable::SetVAdjustment(Model::Adjustment* adjustment)
   {
-    UnattachModel(vAdjustment->GetTopModel());
+    assert(adjustment!=NULL && adjustment->GetTopModel()!=NULL);
+
+    Forget(vAdjustment->GetTopModel());
 
     vAdjustment=adjustment;
 
-    AttachModel(vAdjustment->GetTopModel());
+    Observe(vAdjustment->GetTopModel());
   }
 
   Model::Adjustment* Scrollable::GetHAdjustment() const
   {
-    return hAdjustment.Get();
+    return hAdjustment;
   }
 
   Model::Adjustment* Scrollable::GetVAdjustment() const
   {
-    return vAdjustment.Get();
+    return vAdjustment;
   }
 
   void Group::Draw(int x, int y, size_t w, size_t h)
@@ -2131,8 +2194,27 @@ namespace Lum {
     return container->GetBaseline();
   }
 
+  void Component::CalcSize()
+  {
+    assert(container!=NULL);
+
+    container->SetParent(this);
+    container->SetFlex(true,true);
+    container->CalcSize();
+
+    minWidth=container->GetOMinWidth();
+    minHeight=container->GetOMinHeight();
+
+    width=container->GetOWidth();
+    height=container->GetOHeight();
+
+    Object::CalcSize();
+  }
+
   void Component::Layout()
   {
+    assert(container!=NULL);
+
     container->MoveResize(x,y,width,height);
 
     Object::Layout();
@@ -2197,6 +2279,23 @@ namespace Lum {
     return container->GetBaseline();
   }
 
+  void ControlComponent::CalcSize()
+  {
+    assert(container!=NULL);
+
+    container->SetParent(this);
+    container->SetFlex(true,true);
+    container->CalcSize();
+
+    minWidth=container->GetOMinWidth();
+    minHeight=container->GetOMinHeight();
+
+    width=container->GetOWidth();
+    height=container->GetOHeight();
+
+    Control::CalcSize();
+  }
+
   void ControlComponent::Layout()
   {
     container->MoveResize(x,y,width,height);
