@@ -24,7 +24,8 @@ namespace Lum {
 
   PercentBar::PercentBar()
   : horizontal(true),
-    font(OS::display->GetFont())
+    font(OS::display->GetFont(OS::Display::fontTypeProportional,
+                              OS::Display::fontScaleFootnote))
   {
     SetBackground(OS::display->GetFill(OS::Display::graphBackgroundFillIndex));
   }
@@ -59,7 +60,12 @@ namespace Lum {
              box->minHeight;
     }
     else {
-      width=font->height+
+      width=0;
+      for (size_t i=0; i<=9; i++) {
+        width=std::max(width,font->StringWidth(Base::NumberToWString(i)));
+      }
+
+      width=font->StringWidth(L"1")+2*width+font->StringWidth(L"%")+
             2*OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder)+
             box->minWidth;
     height=1;
