@@ -23,11 +23,9 @@
 
 namespace Lum {
 
-  static ImageState::Prefs *prefs=new ::Lum::ImageState::Prefs(L"Radio");
-
   Radio::Radio()
    : ImageState(OS::Theme::objRadio)
   {
-    SetPrefs(::Lum::prefs);
+    // no code
   }
 }
