@@ -98,7 +98,7 @@ namespace Lum {
   {
     Object::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
@@ -175,7 +175,7 @@ namespace Lum {
     int          interval,exp,max,pos,mark,off,width,height,intv;
     OS::DrawInfo *draw;
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
