@@ -203,7 +203,7 @@ namespace Lum {
 
     Control::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       draw->focused=false;
       return;
     }
@@ -479,7 +479,7 @@ namespace Lum {
 
     Control::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       draw->focused=false;
       return;
     }
