@@ -34,12 +34,7 @@ namespace Lum {
 
   State::~State()
   {
-    if (boolModel.Valid()) {
-      UnattachModel(boolModel);
-    }
-    if (intModel.Valid()) {
-      UnattachModel(intModel);
-    }
+    // no code
   }
 
   bool State::IsIn(const OS::MouseEvent& event) const
