@@ -21,7 +21,12 @@
 
 #include <Lum/OS/Theme.h>
 
+#include <Lum/Base/String.h>
+
+#include <Lum/Array.h>
+#include <Lum/Button.h>
 #include <Lum/Menu.h>
+#include <Lum/Space.h>
 
 namespace Lum {
 
@@ -135,7 +140,7 @@ namespace Lum {
     visWidth(20),
     offset(0),cursor(0),
     markA((size_t)-1),markB((size_t)-1),
-    font(::Lum::OS::display->GetFont()),
+    font(OS::display->GetFont()),
     model(NULL),
     selected(false),
     readOnly(false),
@@ -146,11 +151,12 @@ namespace Lum {
     copyAction(new Model::Action),
     pasteAction(new Model::Action),
     eraseAction(new Model::Action),
-    markAllAction(new Model::Action)
+    markAllAction(new Model::Action),
+    inputHelper(NULL)
   {
     SetBackground(OS::display->GetFill(OS::Display::entryBackgroundFillIndex));
 
-    SetController(::Lum::controller);
+    SetController(Lum::controller);
 
     SetCanFocus(true);
     RequestFocus();
@@ -162,30 +168,20 @@ namespace Lum {
     eraseAction->Disable();
     markAllAction->Disable();
 
-    AttachModel(blinkAction);
+    Observe(blinkAction);
 
-    AttachModel(cutAction);
-    AttachModel(copyAction);
-    AttachModel(pasteAction);
-    AttachModel(eraseAction);
-    AttachModel(markAllAction);
+    Observe(cutAction);
+    Observe(copyAction);
+    Observe(pasteAction);
+    Observe(eraseAction);
+    Observe(markAllAction);
   }
 
   String::~String()
   {
     OS::display->RemoveTimer(blinkAction);
 
-    UnattachModel(markAllAction);
-    UnattachModel(eraseAction);
-    UnattachModel(pasteAction);
-    UnattachModel(copyAction);
-    UnattachModel(cutAction);
-
-    UnattachModel(blinkAction);
-
-    if (model.Valid()) {
-      UnattachModel(model);
-    }
+    delete inputHelper;
   }
 
   bool String::HasBaseline() const
@@ -197,7 +193,7 @@ namespace Lum {
   {
     assert(inited);
 
-    return GetTopBorder()+OS::display->GetTheme()->GetEntryHorizTextOffset()+(height-font->height) / 2 + font->ascent;
+    return GetTopBorder()+OS::display->GetTheme()->GetEntryVertTextOffset()+(height-font->height) / 2 + font->ascent;
   }
 
   bool String::SetModel(Base::Model* model)
@@ -209,6 +205,26 @@ namespace Lum {
     return this->model.Valid();
   }
 
+  void String::SetInputHelper(InputHelper *inputHelper)
+  {
+    delete this->inputHelper;
+
+    this->inputHelper=inputHelper;
+
+    SetRequestsKeyboard(this->inputHelper==NULL);
+  }
+
+  void String::OpenInputHelper()
+  {
+    if (//OS::display->GetKeyboardHandler()!=NULL &&
+        inputHelper!=NULL &&
+        !inputHelper->IsOpen()) {
+      inputHelper->SetParent(GetWindow());
+      inputHelper->SetReference(this);
+      inputHelper->Open(this);
+    }
+  }
+
   void String::SetCursorUpAction(Model::Action* action)
   {
     cursorUpAction=action;
@@ -630,8 +646,8 @@ namespace Lum {
 
   void String::CalcSize()
   {
-    width=visWidth+2*OS::display->GetTheme()->GetEntryHorizTextOffset();
-    height=font->height+2*OS::display->GetTheme()->GetEntryVertTextOffset();
+    width=visWidth;
+    height=font->height;
 
     minWidth=width;
     minHeight=height;
@@ -820,7 +836,6 @@ namespace Lum {
 
     Control::Draw(x,y,w,h);
 
-
     if (!OIntersect(x,y,w,h)) {
       draw->focused=false;
       return;
@@ -836,12 +851,13 @@ namespace Lum {
 
     /* Draw background */
     if (!model.Valid() || !model->IsEnabled()) {
-      DrawParentBackground(x,y,w,h);
-    }
-    else {
-      DrawBackground(x,y,w,h);
+      draw->disabled=true;
     }
 
+    DrawBackground(x,y,w,h);
+
+    draw->disabled=false;
+
     /* Draw optional baseline */
     if (baseline) {
       draw->PushForeground(OS::Display::tableTextColor);
@@ -1083,6 +1099,7 @@ namespace Lum {
       TriggerCursorBlink();
       ClearSelection();
       Redraw();
+
       OS::display->QuerySelection(GetWindow(),this);
 
       return true;
@@ -1100,9 +1117,9 @@ namespace Lum {
           SetSelection(help,cursor);
           Redraw();
         }
-      }
 
-      return true;
+        OpenInputHelper();
+      }
     }
     else if (event.type==OS::MouseEvent::move && event.IsGrabed() && event.qualifier==OS::qualifierButton1) {
       size_t help=GetCursorPos(event.x);
@@ -1264,5 +1281,215 @@ namespace Lum {
 
     Control::Resync(model,msg);
   }
+
+  String::InputHelper::InputHelper()
+   : backAction(new Model::Action())
+  {
+    Observe(backAction);
+  }
+
+  void String::InputHelper::RegisterKey(Model::Action* action, const std::wstring& string)
+  {
+    assert(action!=NULL && !string.empty());
+
+    Observe(action);
+
+    strings[action]=string;
+  }
+
+  Button* String::InputHelper::CreateTextButton(const std::wstring& label, const std::wstring& text)
+  {
+    Button           *button;
+    Model::ActionRef action=new Model::Action();
+
+    button=new Button(label);
+    button->SetFlex(true,true);
+    button->SetModel(action);
+
+    RegisterKey(action,text);
+
+    return button;
+  }
+
+  Button* String::InputHelper::CreateTextButton(const std::wstring& label, Model::Action* action)
+  {
+    Button           *button;
+
+    button=new Button(label);
+    button->SetFlex(true,true);
+    button->SetModel(action);
+
+    return button;
+  }
+
+  bool String::InputHelper::Open(String *string)
+  {
+    this->string=string;
+
+    return Popup::Open(false);
+  }
+
+  void String::InputHelper::Close()
+  {
+    strings.clear();
+
+    Popup::Close();
+  }
+
+  void String::InputHelper::Resync(Base::Model* model, const Base::ResyncMsg& msg)
+  {
+    if (dynamic_cast<Model::Action*>(model)!=NULL &&
+             dynamic_cast<Model::Action*>(model)->IsFinished()){
+      std::map<Model::ActionRef,std::wstring>::iterator iter=strings.find(dynamic_cast<Model::Action*>(model));
+
+      if (iter!=strings.end()) {
+        string->ActionInsertString(iter->second);
+      }
+      else if (model==backAction) {
+        string->ActionBackspace();
+      }
+    }
+    Popup::Resync(model,msg);
+  }
+
+  InputHelperNumber::InputHelperNumber(Type type)
+   : type(type),
+     colonAction(new Model::Action())
+  {
+    digitActions.resize(16);
+
+    for (size_t i=0; i<=15; i++) {
+      digitActions[i]=new Lum::Model::Action();
+    }
+  }
+
+  void InputHelperNumber::PreInit()
+  {
+    Array *array=new Array();
+
+    array->SetFlex(false,false);
+    array->SetSpace(false,false);
+
+    if (type==typeBin) {
+      array->SetHorizontalCount(3);
+      array->Add(CreateTextButton(L"0",L"0"));
+      array->Add(CreateTextButton(L"1",L"1"));
+      array->Add(CreateTextButton(L"<-",backAction));
+    }
+    else if (type==typeOct) {
+      array->SetHorizontalCount(5);
+      array->Add(CreateTextButton(L"0",L"0"));
+      array->Add(CreateTextButton(L"1",L"1"));
+      array->Add(CreateTextButton(L"2",L"2"));
+      array->Add(CreateTextButton(L"3",L"3"));
+      array->Add(CreateTextButton(L"4",L"4"));
+      array->Add(CreateTextButton(L"5",L"5"));
+      array->Add(CreateTextButton(L"6",L"6"));
+      array->Add(CreateTextButton(L"7",L"7"));
+      array->Add(new VSpace());
+      array->Add(CreateTextButton(L"<-",backAction));
+    }
+    else if (type==typePosDec) {
+      array->SetHorizontalCount(3);
+      array->Add(CreateTextButton(L"7",L"7"));
+      array->Add(CreateTextButton(L"8",L"8"));
+      array->Add(CreateTextButton(L"9",L"9"));
+
+      array->Add(CreateTextButton(L"4",L"4"));
+      array->Add(CreateTextButton(L"5",L"5"));
+      array->Add(CreateTextButton(L"6",L"6"));
+
+      array->Add(CreateTextButton(L"1",L"1"));
+      array->Add(CreateTextButton(L"2",L"2"));
+      array->Add(CreateTextButton(L"3",L"3"));
+
+      array->Add(CreateTextButton(L"0",L"0"));
+      array->Add(new VSpace());
+      array->Add(CreateTextButton(L"<-",backAction));
+    }
+    else if (type==typeDec) {
+      array->SetHorizontalCount(3);
+      array->Add(CreateTextButton(L"7",L"7"));
+      array->Add(CreateTextButton(L"8",L"8"));
+      array->Add(CreateTextButton(L"9",L"9"));
+
+      array->Add(CreateTextButton(L"4",L"4"));
+      array->Add(CreateTextButton(L"5",L"5"));
+      array->Add(CreateTextButton(L"6",L"6"));
+
+      array->Add(CreateTextButton(L"1",L"1"));
+      array->Add(CreateTextButton(L"2",L"2"));
+      array->Add(CreateTextButton(L"3",L"3"));
+
+      array->Add(CreateTextButton(L"0",L"0"));
+      array->Add(CreateTextButton(L"-",L"-"));
+      array->Add(CreateTextButton(L"<-",backAction));
+    }
+    else if (type==typeHex) {
+      array->SetHorizontalCount(9);
+      array->Add(CreateTextButton(L"0",L"0"));
+      array->Add(CreateTextButton(L"1",L"1"));
+      array->Add(CreateTextButton(L"2",L"2"));
+      array->Add(CreateTextButton(L"3",L"3"));
+      array->Add(CreateTextButton(L"4",L"4"));
+      array->Add(CreateTextButton(L"5",L"5"));
+      array->Add(CreateTextButton(L"6",L"6"));
+      array->Add(CreateTextButton(L"7",L"7"));
+      array->Add(CreateTextButton(L"8",L"8"));
+      array->Add(CreateTextButton(L"9",L"9"));
+      array->Add(CreateTextButton(L"A",L"A"));
+      array->Add(CreateTextButton(L"B",L"B"));
+      array->Add(CreateTextButton(L"C",L"C"));
+      array->Add(CreateTextButton(L"D",L"D"));
+      array->Add(CreateTextButton(L"E",L"E"));
+      array->Add(CreateTextButton(L"F",L"F"));
+      array->Add(new VSpace());
+      array->Add(CreateTextButton(L"<-",backAction));
+    }
+    else if (type==typePosFloat) {
+      array->SetHorizontalCount(3);
+      array->Add(CreateTextButton(L"7",L"7"));
+      array->Add(CreateTextButton(L"8",L"8"));
+      array->Add(CreateTextButton(L"9",L"9"));
+
+      array->Add(CreateTextButton(L"4",L"4"));
+      array->Add(CreateTextButton(L"5",L"5"));
+      array->Add(CreateTextButton(L"6",L"6"));
+
+      array->Add(CreateTextButton(L"1",L"1"));
+      array->Add(CreateTextButton(L"2",L"2"));
+      array->Add(CreateTextButton(L"3",L"3"));
+
+      array->Add(CreateTextButton(L"0",L"0"));
+      array->Add(CreateTextButton(Lum::Base::GetDecimalPointWString(),Lum::Base::GetDecimalPointWString()));
+      array->Add(CreateTextButton(L"<-",backAction));
+    }
+    else if (type==typeFloat) {
+      array->SetHorizontalCount(4);
+      array->Add(CreateTextButton(L"7",L"7"));
+      array->Add(CreateTextButton(L"8",L"8"));
+      array->Add(CreateTextButton(L"9",L"9"));
+      array->Add(CreateTextButton(L"-",L"-"));
+
+      array->Add(CreateTextButton(L"4",L"4"));
+      array->Add(CreateTextButton(L"5",L"5"));
+      array->Add(CreateTextButton(L"6",L"6"));
+      array->Add(CreateTextButton(L"+",L"+"));
+
+      array->Add(CreateTextButton(L"1",L"1"));
+      array->Add(CreateTextButton(L"2",L"2"));
+      array->Add(CreateTextButton(L"3",L"3"));
+      array->Add(CreateTextButton(L"e",L"e"));
+
+      array->Add(CreateTextButton(L"0",L"0"));
+      array->Add(CreateTextButton(Lum::Base::GetDecimalPointWString(),Lum::Base::GetDecimalPointWString()));
+      array->Add(new VSpace());
+      array->Add(CreateTextButton(L"<-",backAction));
+    }
+
+    SetMain(array);
+
+    Popup::PreInit();
+  }
 }
 
