@@ -59,9 +59,7 @@ namespace Lum {
   }
 
   TableView::TableView()
-  : model(),
-    selection(new Model::NoneSelection()),
-    selectionAction(new Model::Action),
+  : selectionAction(new Model::Action),
     doubleClickAction(new Model::Action),
     mouseSelectionAction(new Model::Action),
     updateScrollerAction(new Model::Action),
@@ -70,10 +68,13 @@ namespace Lum {
     autoVSize(false),
     currentPos(1),
     scrolling(false),
-    scrollRefresh(true),
+    scrollRefresh(false),
     scrollTimerAction(new Model::Action()),
-    cx(0),
-    cy(0),
+    px(0),
+    py(0),
+    ppos(0),
+    my(0),
+    sy(0),
     mouseTimerAction(new Model::Action()),
     tableWidth(0),
     rowHeight(0),
@@ -87,29 +88,13 @@ namespace Lum {
 
     SetController(::Lum::controller);
 
-    AttachModel(updateScrollerAction);
-    AttachModel(scrollTimerAction);
-    AttachModel(mouseTimerAction);
+    Observe(updateScrollerAction);
+    Observe(scrollTimerAction);
+    Observe(mouseTimerAction);
   }
 
   TableView::~TableView()
   {
-    UnattachModel(mouseTimerAction);
-    UnattachModel(scrollTimerAction);
-    UnattachModel(updateScrollerAction);
-
-    if (model.Valid()) {
-      UnattachModel(model);
-    }
-
-    if (header.Valid()) {
-      UnattachModel(header);
-    }
-
-    if (selection.Valid()) {
-      UnattachModel(selection);
-    }
-
     delete formatProvider;
   }
 
@@ -238,13 +223,13 @@ namespace Lum {
   void TableView::SetHeader(Model::Header *header)
   {
     if (this->header.Valid()) {
-      UnattachModel(this->header);
+      Forget(this->header);
     }
 
     this->header=header;
 
     if (this->header.Valid()) {
-      AttachModel(this->header);
+      Observe(this->header);
     }
   }
 
@@ -258,12 +243,15 @@ namespace Lum {
   {
     assert(selection!=NULL);
 
-    this->selection->Clear();
-    UnattachModel(this->selection);
+    if (this->selection.Valid()) {
+      this->selection->Clear();
+      Forget(this->selection);
+    }
 
     this->selection=selection;
+
     if (this->selection.Valid()) {
-      AttachModel(this->selection);
+      Observe(this->selection);
     }
   }
 
@@ -390,8 +378,9 @@ namespace Lum {
     // TableView does know, that GetParent()->GetParent() is normally of type
     // Table and requests width of vertical scroller to resize labels that way
     // that content does not scroll out of view...
-    if (firstDraw && GetParent()!=NULL &&
-        dynamic_cast<Table*>(GetParent()->GetParent())!=NULL/* &&
+    if (header->GetColumns()>1 &&
+        firstDraw &&
+        GetParent()!=NULL && dynamic_cast<Table*>(GetParent()->GetParent())!=NULL/* &&
         vAdjustment->GetVisible()<hAdjustment->GetTotal()*/) {
       targetWidth-=dynamic_cast<Table*>(GetParent()->GetParent())->GetVerticalScrollerWidth();
     }
@@ -488,6 +477,16 @@ namespace Lum {
 
   /* ---------- Printing --------------- */
 
+  OS::Color TableView::GetTextColor(OS::DrawInfo *draw) const
+  {
+    if (draw->selected) {
+      return OS::display->GetColor(OS::Display::fillTextColor);
+    }
+    else {
+      return OS::display->GetColor(OS::Display::tableTextColor);
+    }
+  }
+
   void TableView::DrawCell(OS::DrawInfo* draw,
                            int xPos,
                            int yPos,
@@ -508,12 +507,10 @@ namespace Lum {
 
     if (selected) {
       back=OS::display->GetFill(OS::Display::tableBackgroundFillIndex);
-      draw->PushForeground(OS::Display::fillTextColor);
       draw->selected=true;
     }
     else {
       back=formatProvider->GetBackground(x,y);
-      draw->PushForeground(formatProvider->GetTextColor(x,y));
     }
 
     cliped=false;
@@ -528,6 +525,13 @@ namespace Lum {
         back->Draw(draw,xPos,yPos,width,height,xPos,yPos,width,height);
       }
 
+      if (selected) {
+        draw->PushForeground(OS::Display::fillTextColor);
+      }
+      else {
+        draw->PushForeground(formatProvider->GetTextColor(x,y));
+      }
+
       font->StringExtent(string,extent);
       cliped=extent.width>width;
 
@@ -548,6 +552,8 @@ namespace Lum {
       }
 
       draw->DrawString(textStart,yPos+font->ascent+((int)height-(int)font->height) / 2,string);
+
+      draw->PopForeground();
     }
     else if (object!=NULL) {
       bool focused=draw->focused;
@@ -562,9 +568,8 @@ namespace Lum {
 
       object->Resize(width,height);
       object->Move(xPos,yPos+((int)height-(int)object->GetOHeight()) / 2);
-      object->SetBackground(back);
 
-      if (drawBackground && (object->GetOWidth()!=width || object->GetOHeight()!=height)) {
+      if (drawBackground) {
         back->Draw(draw,xPos,yPos,width,height,xPos,yPos,width,height);
       }
 
@@ -574,7 +579,10 @@ namespace Lum {
         draw->PushClip(xPos,yPos,width,height);
       }
 
-      object->Draw(xPos,yPos,width,height);
+      if (object->GetBackground()==NULL) {
+        object->SetBackground(new Lum::OS::EmptyFill());
+      }
+      object->Draw(xPos,yPos,object->GetOWidth(),object->GetOHeight());
 
       draw->focused=focused;
     }
@@ -582,7 +590,7 @@ namespace Lum {
       back->Draw(draw,xPos,yPos,width,height,xPos,yPos,width,height);
     }
 
-    if (selected && !selection->IsLineSelected(y) && HasFocus()) {
+    if (selected && selection.Valid() && !selection->IsLineSelected(y) && HasFocus()) {
       OS::FrameRef focus=OS::display->GetFrame(OS::Display::focusFrameIndex);
 
       /* Draw a frame arond one cell */
@@ -594,7 +602,6 @@ namespace Lum {
     }
 
     draw->selected=false;
-    draw->PopForeground();
   }
 
   /**
@@ -636,11 +643,7 @@ namespace Lum {
     if (x<(int)(this->x+width)) { /* Fill space behind last cell in row */
       OS::Fill* back;
 
-      if (selection.Valid() && selection->IsLineSelected(line)) {
-        back=OS::display->GetFill(OS::Display::tableBackgroundFillIndex);
-        draw->selected=true;
-      }
-      else if (line%2!=0) {
+      if (line%2!=0) {
         back=OS::display->GetFill(OS::Display::tableBackgroundFillIndex);
       }
       else {
@@ -651,9 +654,6 @@ namespace Lum {
                  x,y,this->x+width-x+1,rowHeight,
                  x,y,this->x+width-x+1,rowHeight);
 
-      if (selection.Valid() && selection->IsLineSelected(line)) {
-        draw->selected=false;
-      }
     }
 
     if (selection.Valid() && selection->IsLineSelected(line) && HasFocus()) {
@@ -690,10 +690,6 @@ namespace Lum {
     endPos+=y;
 
     while (startPos<=endPos) {
-      draw->PushForeground(Lum::OS::display->GetColor(Lum::OS::Display::whiteColor));
-      draw->FillRectangle(x,startPos,width,rowHeight);
-      draw->PopForeground();
-
       DrawLine(draw,startPos,startLine+1);
       startPos+=rowHeight;
       startLine++;
@@ -774,6 +770,9 @@ namespace Lum {
 
   void TableView::Layout()
   {
+    // If we are still scorlling during a resize event, stop scrolling
+    scrollRefresh=false;
+
     CalculateRowHeight();
 
     if (model.Valid() && header.Valid() && autoFitColumns) {
@@ -789,7 +788,7 @@ namespace Lum {
   {
     Scrollable::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
@@ -860,9 +859,12 @@ namespace Lum {
         if (scrolling) {
           Lum::OS::display->AddTimer(0,1000000/25,scrollTimerAction);
         }
+        else {
+          scrollRefresh=false;
+        }
       }
       else {
-        scrollRefresh=true;
+        scrollRefresh=false;
         DrawRect(draw,y-this->y,h);
       }
     }
@@ -871,6 +873,14 @@ namespace Lum {
     }
   }
 
+  void TableView::Hide()
+  {
+    scrollRefresh=false;
+    scrolling=false;
+
+    Scrollable::Hide();
+  }
+
   void TableView::DrawFocus()
   {
     if (!model.Valid()) {
@@ -1019,9 +1029,11 @@ namespace Lum {
 
     if ((singleCell=dynamic_cast<Model::SingleCellSelection*>(selection.Get()))!=NULL) {
       singleCell->SelectCell(1,singleCell->GetRow());
+      MakeVisible(singleCell->GetColumn(),singleCell->GetRow());
     }
     else if ((singleLine=dynamic_cast<Model::SingleLineSelection*>(selection.Get()))!=NULL) {
       singleLine->SelectLine(1);
+      MakeVisible(1,singleLine->GetLine());
     }
     else {
       vAdjustment->SetTop(1);
@@ -1035,9 +1047,11 @@ namespace Lum {
 
     if ((singleCell=dynamic_cast<Model::SingleCellSelection*>(selection.Get()))!=NULL) {
       singleCell->SelectCell(header->GetColumns(),singleCell->GetRow());
+      MakeVisible(singleCell->GetColumn(),singleCell->GetRow());
     }
     else if ((singleLine=dynamic_cast<Model::SingleLineSelection*>(selection.Get()))!=NULL) {
       singleLine->SelectLine(model->GetRows());
+      MakeVisible(1,singleLine->GetLine());
     }
     else {
       vAdjustment->SetTop(vAdjustment->GetTotal()-vAdjustment->GetVisible());
@@ -1133,8 +1147,9 @@ namespace Lum {
     if (event.type==OS::MouseEvent::down && PointIsIn(event)) {
       if (event.button==OS::MouseEvent::button1) {
         if (GetCell(event.x,event.y,xc,yc) && selection.Valid() && yc<=model->GetRows()) {
-          cx=event.x;
-          cy=event.y;
+          px=event.x;
+          py=event.y;
+          ppos=currentPos;
 
           selection->SelectCell(xc,yc);
           OnMouseSelection();
@@ -1142,22 +1157,39 @@ namespace Lum {
             ActionDoubleClick();
           }
 
+          my=event.y;
+          sy=event.y;
           mouseTimer.SetToNow();
           Lum::OS::display->AddTimer(0,1000000/20,mouseTimerAction);
+          return true;
         }
       }
       else if (event.button==OS::MouseEvent::button4) {
+        scrollRefresh=false;
         vAdjustment->DecTop();
       }
       else if (event.button==OS::MouseEvent::button5) {
+        scrollRefresh=false;
         vAdjustment->IncTop();
       }
+    }
+    else if (event.type==OS::MouseEvent::move &&
+             (event.qualifier & OS::MouseEvent::button1) &&
+             event.IsGrabed()) {
+      my=event.y;
+
+      if (event.y>=py && (size_t)(event.y-py)>=ppos) {
+        vAdjustment->SetTop(1);
+      }
+      else {
+        vAdjustment->SetTop(ppos+(py-event.y));
+      }
 
       return true;
     }
-    else if (event.IsGrabed() &&
-             event.type==OS::MouseEvent::move &&
-             (event.qualifier & OS::MouseEvent::button1)) {
+    else if (event.IsGrabEnd()) {
+      Lum::OS::display->RemoveTimer(mouseTimerAction);
+
       Lum::Base::SystemTime now;
 
       now.Sub(mouseTimer);
@@ -1167,23 +1199,18 @@ namespace Lum {
         return true;
       }
 
-      int step=((cy-event.y)*1000000)/(now.GetMicroseconds()+1000000*now.GetTime());
+      int step=((sy-event.y)*1000000)/(now.GetMicroseconds()+1000000*now.GetTime());
 
       if (abs(step)<5) {
         return true;
       }
 
       if (step>0) {
-        step=(int)sqrt(step);
-      }
-      else {
-        step=-(int)sqrt(abs(step));
-      }
-
-      if (step>0) {
+        scrollRefresh=true;
         vAdjustment->SetTop(vAdjustment->GetTop()+step);
       }
       else if (step<0) {
+        scrollRefresh=true;
         if ((size_t)abs(step)<vAdjustment->GetTop()-1) {
           vAdjustment->SetTop(vAdjustment->GetTop()+step);
         }
@@ -1191,15 +1218,6 @@ namespace Lum {
           vAdjustment->SetTop(1);
         }
       }
-
-      cx=event.x;
-      cy=event.y;
-      mouseTimer.SetToNow();
-
-      return true;
-    }
-    else if (event.type==OS::MouseEvent::up && PointIsIn(event)) {
-      Lum::OS::display->RemoveTimer(mouseTimerAction);
     }
 
     return false;
@@ -1262,26 +1280,23 @@ namespace Lum {
         Redraw();
       }
       else if (model==vAdjustment->GetTopModel()) {
-        if (!scrolling) {
-          scrolling=true;
-          Redraw();
+        if (!scrollRefresh) {
+          currentPos=vAdjustment->GetTop();
         }
-      }
-      else if (model==hAdjustment->GetTopModel()) {
         Redraw();
       }
-      else if (model==selection) {
+      else if (model==hAdjustment->GetTopModel() || model==selection) {
         Redraw();
       }
-      if (model==scrollTimerAction && scrollTimerAction->IsFinished()) {
+      else if (model==scrollTimerAction && scrollTimerAction->IsFinished()) {
         Redraw();
       }
       else if (model==mouseTimerAction && mouseTimerAction->IsFinished()) {
-        vAdjustment->SetTop(currentPos);
-        Redraw();
-        Lum::OS::display->RemoveTimer(scrollTimerAction);
+        sy=my;
+        mouseTimer.SetToNow();
+        Lum::OS::display->AddTimer(0,1000000/20,mouseTimerAction);
       }
-      if (model==updateScrollerAction && updateScrollerAction->IsFinished()) {
+      else if (model==updateScrollerAction && updateScrollerAction->IsFinished()) {
         UpdateScroller();
       }
     }
