@@ -21,10 +21,8 @@
 
 #include <Lum/Base/L10N.h>
 
-#include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/Panel.h>
-#include <Lum/PopupGroup.h>
 #include <Lum/Space.h>
 #include <Lum/Time.h>
 #include <Lum/TimeView.h>
@@ -44,17 +42,12 @@ namespace Lum {
     // no code
   }
 
-  TimeSelect::Popup::Popup(TimeSelect *select, Base::TimeFormat format)
+  TimeSelect::TimeSelectPopup::TimeSelectPopup(TimeSelect *select, Base::TimeFormat format)
   : format(format),
     select(select),
     commit(new Model::Action())
   {
-    AttachModel(commit);
-  }
-
-  TimeSelect::Popup::~Popup()
-  {
-    UnattachModel(commit);
+    Observe(commit);
   }
 
   void TimeSelect::SetFormat(Base::TimeFormat format)
@@ -64,15 +57,11 @@ namespace Lum {
     this->format=format;
   }
 
-  void TimeSelect::Popup::PreInit()
+  void TimeSelect::TimeSelectPopup::PreInit()
   {
-    Button     *button;
-    ButtonRow  *row;
-    Panel      *panel;
-    PopupGroup *container;
-    Time       *picker;
-
-    container=new PopupGroup();
+    ButtonRow *row;
+    Panel     *panel;
+    Time      *picker;
 
     panel=new VPanel();
 
@@ -85,40 +74,30 @@ namespace Lum {
 
     panel->Add(new VSpace());
 
-    row=new ButtonRow();
+    row=ButtonRow::CreateOk(commit);
     row->SetFlex(true,false);
-
-    button=new Button();
-    button->SetFlex(true,true);
-    button->SetText(_ld(dlgButtonOk));
-    button->SetModel(commit);
-    row->Add(button);
-
     panel->Add(row);
 
-    container->SetMain(panel,false);
+    SetMain(panel,false);
 
-    SetTop(container);
-
-    Dialog::PreInit();
+    Popup::PreInit();
   }
 
-  void TimeSelect::Popup::Resync(Base::Model* model, const Base::ResyncMsg& msg)
+  void TimeSelect::TimeSelectPopup::Resync(Base::Model* model, const Base::ResyncMsg& msg)
   {
     if (model==commit && commit->IsFinished()) {
       select->GetModel()->Save();
       Exit();
     }
 
-    Dialog::Resync(model,msg);
+    Popup::Resync(model,msg);
   }
 
   void TimeSelect::OpenPopup()
   {
     GetModel()->Push();
 
-    popup=new Popup(this,format);
-    popup->SetType(OS::Window::typePopup);
+    popup=new TimeSelectPopup(this,format);
     popup->SetParent(GetWindow());
     popup->SetReference(this);
 
