@@ -30,13 +30,11 @@ namespace Lum {
   {
     SetBackground(OS::display->GetFill(OS::Display::scrolledBackgroundFillIndex));
 
-    AttachModel(refreshAction);
+    Observe(refreshAction);
   }
 
   View::~View()
   {
-    UnattachModel(refreshAction);
-
     delete hScroller;
     delete vScroller;
     delete object;
@@ -75,8 +73,8 @@ namespace Lum {
     assert(object!=NULL);
 
     if (this->object!=NULL) {
-      UnattachModel(object->GetHAdjustment());
-      UnattachModel(object->GetVAdjustment());
+      Forget(object->GetHAdjustment());
+      Forget(object->GetVAdjustment());
       delete this->object;
     }
 
@@ -84,8 +82,8 @@ namespace Lum {
     object->SetParent(this);
     object->SetFlex(true,true);
 
-    AttachModel(object->GetHAdjustment());
-    AttachModel(object->GetVAdjustment());
+    Observe(object->GetHAdjustment());
+    Observe(object->GetVAdjustment());
   }
 
   bool View::SetModel(Base::Model* model)
