@@ -39,37 +39,66 @@ namespace Lum {
     delete status;
   }
 
-  void WindowGroup::SetMenuStrip(Object* object)
+  void WindowGroup::SetMenuStrip(MenuStrip* menuStrip)
   {
-    this->men=object;
+    delete this->men;
+
+    this->men=menuStrip;
     if (men!=NULL) {
       men->SetParent(this);
     }
+
+    if (visible) {
+      if (this->men!=NULL) {
+        this->men->CalcSize();
+        this->men->ResizeWidth(width);
+      }
+
+      Redraw();
+    }
   }
 
   void WindowGroup::SetToolbar(Object* object)
   {
+    delete this->tool;
+
     this->tool=object;
     if (tool!=NULL) {
       tool->SetParent(this);
     }
+
+    if (visible) {
+      Redraw();
+    }
   }
 
   void WindowGroup::SetMain(Object* object, bool seamless)
   {
+    delete this->main;
+
     this->main=object;
     if (main!=NULL) {
       main->SetParent(this);
       mainSeamless=seamless;
     }
+
+    if (visible) {
+      Redraw();
+    }
   }
 
   void WindowGroup::SetStatusLine(Object* object)
   {
+    delete this->status;
+
     this->status=object;
     if (status!=NULL) {
       status->SetParent(this);
     }
+
+    if (visible) {
+      Redraw();
+    }
   }
 
   bool WindowGroup::VisitChildren(Visitor &visitor, bool /*onlyVisible*/)
